@@ -18,13 +18,17 @@
 #include "config.h"
 
 #include <qfile.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qstring.h>
+#include <qstringlist.h>
 
 #include <kcmdlineargs.h>
 #include <kconfig.h>
 #include <kcrash.h>
 #include <kglobal.h>
+#include <kstandarddirs.h>
+
+#include <artsc/artsc.h> // for arts_init()
 
 #include "libkwave/Parser.h"
 
@@ -58,6 +62,9 @@ KwaveApp::KwaveApp()
     m_topwidget_list.setAutoDelete(false);
     readConfig();
 
+    // initialize the aRts daemon, start him if necessary
+    initArts();
+
     // load the list of plugins
     PluginManager::findPlugins();
 
@@ -94,14 +101,14 @@ int KwaveApp::newInstance()
 //***************************************************************************
 bool KwaveApp::isOK()
 {
-    ASSERT(!m_topwidget_list.isEmpty());
+    Q_ASSERT(!m_topwidget_list.isEmpty());
     return (!m_topwidget_list.isEmpty());
 }
 
 //***************************************************************************
 bool KwaveApp::executeCommand(const QString &command)
 {
-//    debug("KwaveApp::executeCommand(%s)", command);    // ###
+//    qDebug("KwaveApp::executeCommand(%s)", command);    // ###
     Parser parser(command);
     if (parser.command() == "newwindow") {
 	newWindow(0);
@@ -139,11 +146,11 @@ void KwaveApp::addRecentFile(const QString &newfile)
 bool KwaveApp::newWindow(const KURL &url)
 {
     TopWidget *new_top_widget = new TopWidget(*this);
-    ASSERT(new_top_widget);
+    Q_ASSERT(new_top_widget);
     if (!new_top_widget) return false;
 
     if ( !(new_top_widget->isOK()) ) {
-	warning("KwaveApp::newWindow() failed!");
+	qWarning("KwaveApp::newWindow() failed!");
 	delete new_top_widget;
 	return false;
     }
@@ -175,8 +182,7 @@ bool KwaveApp::newWindow(const KURL &url)
 //***************************************************************************
 bool KwaveApp::closeWindow(TopWidget *todel)
 {
-    debug("KwaveApp::closeWindow(TopWidget *todel)");
-    ASSERT(todel);
+    Q_ASSERT(todel);
 
     // save the configuration, including the list of recent files
     saveConfig();
@@ -204,7 +210,7 @@ MemoryManager &KwaveApp::memoryManager()
 void KwaveApp::saveRecentFiles()
 {
     KConfig *cfg = KGlobal::config();
-    ASSERT(cfg);
+    Q_ASSERT(cfg);
     if (!cfg) return;
 
     cfg->setGroup("Recent Files");
@@ -221,11 +227,7 @@ void KwaveApp::saveRecentFiles()
 //***************************************************************************
 void KwaveApp::saveConfig()
 {
-    KConfig *cfg = KGlobal::config();
-    ASSERT(cfg);
-    if (!cfg) return;
-
-    // also save the list of recent files
+    // save the list of recent files
     saveRecentFiles();
 }
 
@@ -236,7 +238,7 @@ void KwaveApp::readConfig()
     QString key;
 
     KConfig *cfg = config();
-    ASSERT(cfg);
+    Q_ASSERT(cfg);
     if (!cfg) return;
 
     cfg->setGroup("Recent Files");
@@ -269,5 +271,34 @@ KwaveApp::~KwaveApp()
     m_memory_manager.close();
 }
 
+//***************************************************************************
+void KwaveApp::initArts()
+{
+    arts_init();
+
+    if (!Arts::Dispatcher::the()) { 
+	qWarning("aRts daemon isn't running. Starting it...");
+
+	QString path;
+	QStringList args;
+	
+	path = QFile::encodeName(KStandardDirs::findExe(
+	 	       		 QString::fromLatin1("kcminit")));
+	
+	args.append(QString::fromLatin1("arts"));
+
+	kdeinitExec(path, args);
+
+	int time = 0;
+	do {
+	    ::sleep(time/2);
+	    arts_init();
+	    // every time it fails, we should wait a little longer
+	    // between tries
+	    time++;
+	} while (time < 6 && !Arts::Dispatcher::the());
+    }
+}
+
 //***************************************************************************
 //***************************************************************************
