@@ -33,12 +33,11 @@
 #include <kstdaccel.h>
 #include <kstatusbar.h>
 
+#include "libkwave/KwavePlugin.h" // for some helper functions
 #include "libkwave/Parser.h"
 
-#include "libgui/Dialog.h"
 #include "libgui/MultiStateWidget.h"
 #include "libgui/OverViewWidget.h"
-#include "libgui/KwavePlugin.h" // for some helper functions
 
 #include "SignalWidget.h"
 #include "SignalManager.h"
@@ -66,16 +65,16 @@ MainWidget::MainWidget(QWidget *parent)
      frmChannelControls(0),
      m_scrollbar(0), m_lamps()/*, m_speakers()*/, m_last_tracks(0)
 {
-//    debug("MainWidget::MainWidget()");
+//    qDebug("MainWidget::MainWidget()");
     int s[3];
 
     // create the layout objects
     QGridLayout *topLayout = new QGridLayout(this, 3, 2, 0);
-    ASSERT(topLayout);
+    Q_ASSERT(topLayout);
     if (!topLayout) return;
 
     QHBoxLayout *signalLayout = new QHBoxLayout();
-    ASSERT(signalLayout);
+    Q_ASSERT(signalLayout);
     if (!signalLayout) return;
     topLayout->addLayout(signalLayout, 0, 1);
 
@@ -84,13 +83,13 @@ MainWidget::MainWidget(QWidget *parent)
     // background frame of the channel controls, does the
     // clipping for us
     QFrame *frmChannelsBack = new QFrame(this);
-    ASSERT(frmChannelsBack);
+    Q_ASSERT(frmChannelsBack);
     if (!frmChannelsBack) return;
     frmChannelsBack->setFrameStyle(0);
     frmChannelsBack->setFixedWidth(30);
 
     frmChannelControls = new QFrame(frmChannelsBack);
-    ASSERT(frmChannelControls);
+    Q_ASSERT(frmChannelControls);
     if (!frmChannelControls) return;
     frmChannelControls->setFrameStyle(0);
     frmChannelControls->setFixedWidth(30);
@@ -106,7 +105,7 @@ MainWidget::MainWidget(QWidget *parent)
     m_lamps.clear();
     MultiStateWidget *msw =
 	new MultiStateWidget(frmChannelControls, 0);
-    ASSERT(msw);
+    Q_ASSERT(msw);
     if (!msw) return;
     m_lamps.append(msw);
     s[0] = m_lamps.at(0)->addPixmap("light_on.xpm");
@@ -116,7 +115,7 @@ MainWidget::MainWidget(QWidget *parent)
 //    m_speakers.setAutoDelete(true);
 //    m_speakers.clear();
 //    msw = new MultiStateWidget(frmChannelControls, 0, 3);
-//    ASSERT(msw);
+//    Q_ASSERT(msw);
 //    if (!msw) return;
 //    m_speakers.append(msw);
 //    s[0] = m_speakers.at(0)->addPixmap("rspeaker.xpm");
@@ -127,7 +126,7 @@ MainWidget::MainWidget(QWidget *parent)
     // -- accelerator keys for 1...9 --
 
 // ###     keys = new QAccel(this);
-// ###     ASSERT(keys);
+// ###     Q_ASSERT(keys);
 // ###     if (!keys) return;
 // ###     for (int i=0; i < 10; i++) {
 // ### 	keys->insertItem(tbl_keys[i]);
@@ -138,7 +137,7 @@ MainWidget::MainWidget(QWidget *parent)
     // -- slider for horizontal scrolling --
 
     m_slider = new OverViewWidget(m_signal_widget.signalManager(), this);
-    ASSERT(m_slider);
+    Q_ASSERT(m_slider);
     if (!m_slider) return;
     m_slider->setFixedHeight(20/*playbutton->height()*3/4*/);
     topLayout->addWidget(m_slider, 1, 1);
@@ -146,7 +145,7 @@ MainWidget::MainWidget(QWidget *parent)
     // -- scrollbar for the signal widget and the channel controls --
 
     m_scrollbar = new QScrollBar(this);
-    ASSERT(m_scrollbar);
+    Q_ASSERT(m_scrollbar);
     if (!m_scrollbar) return;
     m_scrollbar->setOrientation(QScrollBar::Vertical);
     m_scrollbar->setFixedWidth(m_scrollbar->sizeHint().width());
@@ -186,8 +185,10 @@ MainWidget::MainWidget(QWidget *parent)
 	    this, SLOT(forwardZoomChanged(double)));
     connect(&m_signal_widget, SIGNAL(sigCommand(const QString &)),
 	    this, SLOT(forwardCommand(const QString &)));
-    connect(&m_signal_widget, SIGNAL(selectedTimeInfo(unsigned int,double)),
-	    this, SLOT(forwardSelectedTimeInfo(unsigned int, double)));
+    connect(&m_signal_widget, SIGNAL(selectedTimeInfo(unsigned int,
+            unsigned int, double)),
+	    this, SLOT(forwardSelectedTimeInfo(unsigned int,
+            unsigned int, double)));
     connect(&m_signal_widget, SIGNAL(sigTrackInserted(unsigned int)),
 	    this, SLOT(slotTrackInserted(unsigned int)));
     connect(&m_signal_widget, SIGNAL(sigTrackDeleted(unsigned int)),
@@ -198,16 +199,16 @@ MainWidget::MainWidget(QWidget *parent)
 
     refreshChannelControls();
 
-//    debug("MainWidget::MainWidget(): done.");
+//    qDebug("MainWidget::MainWidget(): done.");
 }
 
 //***************************************************************************
 bool MainWidget::isOK()
 {
-    ASSERT(frmChannelControls);
-//    ASSERT(keys); ###
-    ASSERT(m_scrollbar);
-    ASSERT(m_slider);
+    Q_ASSERT(frmChannelControls);
+//    Q_ASSERT(keys); ###
+    Q_ASSERT(m_scrollbar);
+    Q_ASSERT(m_slider);
 
     return ( frmChannelControls /* ### && keys */ &&
     	m_scrollbar && m_slider );
@@ -230,7 +231,7 @@ void MainWidget::resizeEvent(QResizeEvent *)
 //***************************************************************************
 void MainWidget::scrollbarMoved(int newval)
 {
-    ASSERT(frmChannelControls);
+    Q_ASSERT(frmChannelControls);
     if (!frmChannelControls) return;
 
     // move the signal and the channel controls
@@ -283,9 +284,10 @@ void MainWidget::forwardZoomChanged(double zoom)
 }
 
 //***************************************************************************
-void MainWidget::forwardSelectedTimeInfo(unsigned int samples, double ms)
+void MainWidget::forwardSelectedTimeInfo(unsigned int offset,
+                                         unsigned int length, double rate)
 {
-    emit selectedTimeInfo(samples, ms);
+    emit selectedTimeInfo(offset, length, rate);
 }
 
 //***************************************************************************
@@ -305,7 +307,7 @@ void MainWidget::resetChannels()
 {
     unsigned int t = tracks();
     for (unsigned int i = 0; i < t; i++) {
-	ASSERT(m_lamps.at(i));
+	Q_ASSERT(m_lamps.at(i));
 	if (m_lamps.at(i)) m_lamps.at(i)->setState(0);
     }
 }
@@ -315,7 +317,7 @@ void MainWidget::parseKey(int key)
 {
     if ((key < 0) || ((unsigned int)key >= tracks()))
 	return;
-    ASSERT(m_lamps.at(key));
+    Q_ASSERT(m_lamps.at(key));
     if (!m_lamps.at(key)) return;
     m_lamps.at(key)->nextState();
 }
@@ -329,7 +331,7 @@ void MainWidget::forwardCommand(const QString &command)
 //***************************************************************************
 bool MainWidget::executeCommand(const QString &command)
 {
-//    debug("MainWidget::executeCommand(%s)", command);
+//    qDebug("MainWidget::executeCommand(%s)", command);
 
     if (!command.length()) return false;
     Parser parser(command);
@@ -355,10 +357,10 @@ bool MainWidget::executeCommand(const QString &command)
 //***************************************************************************
 void MainWidget::refreshChannelControls()
 {
-    ASSERT(frmChannelControls);
+    Q_ASSERT(frmChannelControls);
     if (!frmChannelControls) return;
 
-    ASSERT(frmChannelControls);
+    Q_ASSERT(frmChannelControls);
     if (!frmChannelControls) return;
 
     unsigned int channels = tracks();
@@ -376,14 +378,14 @@ void MainWidget::refreshChannelControls()
 	m_scrollbar->show();
 	w -= b;
 	scrollbar_visible = true;
-	debug(" - scrollbar shown");
+	qDebug(" - scrollbar shown");
     } else if (!need_scrollbar && scrollbar_visible) {
 	// -- hide the scrollbar --
 	m_scrollbar->hide();
 	m_scrollbar->setFixedWidth(0);
 	w += b;
 	scrollbar_visible = false;
-	debug(" - scrollbar hidden");
+	qDebug(" - scrollbar hidden");
     }
 
     if (scrollbar_visible) {
@@ -395,7 +397,7 @@ void MainWidget::refreshChannelControls()
 	min = 0;
 	max = h-m_signal_frame.height();
 	m_scrollbar->setRange(min, max);
-	m_scrollbar->setValue(floor(val * (double)max));
+	m_scrollbar->setValue((int)floor(val * (double)max));
 	m_scrollbar->setSteps(1, m_signal_frame.height());
     }
 
@@ -411,8 +413,8 @@ void MainWidget::refreshChannelControls()
 
     // move the existing lamps and speakers to their new position
     for (unsigned int i = 0; (i < m_last_tracks) && (i < channels); i++) {
-	ASSERT(m_lamps.at(i));
-//	ASSERT(m_speakers.at(i));
+	Q_ASSERT(m_lamps.at(i));
+//	Q_ASSERT(m_speakers.at(i));
 	if (!m_lamps.at(i)) continue;
 //	if (!m_speakers.at(i)) continue;
 
@@ -431,11 +433,11 @@ void MainWidget::refreshChannelControls()
     for (unsigned int i = m_last_tracks; i < channels; i++) {
 	int s[3];
 	MultiStateWidget *msw = new MultiStateWidget(frmChannelControls, i);
-	ASSERT(msw);
+	Q_ASSERT(msw);
 	if (!msw) continue;
 
 	m_lamps.append(msw);
-	ASSERT(m_lamps.at(i));
+	Q_ASSERT(m_lamps.at(i));
 	if (!m_lamps.at(i)) continue;
 	s[0] = m_lamps.at(i)->addPixmap("light_on.xpm");
 	s[1] = m_lamps.at(i)->addPixmap("light_off.xpm");
@@ -446,10 +448,10 @@ void MainWidget::refreshChannelControls()
 	m_lamps.at(i)->setStates(s);
 
 //        msw = new MultiStateWidget(frmChannelControls, 0, 3);
-//        ASSERT(msw);
+//        Q_ASSERT(msw);
 //        if (!msw) continue;
 //	m_speakers.append(msw);
-//	ASSERT(m_speakers.at(i));
+//	Q_ASSERT(m_speakers.at(i));
 //	if (!m_speakers.at(i)) continue;
 //	s[0] = m_speakers.at(i)->addPixmap("rspeaker.xpm");
 //	s[1] = m_speakers.at(i)->addPixmap("lspeaker.xpm");
@@ -466,8 +468,8 @@ void MainWidget::refreshChannelControls()
 
     // set the updated identifiers of the widgets
     for (unsigned int i = 0; i < channels; i++) {
-	ASSERT(m_lamps.at(i));
-//	ASSERT(m_speakers.at(i));
+	Q_ASSERT(m_lamps.at(i));
+//	Q_ASSERT(m_speakers.at(i));
 	if (!m_lamps.at(i)) continue;
 //	if (!m_speakers.at(i)) continue;
 
@@ -484,12 +486,6 @@ unsigned int MainWidget::tracks()
     return m_signal_widget.tracks();
 }
 
-//***************************************************************************
-unsigned int MainWidget::bits()
-{
-    return m_signal_widget.bits();
-}
-
 //***************************************************************************
 SignalManager &MainWidget::signalManager()
 {
