@@ -181,7 +181,7 @@ size_t MemoryManager::virtualUsed()
     size_t used = 0;
     QMap<void*,SwapFile*>::Iterator it;
     for (it=m_swap_files.begin(); it != m_swap_files.end(); ++it) {
-	ASSERT(it.data());
+	Q_ASSERT(it.data());
 	if (it.data()) used += (it.data()->size() >> 10) + 1;
     }
     return (used >> 10);
@@ -224,7 +224,7 @@ void *MemoryManager::allocateVirtual(size_t size)
 
     // try to allocate
     SwapFile *swap = new SwapFile();
-    ASSERT(swap);
+    Q_ASSERT(swap);
     if (!swap) return 0;
 
     void *block = swap->allocate(size, nextSwapFileName());
@@ -239,31 +239,59 @@ void *MemoryManager::allocateVirtual(size_t size)
     return 0;
 }
 
+//***************************************************************************
+void *MemoryManager::convertToVirtual(void *block, size_t old_size,
+                                      size_t new_size)
+{
+    size_t current_size = m_physical_size[block];
+    Q_ASSERT(current_size);
+    void *new_block = allocateVirtual(new_size);
+    if (!new_block) return 0;
+
+    // copy old stuff to new location
+    ::memcpy(new_block, block, old_size);
+
+    // remove old memory
+    m_physical_size[block] = 0;
+    void *b = block;
+    ::free(b);
+    m_physical_size.remove(block);
+
+    return new_block;
+}
+
 //***************************************************************************
 void *MemoryManager::resize(void *block, size_t size)
 {
     MutexGuard lock(m_lock);
 
     if (m_physical_size.contains(block)) {
+	// if we are increasing: check if we get too large
+	size_t current_size = m_physical_size[block];
+	if ((size > current_size) && (physicalUsed() +
+	    ((size - current_size) >> 20) > m_physical_limit))
+	{
+	    // too large -> move to virtual memory
+	    qDebug("MemoryManager::resize(%uMB) -> moving to swap", size>>20);
+	    return convertToVirtual(block, current_size, size);
+	}
+    
 	// try to resize the physical memory
 	void *new_block = ::realloc(block, size);
 	if (new_block) {
 	    m_physical_size.remove(block);
 	    m_physical_size.insert(new_block, size);
 	    return new_block;
+	} else {
+	    // resizing failed, try to allocate virtual memory for it
+	    return convertToVirtual(block, current_size, size);
 	}
-	
-	// resizing failed, try to allocate virtual memory for it
-	/**
-	 * @todo try to allocate virtual memory and copy
-	 * if resizing physical failed
-	 */
     }
 
     if (m_swap_files.contains(block)) {
 	// resize the pagefile
 	SwapFile *swap = m_swap_files[block];
-	ASSERT(swap);
+	Q_ASSERT(swap);
 	if (!swap) return 0;
 	
 	void *new_block = swap->resize(size);
@@ -287,7 +315,7 @@ void MemoryManager::free(void *&block)
     if (m_swap_files.contains(block)) {
 	// remove the pagefile
 	SwapFile *swap = m_swap_files[block];
-	ASSERT(swap);
+	Q_ASSERT(swap);
 	if (swap) {
 	    m_swap_files[block] = 0;
 	    delete swap;
@@ -298,7 +326,7 @@ void MemoryManager::free(void *&block)
     if (m_physical_size.contains(block)) {
 	// physical memory
 	void *b = block;
-	ASSERT(b);
+	Q_ASSERT(b);
 	m_physical_size[block] = 0;
 	if (b) ::free(b);
 	m_physical_size.remove(block);
