@@ -28,23 +28,23 @@
 #include <kmessagebox.h>
 #include <klocale.h>
 
+#include "mt/SignalProxy.h"
 #include "mt/TSS_Object.h"
 #include "mt/ThreadCondition.h"
-#include "mt/ThreadsafeX11Guard.h"
 
-#include "libkwave/Parser.h"
+#include "libkwave/ArtsMultiPlaybackSink.h"
 #include "libkwave/LineParser.h"
 #include "libkwave/FileLoader.h"
+#include "libkwave/KwavePlugin.h"
 #include "libkwave/MultiTrackReader.h"
 #include "libkwave/MultiTrackWriter.h"
+#include "libkwave/Parser.h"
+#include "libkwave/PlayBackDevice.h"
+#include "libkwave/PlaybackDeviceFactory.h"
+#include "libkwave/PluginContext.h"
 #include "libkwave/SampleReader.h"
 #include "libkwave/SampleWriter.h"
 
-#include "mt/SignalProxy.h"
-
-#include "libgui/KwavePlugin.h"
-#include "libgui/PluginContext.h"
-
 #include "KwaveApp.h"
 #include "TopWidget.h"
 #include "SignalManager.h"
@@ -54,51 +54,55 @@
 
 #include "PluginManager.h"
 
+//***************************************************************************
+//***************************************************************************
+PluginManager::PluginDeleter::PluginDeleter(KwavePlugin *plugin, void *handle)
+  :QObject(), m_plugin(plugin), m_handle(handle)
+{
+}
+
+//***************************************************************************
+PluginManager::PluginDeleter::~PluginDeleter()
+{
+    // delete the plugin, this should also remove everything it has allocated
+    delete m_plugin;
+
+    // now the handle of the shared object can be cleared too
+    dlclose(m_handle);
+}
+
 //****************************************************************************
 //****************************************************************************
 
-//class PluginGarbageCollector: public Thread
-//{
-//public:
-//    virtual void run();
-//
-//slots:
-//    void remove(KwavePlugin *plugin);
-//
-//private:
-//    QQueue<Plugin> m_queue;
-//    SignalProxy1<KwavePlugin *> m_spx_plugin;
-//}
-//
-//void PluginGarbageCollector::run()
-//{
-//    KwavePlugin *plugin;
-//    do {
-//	plugin = m_spx_plugin.dequeue();
-//	if (!plugin) {
-//	    // dequeued a null plugin -> signal to shut down
-//	    debug("PluginGarbageCollector: shutting down...");
-//	    break;
-//	}
-//	
-//	// wait until the plugin's thread is down
-//	
-//	// delete the plugin
-//	
-//	// remove it's handle
-//	
-//    } while (plugin);
-//}
-
-// static initializer
+// static initializers
 QMap<QString, QString> PluginManager::m_plugin_files;
+QPtrList<KwavePlugin> PluginManager::m_unique_plugins;
+static QPtrList<PlaybackDeviceFactory> m_playback_factories;
 
 //****************************************************************************
 PluginManager::PluginManager(TopWidget &parent)
     :m_spx_name_changed(this, SLOT(emitNameChanged())),
      m_spx_command(this, SLOT(forwardCommand())),
+     m_loaded_plugins(), m_running_plugins(),
      m_top_widget(parent)
 {
+    // use all unique plugins
+    // this does nothing on the first instance, all other instances
+    // will probably find a non-empty list
+    QPtrListIterator<KwavePlugin> itp(m_unique_plugins);
+    for ( ; itp.current(); ++itp ) {
+	KwavePlugin *p = itp.current();
+	Q_ASSERT(p && p->isUnique());
+	if (p && p->isUnique()) {
+	    p->use();
+
+	    // maybe we will become responsible for releasing
+	    // the plugin (when it is in use but the plugin manager
+	    // who has created it is already finished)
+	    connect(p,    SIGNAL(sigClosed(KwavePlugin *)),
+	            this, SLOT(pluginClosed(KwavePlugin *)));
+	}
+    }
 }
 
 //****************************************************************************
@@ -113,63 +117,93 @@ PluginManager::~PluginManager()
     // inform all plugins and client windows that we close now
     emit sigClosed();
 
-    // remove all remaining plugins
-    while (!m_loaded_plugins.isEmpty()) {
-	KwavePlugin *p = m_loaded_plugins.last();
-	if (p) {
-	    debug("PluginManager::~PluginManager(): closing plugin(%s)",
-	           p->name().data());
-	    pluginClosed(p, true);
-	} else {
-	    debug("PluginManager::~PluginManager(): removing null plugin");
-	    m_loaded_plugins.removeRef(p);
+    // release all unique plugins
+    QPtrListIterator<KwavePlugin> itu(m_unique_plugins);
+    for (itu.toLast() ; itu.current(); ) {
+	KwavePlugin *p = itu.current();
+	--itu;
+	Q_ASSERT(p && p->isUnique());
+	if (p && p->isUnique()) {
+	    p->release();
 	}
     }
+
+    // release all own persisiten plugins
+    QPtrListIterator<KwavePlugin> itp(m_loaded_plugins);
+    for (itp.toLast() ; itp.current(); ) {
+	KwavePlugin *p = itp.current();
+	--itp;
+	Q_ASSERT(p);
+	if (p && p->isPersistent()) p->release();
+    }
+
+    // release all own plugins that are left
+    QPtrListIterator<KwavePlugin> it(m_loaded_plugins);
+    for (it.toLast() ; it.current(); ) {
+	KwavePlugin *p = it.current();
+	--it;
+	Q_ASSERT(p);
+	if (p) p->release();
+    }
 }
 
 //***************************************************************************
 void PluginManager::loadAllPlugins()
 {
-    // try to load all plugins
-    // NOTE: this also makes it resident if it is persistent
+    // Try to load all plugins. This has to be called only once per
+    // instance of the main window!
+    // NOTE: this also implicitely makes it resident if it is persistent or unique
     QMap<QString, QString>::Iterator it;
     for (it=m_plugin_files.begin(); it != m_plugin_files.end(); ++it) {
 	QString name = it.key();
-	
+
 	KwavePlugin *plugin = loadPlugin(name);
 	if (plugin) {
-	    // remove it again if it is not persistent
-	    if (!plugin->isPersistent()) pluginClosed(plugin, true);
+// 	    QString state = "";
+// 	    if (plugin->isPersistent()) state += "(persistent)";
+// 	    if (plugin->isUnique()) state += "(unique)";
+// 	    if (!state.length()) state = "(normal)";
+// 	    qDebug("PluginManager::loadAllPlugins(): plugin '"+
+// 		   plugin->name()+"' "+state);
+	    if (!plugin->isUnique() && !plugin->isPersistent()) {
+		// remove it again if it is neither unique nor persistent
+		plugin->release();
+	    }
 	} else {
 	    // loading failed => remove it from the list
-	    warning("PluginManager::loadAllPlugins(): removing '%s' "\
-	            "from list", name.data());
+	    qWarning("PluginManager::loadAllPlugins(): removing '%s' "\
+	            "from list", name.latin1());
 	    m_plugin_files.remove(name);
 	}
     }
 }
 
-//**********************************************************
+//***************************************************************************/
 KwavePlugin *PluginManager::loadPlugin(const QString &name)
 {
-    // first find out if the plugin is already loaded AND persistent
-    // or unique
-    QListIterator<KwavePlugin> it(m_loaded_plugins);
+
+    // first find out if the plugin is already loaded and persistent
+    QPtrListIterator<KwavePlugin> itp(m_loaded_plugins);
+    for ( ; itp.current(); ++itp ) {
+	KwavePlugin *p = itp.current();
+	if (p->isPersistent() && (p->name() == name)) {
+	    Q_ASSERT(p->isPersistent());
+	    qDebug("PluginManager::loadPlugin('"+name+
+	           "') -> returning pointer to persistent");
+	    return p;
+	}
+    }
+
+    // find out if the plugin is already loaded and unique
+    QPtrListIterator<KwavePlugin> it(m_unique_plugins);
     for ( ; it.current(); ++it ) {
 	KwavePlugin *p = it.current();
 	if (p->name() == name) {
-	    if (p->isPersistent()) {
-		// persistent -> return reference only
-		debug("PluginManager::loadPlugin(): returning reference "\
-		      "to persistent plugin '%s'", name.data());
-		return p;
-	    }
-	    if (p->isUnique()) {
-		// prevent from re-loading of a unique plugin
-		warning("PluginManager::loadPlugin(): attempt to re-load "\
-		        "unique plugin '%s'", name.data());
-		return 0;
-	    }
+	    Q_ASSERT(p->isUnique());
+	    Q_ASSERT(p->isPersistent());
+	    qDebug("PluginManager::loadPlugin('"+name+
+	           "') -> returning pointer to unique+persistent");
+	    return p;
 	}
     }
 
@@ -197,37 +231,32 @@ KwavePlugin *PluginManager::loadPlugin(const QString &name)
     // get the loader function
     KwavePlugin *(*plugin_loader)(PluginContext *c) = 0;
 
-#ifdef HAVE_CPLUS_MANGLE_OPNAME
-    // would be fine, but needs libiberty
-    const char *sym_version = cplus_mangle_opname("const char *", 0);
-    const char *sym_author  = cplus_mangle_opname("author", 0);
-    const char *sym_loader  = cplus_mangle_opname("load(PluginContext *)",0);
-#else
-    // hardcoded, might fail on some systems :-(
+    // hardcoded, should always work when the
+    // symbols are declared as extern "C"
     const char *sym_version = "version";
     const char *sym_author  = "author";
-    const char *sym_loader  = "load__FR13PluginContext";
-#endif
+    const char *sym_loader  = "load";
 
     // get the plugin's author
     const char *author = "";
     const char **pauthor = (const char **)dlsym(handle, sym_author);
-    ASSERT(pauthor);
+    Q_ASSERT(pauthor);
     if (pauthor) author=*pauthor;
     if (!author) author = i18n("(unknown)");
 
     // get the plugin's version string
     const char *version = "";
     const char **pver = (const char **)dlsym(handle, sym_version);
-    ASSERT(pver);
+    Q_ASSERT(pver);
     if (pver) version=*pver;
     if (!version) version = i18n("(unknown)");
 
-    plugin_loader = (KwavePlugin *(*)(PluginContext *))dlsym(handle, sym_loader);
-    ASSERT(plugin_loader);
+    plugin_loader =
+        (KwavePlugin *(*)(PluginContext *))dlsym(handle, sym_loader);
+    Q_ASSERT(plugin_loader);
     if (!plugin_loader) {
 	// plugin is null, out of memory or not found
-	warning("PluginManager::loadPlugin(): "\
+	qWarning("PluginManager::loadPlugin('"+name+"'): "\
 		"plugin does not contain a loader, "\
 		"maybe it is damaged or the wrong version?");
 	dlclose(handle);
@@ -246,26 +275,37 @@ KwavePlugin *PluginManager::loadPlugin(const QString &name)
 	author
     );
 
-    ASSERT(context);
+    Q_ASSERT(context);
     if (!context) {
-	warning("PluginManager::loadPlugin(): out of memory");
+	qWarning("PluginManager::loadPlugin('"+name+"'): out of memory");
 	dlclose(handle);
 	return 0;
     }
 
     // call the loader function to create an instance
     KwavePlugin *plugin = (*plugin_loader)(context);
-    ASSERT(plugin);
+    Q_ASSERT(plugin);
     if (!plugin) {
-	warning("PluginManager::loadPlugin(): out of memory");
+	qWarning("PluginManager::loadPlugin('"+name+"'): out of memory");
 	dlclose(handle);
 	return 0;
     }
 
-    // append the plugin into our list of plugins
-    m_loaded_plugins.append(plugin);
+    if (plugin->isUnique()) {
+	// append unique plugins to the global list of unique plugins
+	m_unique_plugins.append(plugin);
+	plugin->use();
+    } else {
+	// append the plugin into our list of loaded plugins
+	m_loaded_plugins.append(plugin);
+	if (plugin->isPersistent()) {
+	    // increment the usage if it is persistent, we will
+	    // only load it once in this instance
+	    plugin->use();
+	}
+    }
 
-    // connect all signals
+    // connect all necessary signals/slots
     connectPlugin(plugin);
 
     // get the last settings and call the "load" function
@@ -282,7 +322,10 @@ int PluginManager::executePlugin(const QString &name, QStringList *params)
     QString command;
     int result = 0;
 
-    // load the plugin
+    // synchronize: wait until any currently running plugins are done
+    sync();
+
+    // load the new plugin
     KwavePlugin *plugin = loadPlugin(name);
     if (!plugin) return -ENOMEM;
 
@@ -290,25 +333,22 @@ int PluginManager::executePlugin(const QString &name, QStringList *params)
 	// parameters were specified -> call directly
 	// without setup dialog
 	result = plugin->start(*params);
-	
+
 	// maybe the start() function has called close() ?
 	if (m_loaded_plugins.findRef(plugin) == -1) {
-	    debug("PluginManager: plugin closed itself in start()"); // ###
+	    qDebug("PluginManager: plugin closed itself in start()"); // ###
 	    result = -1;
 	    plugin = 0;
 	}
-	
+
 	if (plugin && (result >= 0)) {
+	    plugin->use(); // plugin->release() will be called after run()
 	    plugin->execute(*params);
-	
-	    // now it's the the task of the plugin's thread
-	    // to clean up after execution
-	    plugin = 0;
 	}
     } else {
 	// load previous parameters from config
 	QStringList last_params = loadPluginDefaults(name, plugin->version());
-	
+
 	// call the plugin's setup function
 	params = plugin->setup(last_params);
 	if (params) {
@@ -316,10 +356,10 @@ int PluginManager::executePlugin(const QString &name, QStringList *params)
 	    // the setup function has not been aborted.
 	    // Now we can create a command string and
 	    // emit a new command.
-	
+
 	    // store parameters for the next time
 	    savePluginDefaults(name, plugin->version(), *params);
-	
+
 	    // We DO NOT call the plugin's "execute"
 	    // function directly, as it should be possible
 	    // to record all function calls in the
@@ -332,13 +372,13 @@ int PluginManager::executePlugin(const QString &name, QStringList *params)
 	    }
 	    delete params;
 	    command += ")";
-	    debug("PluginManager: command='%s'",command.data()); // ###
+	    qDebug("PluginManager: command='%s'",command.latin1()); // ###
 	}
     }
 
     // now the plugin is no longer needed here, so delete it
     // if it has not already been detached
-    if (plugin && !plugin->isPersistent()) pluginClosed(plugin, true);
+    if (plugin && !plugin->isPersistent()) plugin->release();
 
     // emit a command, let the toplevel window (and macro recorder) get
     // it and call us again later...
@@ -352,20 +392,22 @@ void PluginManager::sync()
 {
     bool one_is_running = true;
     while (one_is_running) {
-	{
-//	    MutexGuard lock_list(m_lock_plugin_list);
-	    QListIterator<KwavePlugin> it(m_loaded_plugins);
-	    one_is_running = false;
-	    for (; it.current(); ++it) {
-		KwavePlugin *plugin = it.current();
-		if (plugin->isRunning()) {
-		    debug("waiting for plugin '%s'", plugin->name().data());
-		    one_is_running = true;
-		    break;
-		}
+	QPtrListIterator<KwavePlugin> it(m_loaded_plugins);
+	one_is_running = false;
+
+	for (; it.current(); ++it) {
+	    KwavePlugin *plugin = it.current();
+	    if (plugin->isRunning()) {
+		qDebug("waiting for plugin '%s'", plugin->name().latin1());
+		one_is_running = true;
+		break;
 	    }
 	}
-	if (one_is_running) qApp->processEvents();
+
+	if (one_is_running) {
+	    qApp->processEvents();
+	    sleep(1000);
+	}
     }
 }
 
@@ -390,11 +432,17 @@ int PluginManager::setupPlugin(const QString &name)
 
     // now the plugin is no longer needed here, so delete it
     // if it has not already been detached and is not persistent
-    if (!plugin->isPersistent()) pluginClosed(plugin, true);
+    if (!plugin->isPersistent()) plugin->release();
 
     return 0;
 }
 
+//***************************************************************************
+FileInfo &PluginManager::fileInfo()
+{
+    return m_top_widget.signalManager().fileInfo();
+}
+
 //***************************************************************************
 QStringList PluginManager::loadPluginDefaults(const QString &name,
 	const QString &version)
@@ -405,7 +453,7 @@ QStringList PluginManager::loadPluginDefaults(const QString &name,
     section += name;
 
     KConfig *cfg = KGlobal::config();
-    ASSERT(cfg);
+    Q_ASSERT(cfg);
     if (!cfg) return list;
 
     cfg->sync();
@@ -416,10 +464,10 @@ QStringList PluginManager::loadPluginDefaults(const QString &name,
 	return list;
     }
     if (!(def_version == version)) {
-	debug("PluginManager::loadPluginDefaults: "\
+	qDebug("PluginManager::loadPluginDefaults: "\
 	    "plugin '%s': defaults for version '%s' not loaded, found "\
-	    "old ones of version '%s'.", name.data(), version.data(),
-	    def_version.data());
+	    "old ones of version '%s'.", name.latin1(), version.latin1(),
+	    def_version.latin1());
 	return list;
     }
 
@@ -432,12 +480,11 @@ void PluginManager::savePluginDefaults(const QString &name,
                                        const QString &version,
                                        QStringList &params)
 {
-    QString def_version;
     QString section("plugin ");
     section += name;
 
     KConfig *cfg = KGlobal::config();
-    ASSERT(cfg);
+    Q_ASSERT(cfg);
     if (!cfg) return;
 
     cfg->sync();
@@ -454,13 +501,13 @@ unsigned int PluginManager::signalLength()
 }
 
 //***************************************************************************
-unsigned int PluginManager::signalRate()
+double PluginManager::signalRate()
 {
     return m_top_widget.signalManager().rate();
 }
 
 //***************************************************************************
-const QArray<unsigned int> PluginManager::selectedTracks()
+const QMemArray<unsigned int> PluginManager::selectedTracks()
 {
     return m_top_widget.signalManager().selectedTracks();
 }
@@ -493,7 +540,7 @@ SampleWriter *PluginManager::openSampleWriter(unsigned int track,
 
 //***************************************************************************
 void PluginManager::openMultiTrackReader(MultiTrackReader &readers,
-    const QArray<unsigned int> &track_list,
+    const QMemArray<unsigned int> &track_list,
     unsigned int first, unsigned int last)
 {
     SignalManager &manager = m_top_widget.signalManager();
@@ -502,7 +549,7 @@ void PluginManager::openMultiTrackReader(MultiTrackReader &readers,
 
 //***************************************************************************
 void PluginManager::openMultiTrackWriter(MultiTrackWriter &writers,
-    const QArray<unsigned int> &track_list, InsertMode mode,
+    const QMemArray<unsigned int> &track_list, InsertMode mode,
     unsigned int left, unsigned int right)
 {
     SignalManager &manager = m_top_widget.signalManager();
@@ -514,17 +561,59 @@ void PluginManager::openMultiTrackWriter(MultiTrackWriter &writers,
                                          InsertMode mode)
 {
     SignalManager &manager = m_top_widget.signalManager();
-    QArray<unsigned int> tracks = manager.selectedTracks();
-    unsigned int left  = selectionStart();
-    unsigned int right = selectionEnd();
-    if (left == right) {
-	left = 0;
-	right = signalLength()-1;
+    QMemArray<unsigned int> tracks = manager.selectedTracks();
+    unsigned int left = 0;
+    unsigned int right = 0;
+
+    if (signalLength()) {
+	// default if signal is present: current selection
+	left  = selectionStart();
+	right = selectionEnd();
+	if (left == right) {
+	    // if no selection: whole signal
+	    left  = 0;
+	    right = signalLength();
+	}
     }
 
     openMultiTrackWriter(writers, tracks, mode, left, right);
 }
 
+//***************************************************************************
+ArtsMultiSink *PluginManager::openMultiTrackPlayback(unsigned int tracks,
+                                                     const QString *name)
+{
+    QString device_name;
+
+    // locate the corresponding playback device factory (plugin)
+    device_name = (name) ? QString(*name) : QString("");
+    PlayBackDevice *device = 0;
+    PlaybackDeviceFactory *factory = 0;
+    QPtrListIterator<PlaybackDeviceFactory> it(m_playback_factories);
+    for (; it.current(); ++it) {
+	PlaybackDeviceFactory *f = it.current();
+	Q_ASSERT(f);
+	if (f && f->supportsDevice(device_name)) {
+	    factory = f;
+	    break;
+	}
+    }
+    Q_ASSERT(factory);
+    if (!factory) return 0;
+
+    // open the playback device with it's default parameters
+    device = factory->openDevice(device_name, 0);
+    Q_ASSERT(device);
+    if (!device) return 0;
+
+    // create the multi track playback sink
+    ArtsMultiSink *sink = new ArtsMultiPlaybackSink(tracks, device);
+    Q_ASSERT(sink);
+    if (!sink) return 0;
+
+    return sink;
+}
+
 //***************************************************************************
 PlaybackController &PluginManager::playbackController()
 {
@@ -548,64 +637,109 @@ void PluginManager::forwardCommand()
 }
 
 //***************************************************************************
-void PluginManager::pluginClosed(KwavePlugin *p, bool remove)
+void PluginManager::pluginClosed(KwavePlugin *p)
 {
-    ASSERT(p);
-    ASSERT(!m_loaded_plugins.isEmpty());
+    Q_ASSERT(p);
+    Q_ASSERT(!m_loaded_plugins.isEmpty() || !m_unique_plugins.isEmpty());
+    if (!p) return;
 
-    if (p) {
-//	void *h = p->handle();
-	
-	// disconnect the signals to avoid recursion
-	disconnectPlugin(p);
+    // disconnect the signals to avoid recursion
+    disconnectPlugin(p);
 
+    if (m_loaded_plugins.findRef(p) != -1) {
 	m_loaded_plugins.setAutoDelete(false);
 	m_loaded_plugins.removeRef(p);
-
-	if (remove) {
-//	    debug("PluginManager::pluginClosed(%p): deleting",p);
-	    delete p;
-//	    if (h) dlclose(h);
-	}
-
+    }
+    if (m_unique_plugins.findRef(p) != -1) {
+	m_unique_plugins.setAutoDelete(false);
+	m_unique_plugins.removeRef(p);
     }
 
-//    debug("PluginManager::pluginClosed(): done");
+    // schedule the deferred delete/unload of the plugin
+    void *handle = p->handle();
+    Q_ASSERT(handle);
+    PluginDeleter *delete_later = new PluginDeleter(p, handle);
+    Q_ASSERT(delete_later);
+    if (delete_later) delete_later->deleteLater();
+
+//    qDebug("PluginManager::pluginClosed(): done");
+}
+
+//***************************************************************************
+void PluginManager::pluginStarted(KwavePlugin *p)
+{
+    Q_ASSERT(p);
+    if (!p) return;
+
+    // the plugin is running -> increase the usage count in order to
+    // prevent our lists from containing invalid entries
+    p->use();
+
+    // add the plugin to the list of running plugins
+    m_running_plugins.append(p);
+}
+
+//***************************************************************************
+void PluginManager::pluginDone(KwavePlugin *p)
+{
+    Q_ASSERT(p);
+    if (!p) return;
+
+    // remove the plugin from the list of running plugins
+    m_running_plugins.setAutoDelete(false);
+    m_running_plugins.removeRef(p);
+
+    // release the plugin, at least we do no longer need it
+    p->release();
 }
 
 //****************************************************************************
 void PluginManager::connectPlugin(KwavePlugin *plugin)
 {
-    ASSERT(plugin);
+    Q_ASSERT(plugin);
     if (!plugin) return;
 
-    connect(this, SIGNAL(sigClosed()),
-	    plugin, SLOT(close()));
+    if (!plugin->isUnique()) {
+	connect(this, SIGNAL(sigClosed()),
+	        plugin, SLOT(close()));
+    }
 
-    connect(plugin, SIGNAL(sigClosed(KwavePlugin *,bool)),
-	    this, SLOT(pluginClosed(KwavePlugin *,bool)));
+    connect(plugin, SIGNAL(sigClosed(KwavePlugin *)),
+	    this, SLOT(pluginClosed(KwavePlugin *)));
 
+    connect(plugin, SIGNAL(sigRunning(KwavePlugin *)),
+	    this, SLOT(pluginStarted(KwavePlugin *)));
+
+    connect(plugin, SIGNAL(sigDone(KwavePlugin *)),
+	    this, SLOT(pluginDone(KwavePlugin *)));
 }
 
 //****************************************************************************
 void PluginManager::disconnectPlugin(KwavePlugin *plugin)
 {
-    ASSERT(plugin);
+    Q_ASSERT(plugin);
     if (!plugin) return;
 
+    disconnect(plugin, SIGNAL(sigDone(KwavePlugin *)),
+	       this, SLOT(pluginDone(KwavePlugin *)));
+
+    disconnect(plugin, SIGNAL(sigRunning(KwavePlugin *)),
+	       this, SLOT(pluginStarted(KwavePlugin *)));
+
     disconnect(this, SIGNAL(sigClosed()),
 	       plugin, SLOT(close()));
 
-    disconnect(plugin, SIGNAL(sigClosed(KwavePlugin *,bool)),
-	       this, SLOT(pluginClosed(KwavePlugin *,bool)));
-
+    if (!plugin->isUnique()) {
+	disconnect(plugin, SIGNAL(sigClosed(KwavePlugin *)),
+	           this, SLOT(pluginClosed(KwavePlugin *)));
+    }
 }
 
 //****************************************************************************
 void PluginManager::emitNameChanged()
 {
     const QString *name = m_spx_name_changed.dequeue();
-    ASSERT(name);
+    Q_ASSERT(name);
     if (name) {
 	emit sigSignalNameChanged(*name);
 	delete name;
@@ -627,31 +761,44 @@ void PluginManager::findPlugins()
     QStringList::Iterator it;
     for (it=files.begin(); it != files.end(); ++it) {
 	QString file = *it;
-	
+
 	void *handle = dlopen(file, RTLD_NOW);
 	if (handle) {
 	    const char **name    = (const char **)dlsym(handle, "name");
 	    const char **version = (const char **)dlsym(handle, "version");
 	    const char **author  = (const char **)dlsym(handle, "author");
-	
+
 	    // skip it if something is missing or null
 	    if (!name || !version || !author) continue;
 	    if (!*name || !*version || !*author) continue;
-	
+
 	    m_plugin_files.insert(*name, file);
-	    printf("%16s %5s written by %s", *name, *version, *author);
-	
+	    qDebug(i18n("%16s %5s written by %s"), *name, *version, *author);
+
 	    dlclose (handle);
-	
 	} else {
-	    printf("error in '%s':\n\t %s\n", file.data(),
+	    qWarning(i18n("error in '%s':\n\t %s"), file.latin1(),
 		dlerror());
 	}
-	
-	printf("\n");
     }
 
-    printf("--- \n found %d plugins\n", m_plugin_files.count());
+    qDebug(i18n("--- \n found %d plugins\n"), m_plugin_files.count());
+}
+
+//****************************************************************************
+void PluginManager::registerPlaybackDeviceFactory(
+    PlaybackDeviceFactory *factory)
+{
+    m_playback_factories.append(factory);
+
+}
+
+//****************************************************************************
+void PluginManager::unregisterPlaybackDeviceFactory(
+    PlaybackDeviceFactory *factory)
+{
+    m_playback_factories.setAutoDelete(false);
+    m_playback_factories.removeRef(factory);
 }
 
 //****************************************************************************
