@@ -23,7 +23,8 @@
 
 #include <qbitmap.h>
 #include <qfile.h>
-#include <qlist.h>
+#include <qfileinfo.h>
+#include <qptrlist.h>
 #include <qpainter.h>
 #include <qstring.h>
 #include <qtimer.h>
@@ -59,6 +60,7 @@
 #include "UndoAction.h"
 #include "UndoDeleteAction.h"
 #include "UndoDeleteTrack.h"
+#include "UndoFileInfo.h"
 #include "UndoInsertAction.h"
 #include "UndoInsertTrack.h"
 #include "UndoModifyAction.h"
@@ -66,10 +68,6 @@
 #include "UndoTransaction.h"
 #include "UndoTransactionGuard.h"
 
-#if __BYTE_ORDER==__BIG_ENDIAN
-#define IS_BIG_ENDIAN
-#endif
-
 #define min(x,y) (((x)<(y)) ? (x) : (y))
 #define max(x,y) (((x)>(y)) ? (x) : (y))
 
@@ -95,8 +93,9 @@ SignalManager::SignalManager(QWidget *parent)
     m_undo_transaction_level(0),
     m_undo_transaction_lock(),
     m_spx_undo_redo(this, SLOT(emitUndoRedoInfo())),
-    m_undo_limit(64*1024*1024) // 64 MB (for testing) ###
+    m_undo_limit(64*1024*1024), // 64 MB (for testing) ###
     /** @todo the undo memory limit should be user-configurable. */
+    m_file_info()
 {
     // connect to the track's signals
     Signal *sig = &m_signal;
@@ -122,6 +121,7 @@ SignalManager::SignalManager(QWidget *parent)
 int SignalManager::loadFile(const KURL &url)
 {
     int res = 0;
+    FileProgress *dialog = 0;
     m_name = url.filename();
 
     // enter and stay in not modified state
@@ -133,8 +133,8 @@ int SignalManager::loadFile(const KURL &url)
     disableUndo();
 
     QString mimetype = CodecManager::whatContains(url);
-    debug("SignalManager::loadFile(%s) - [%s]", url.prettyURL().data(),
-          mimetype.data());
+    qDebug("SignalManager::loadFile(%s) - [%s]", url.prettyURL().latin1(),
+          mimetype.latin1());
     Decoder *decoder = CodecManager::decoder(mimetype);
     while (decoder) {
 	// be sure that the current signal is really closed
@@ -143,32 +143,38 @@ int SignalManager::loadFile(const KURL &url)
 	// open the source file
 	QString filename = url.path();
 	QFile src(filename);
-	if (!decoder->open(m_parent_widget, src)) {
-	    warning("unable to open source: '%s'", url.prettyURL().data());
-	    res = -EIO;
+	if (!(res = decoder->open(m_parent_widget, src))) {
+	    qWarning("unable to open source: '%s'", url.prettyURL().latin1());
 	    break;
 	}
 	
+	// enter the filename/mimetype and size into the decoder
+	QFileInfo fi(src);
+	decoder->info().set(INF_FILENAME, fi.absFilePath());
+	decoder->info().set(INF_FILESIZE, (unsigned int)src.size());
+	decoder->info().set(INF_MIMETYPE, mimetype);
+	
+	// get the file info from the decoder
+	m_file_info = decoder->info();
+	
+	// detect stream mode. if so, use one sample as display
+	bool streaming = (!m_file_info.length());
+	
 	// we must change to open state to see the file while
 	// it is loaded
 	m_closed = false;
 	m_empty = false;
 	
-	// set rate and resolution of the signal
-	m_signal.setRate((int)rint(decoder->info().rate()));
-	m_signal.setBits(decoder->info().bits());
-	
 	// create all tracks (empty)
 	unsigned int track;
 	const unsigned int tracks = decoder->info().tracks();
 	const unsigned int length = decoder->info().length();
-	ASSERT(tracks);
-	ASSERT(length);
+	Q_ASSERT(tracks);
 	for (track=0; track < tracks; ++track) {
 	    Track *t = m_signal.appendTrack(length);
-	    ASSERT(t);
-	    if (!t || t->length() != length) {
-		warning("out of memory");
+	    Q_ASSERT(t);
+	    if (!t || (t->length() != length)) {
+		qWarning("out of memory");
 		res = -ENOMEM;
 		break;
 	    }
@@ -177,36 +183,77 @@ int SignalManager::loadFile(const KURL &url)
 	
 	// create the multitrack writer as destination
 	MultiTrackWriter writers;
-	openMultiTrackWriter(writers, allTracks(), Overwrite, 0, length-1);
+
+	// if length was zero -> append mode / decode a stream ?
+	InsertMode mode = (streaming) ? Append : Overwrite;
+	openMultiTrackWriter(writers, allTracks(), mode, 0,
+	    (length) ? length-1 : 0);
+
+	// try to calculate the resulting length, but if this is
+	// not possible, we try to use the source length instead
+	FileInfo &info = decoder->info();
+	unsigned int resulting_size = info.tracks() * info.length() *
+	                              (info.bits() >> 3);
+	bool use_src_size = (!resulting_size);
+	if (use_src_size) resulting_size = src.size();
 	
 	//prepare and show the progress dialog
-	FileInfo &info = decoder->info();
-	FileProgress *dialog = new FileProgress(m_parent_widget,
-	    filename, info.tracks()*info.length(), info.length(),
-	    info.rate(), info.bits(), info.tracks());
-	ASSERT(dialog);
-	QObject::connect(&writers, SIGNAL(progress(unsigned int)),
-	                 dialog, SLOT(setValue(unsigned int)));
+	dialog = new FileProgress(m_parent_widget,
+	    filename, resulting_size,
+	    info.length(), info.rate(), info.bits(), info.tracks());
+	Q_ASSERT(dialog);
+	if (use_src_size) {
+	    // use source size for progress / stream mode
+	    QObject::connect(decoder, SIGNAL(sourceProcessed(unsigned int)),
+	                     dialog, SLOT(setBytePosition(unsigned int)));
+	    QObject::connect(&writers, SIGNAL(progress(unsigned int)),
+	                     dialog, SLOT(setLength(unsigned int)));
+	} else {
+	    // use resulting size for progress
+	    QObject::connect(&writers, SIGNAL(progress(unsigned int)),
+	                     dialog, SLOT(setValue(unsigned int)));
+	}
 	QObject::connect(dialog, SIGNAL(cancelled()),
 	                 &writers, SLOT(cancel()));
 	
 	// now decode
 	res = 0;
 	if (!decoder->decode(m_parent_widget, writers)) {
-	    warning("decoding failed.");
+	    qWarning("decoding failed.");
 	    res = -EIO;
+	} else {
+	    // read information back from the decoder, some settings
+	    // might have become available during the decoding process
+	    m_file_info = decoder->info();
+	    m_file_info.dump();
 	}
+	
 	decoder->close();
-	if (dialog) delete dialog;
+	
+	// check for length info in stream mode
+	if (!res && streaming) {
+	    // source was opened in stream mode -> now we have the length
+	    writers.flush();
+	    unsigned int new_length = writers.last();
+	    if (new_length) new_length++;
+	    m_file_info.setLength(new_length);
+	}
+	
+	// update the length info in the progress dialog if needed
+	if (dialog && use_src_size) {
+	    dialog->setLength(m_file_info.length() * m_file_info.tracks());
+	    dialog->setBytePosition(src.size());
+	}
 	
 	emitStatusInfo();
 	break;
     }
     if (!decoder) {
-	warning("unknown file type");
+	qWarning("unknown file type");
 	res = -EMEDIUMTYPE;
+    } else {
+	delete decoder;
     }
-    if (decoder) delete decoder;
 
     // remember the last length
     m_last_length = length();
@@ -217,17 +264,20 @@ int SignalManager::loadFile(const KURL &url)
     // modified can change from now on
     enableModifiedChange(true);
 
+    if (dialog) delete dialog;
     if (res) close();
+    
     return res;
 }
 
 //***************************************************************************
-int SignalManager::save(const KURL &url, unsigned int bits, bool selection)
+int SignalManager::save(const KURL &url, bool selection)
 {
     int res = 0;
     unsigned int ofs = 0;
     unsigned int len = length();
     unsigned int tracks = this->tracks();
+    unsigned int bits = this->bits();
 
     if (selection) {
 	// zero-length -> nothing to do
@@ -243,12 +293,43 @@ int SignalManager::save(const KURL &url, unsigned int bits, bool selection)
     }
 
     QString mimetype_name;
-    mimetype_name = KMimeType::findByURL(url)->name();
-    debug("SignalManager::save(%s) - [%s] (%d bit, selection=%d)",
-	url.prettyURL().data(), mimetype_name.data(), bits, selection);
+    mimetype_name = CodecManager::whatContains(url);
+    qDebug("SignalManager::save(%s) - [%s] (%d bit, selection=%d)",
+	url.prettyURL().latin1(), mimetype_name.latin1(), bits, selection);
 
     Encoder *encoder = CodecManager::encoder(mimetype_name);
     if (encoder) {
+	// maybe we now have a new mime type
+	m_file_info.set(INF_MIMETYPE, mimetype_name);
+    
+	// check if we loose information and as the user if this would
+	// be acceptable if so
+	QValueList<FileProperty> supported = encoder->supportedProperties();
+	QMap<FileProperty, QVariant> properties(m_file_info.properties());
+	bool all_supported = true;
+	QMap<FileProperty, QVariant>::Iterator it;
+	QString lost_properties;
+	for (it=properties.begin(); it!=properties.end(); ++it) {
+	    if ( (! supported.contains(it.key())) &&
+                 (m_file_info.canLoadSave(it.key())) )
+	    {
+		qWarning("SignalManager::save(): unsupported property '%s'",
+		    m_file_info.name(it.key()).latin1());
+		all_supported = false;
+		lost_properties += m_file_info.name(it.key()) + "\n";
+	    }
+	}
+	if (!all_supported) {
+	    // show a warning to the user and ask him if he wants to continue
+	    if (KMessageBox::warningContinueCancel(m_parent_widget,
+		i18n("Saving in this format will loose the following "
+		     "additional file attribute(s):\n"
+		     "%1\n"
+		     "Do you still want to continue?").arg(
+		     lost_properties)
+		) != KMessageBox::Continue) return -1;
+	}
+
 	// open the destination file
 	QString filename = url.path();
 	QFile dst(filename);
@@ -260,27 +341,29 @@ int SignalManager::save(const KURL &url, unsigned int bits, bool selection)
 	    openMultiTrackReader(src, allTracks(), ofs, ofs+len-1);
 	}
 	
-	// create file information
-	FileInfo info;
-	info.setLength(len);
-	info.setRate(rate());
-	info.setBits(bits);
-	info.setTracks(tracks);
+	// update the file information
+	m_file_info.setLength(len);
+	m_file_info.setRate(rate());
+	m_file_info.setBits(bits);
+	m_file_info.setTracks(tracks);
+	m_file_info.set(INF_FILENAME, filename);
 	
 	//prepare and show the progress dialog
 	FileProgress *dialog = new FileProgress(m_parent_widget,
-	    filename, info.tracks()*info.length(), info.length(),
-	    info.rate(), info.bits(), info.tracks());
-	ASSERT(dialog);
+	    filename, m_file_info.tracks()*m_file_info.length()*
+	    (m_file_info.bits() >> 3),
+	    m_file_info.length(), m_file_info.rate(), m_file_info.bits(),
+	    m_file_info.tracks());
+	Q_ASSERT(dialog);
 	QObject::connect(&src,   SIGNAL(progress(unsigned int)),
 	                 dialog, SLOT(setValue(unsigned int)));
 	QObject::connect(dialog, SIGNAL(cancelled()),
 	                 &src,   SLOT(cancel()));
 	
 	// invoke the encoder...
-	if (!encoder->encode(m_parent_widget, src, dst, info)) {
+	if (!encoder->encode(m_parent_widget, src, dst, m_file_info)) {
 	    KMessageBox::error(m_parent_widget,
-	        i18n("An error occurred while reading the file!"));
+	        i18n("An error occurred while saving the file!"));
 	    res = -1;
 	}
 	
@@ -306,7 +389,7 @@ int SignalManager::save(const KURL &url, unsigned int bits, bool selection)
 	enableModifiedChange(true);
 	setModified(false);
     }
-    debug("SignalManager::save(): res=%d",res);
+    qDebug("SignalManager::save(): res=%d",res);
     return res;
 }
 
@@ -322,8 +405,9 @@ void SignalManager::newSignal(unsigned int samples, double rate,
     // disable undo (discards all undo/redo data)
     disableUndo();
 
-    m_signal.setRate((int)rint(rate));
-    m_signal.setBits(bits);
+    m_file_info.clear();
+    m_file_info.setRate(rate);
+    m_file_info.setBits(bits);
 
     // now the signal is considered not to be empty
     m_closed = false;
@@ -365,11 +449,11 @@ void SignalManager::close()
 }
 
 //***************************************************************************
-const QArray<unsigned int> SignalManager::selectedTracks()
+const QMemArray<unsigned int> SignalManager::selectedTracks()
 {
     unsigned int track;
     unsigned int count = 0;
-    QArray<unsigned int> list(tracks());
+    QMemArray<unsigned int> list(tracks());
 
     for (track=0; track < list.count(); track++) {
 	if (!m_signal.trackSelected(track)) continue;
@@ -381,7 +465,7 @@ const QArray<unsigned int> SignalManager::selectedTracks()
 }
 
 //***************************************************************************
-const QArray<unsigned int> SignalManager::allTracks()
+const QMemArray<unsigned int> SignalManager::allTracks()
 {
     return m_signal.allTracks();
 }
@@ -412,7 +496,7 @@ SampleWriter *SignalManager::openSampleWriter(unsigned int track,
     UndoAction *action = 0;
     switch (mode) {
 	case Append:
-	    debug("SignalManager::openSampleWriter(): NO UNDO FOR APPEND YET !");
+	    qDebug("SignalManager::openSampleWriter(): NO UNDO FOR APPEND YET !");
 	    break;
 	case Insert:
 	    action = new UndoInsertAction(track, left, right-left+1);
@@ -426,14 +510,14 @@ SampleWriter *SignalManager::openSampleWriter(unsigned int track,
 	    action = new UndoModifyAction(track, left, right-left+1);
 	    break;
     }
-    ASSERT(action);
+    Q_ASSERT(action);
 
     {
 	ThreadsafeX11Guard x11_guard;
 	if (!registerUndoAction(action)) {
 	    // creating/starting the action failed, so fail now.
 	    // close the writer and return 0 -> abort the operation
-	    debug("SignalManager::openSampleWriter(): register failed"); // ###
+	    qDebug("SignalManager::openSampleWriter(): register failed"); // ###
 	    if (action) delete action;
 	    delete writer;
 	    return 0;
@@ -450,7 +534,7 @@ SampleWriter *SignalManager::openSampleWriter(unsigned int track,
 
 //***************************************************************************
 void SignalManager::openMultiTrackReader(MultiTrackReader &readers,
-    const QArray<unsigned int> &track_list,
+    const QMemArray<unsigned int> &track_list,
     unsigned int first, unsigned int last)
 {
     m_signal.openMultiTrackReader(readers, track_list, first, last);
@@ -458,7 +542,7 @@ void SignalManager::openMultiTrackReader(MultiTrackReader &readers,
 
 //***************************************************************************
 void SignalManager::openMultiTrackWriter(MultiTrackWriter &writers,
-    const QArray<unsigned int> &track_list, InsertMode mode,
+    const QMemArray<unsigned int> &track_list, InsertMode mode,
     unsigned int left, unsigned int right)
 {
     UndoTransactionGuard guard(*this, 0);
@@ -476,7 +560,7 @@ void SignalManager::openMultiTrackWriter(MultiTrackWriter &writers,
 	    writers.insert(i, s);
 	} else {
 	    // out of memory or aborted
-	    debug("Signal::openMultiTrackWriter: "\
+	    qDebug("Signal::openMultiTrackWriter: "\
 	          "out of memory or aborted");
 	    writers.clear();
 	    return;
@@ -487,10 +571,11 @@ void SignalManager::openMultiTrackWriter(MultiTrackWriter &writers,
 //***************************************************************************
 bool SignalManager::executeCommand(const QString &command)
 {
-//    debug("SignalManager::executeCommand(%s)", command.data());    // ###
+//    qDebug("SignalManager::executeCommand(%s)", command.latin1());    // ###
 
     unsigned int offset = m_selection.offset();
     unsigned int length = m_selection.length();
+    double rate = m_file_info.rate();
 
     if (!command.length()) return true;
     Parser parser(command);
@@ -502,19 +587,19 @@ bool SignalManager::executeCommand(const QString &command)
 	redo();
     CASE_COMMAND("copy")
 	ClipBoard &clip = KwaveApp::clipboard();
-	clip.copy(m_signal, selectedTracks(), offset, length);
+	clip.copy(m_signal, selectedTracks(), offset, length, rate);
     CASE_COMMAND("paste")
 	paste(KwaveApp::clipboard(), offset, length);
     CASE_COMMAND("cut")
 	ClipBoard &clip = KwaveApp::clipboard();
-	clip.copy(m_signal, selectedTracks(), offset, length);
+	clip.copy(m_signal, selectedTracks(), offset, length, rate);
 	UndoTransactionGuard undo(*this, i18n("cut"));
 	deleteRange(offset, length);
     CASE_COMMAND("crop")
 	UndoTransactionGuard undo(*this, i18n("crop"));
 	unsigned int rest = this->length() - offset;
 	rest = (rest > length) ? (rest-length) : 0;
-	QArray<unsigned int> tracks = selectedTracks();
+	QMemArray<unsigned int> tracks = selectedTracks();
 	if (saveUndoDelete(tracks, offset+length, rest) &&
 	    saveUndoDelete(tracks, 0, offset))
 	{
@@ -539,7 +624,7 @@ bool SignalManager::executeCommand(const QString &command)
 //		/* ### check if the signal has to be re-sampled ### */
 //
 //		for (unsigned int i = 0; i < m_channels; i++) {
-//		    ASSERT(signal.at(i));
+//		    Q_ASSERT(signal.at(i));
 //		    if (signal.at(i)) {
 //			signal.at(i)->mixPaste(
 //			    toinsert->getSignal(sourcechan)
@@ -573,7 +658,7 @@ bool SignalManager::executeCommand(const QString &command)
 void SignalManager::paste(ClipBoard &clipboard, unsigned int offset,
                           unsigned int length)
 {
-    QArray<unsigned int> selected_tracks = selectedTracks();
+    QMemArray<unsigned int> selected_tracks = selectedTracks();
     if (clipboard.isEmpty()) return;
     if (!selected_tracks.size()) return;
 
@@ -589,7 +674,7 @@ void SignalManager::paste(ClipBoard &clipboard, unsigned int offset,
     // if the signal has no tracks, create new ones
     if (!tracks()) {
 	unsigned int missing = clipboard.tracks();
-	debug("SignalManager::paste(): appending %u tracks", missing);
+	qDebug("SignalManager::paste(): appending %u tracks", missing);
 	while (missing--) appendTrack();	
     }
 
@@ -637,7 +722,7 @@ void SignalManager::insertTrack(unsigned int index)
     }
 
     unsigned int count = tracks();
-    ASSERT(index <= count);
+    Q_ASSERT(index <= count);
     if (index > count) index = count;
 
     // if the signal is currently empty, use the last
@@ -646,11 +731,11 @@ void SignalManager::insertTrack(unsigned int index)
 
     if (index >= count) {
 	// do an "append"
-//	debug("SignalManager::insertTrack(): appending");
+//	qDebug("SignalManager::insertTrack(): appending");
 	m_signal.appendTrack(len);
     } else {
 	// insert into the list
-	warning("m_signal.insertTrack(index, len) - NOT IMPLEMENTED !");
+	qWarning("m_signal.insertTrack(index, len) - NOT IMPLEMENTED !");
 	// ### TODO ### m_signal.insertTrack(index, len);
     }
 
@@ -741,7 +826,7 @@ SignalManager::~SignalManager()
 
 //***************************************************************************
 bool SignalManager::deleteRange(unsigned int offset, unsigned int length,
-                                const QArray<unsigned int> &track_list)
+                                const QMemArray<unsigned int> &track_list)
 {
     if (!length) return true; // nothing to do
     UndoTransactionGuard undo(*this, i18n("delete"));
@@ -794,7 +879,7 @@ void SignalManager::selectRange(unsigned int offset, unsigned int length)
 }
 
 //***************************************************************************
-void SignalManager::selectTracks(QArray<unsigned int> &track_list)
+void SignalManager::selectTracks(QMemArray<unsigned int> &track_list)
 {
     unsigned int track;
     unsigned int n_tracks = tracks();
@@ -834,7 +919,7 @@ int SignalManager::loadAscii()
     float amp;
     int *sample = 0;
 
-    FILE *sigin = fopen(m_name.data(), "r");
+    FILE *sigin = fopen(m_name.latin1(), "r");
     if (!sigin) {
 	KMessageBox::error(0, i18n("File does not exist !"), i18n("Info"), 2);
 	return -ENOENT;
@@ -855,13 +940,13 @@ int SignalManager::loadAscii()
 	    cnt++;
 	}
     }
-    debug("SignalManager::loadAscii(): reading ascii file with %d samples",
+    qDebug("SignalManager::loadAscii(): reading ascii file with %d samples",
 	  cnt);    // ###
 
     // get the maximum and the scale
     amp = (float)((1 << 23)-1) / max;
     Signal *new_signal = new Signal(cnt, rate);
-    ASSERT(new_signal);
+    Q_ASSERT(new_signal);
 
     if (new_signal) {
 	signal.append(new_signal);
@@ -895,18 +980,18 @@ void SignalManager::emitStatusInfo()
 
 int SignalManager::exportAscii(const char *name)
 {
-    ASSERT(name);
+    Q_ASSERT(name);
     if (!name) return ;
 
     unsigned int length = getLength();
-    ASSERT(length);
+    Q_ASSERT(length);
     if (!length) return;
 
-    ASSERT(m_channels);
+    Q_ASSERT(m_channels);
     if (!m_channels) return;
 
     FILE *sigout = fopen(name, "w");
-    ASSERT(sigout);
+    Q_ASSERT(sigout);
     if (!sigout) return;
 
     //prepare and show the progress dialog
@@ -968,6 +1053,8 @@ PlaybackController &SignalManager::playbackController()
 //***************************************************************************
 void SignalManager::startUndoTransaction(const QString &name)
 {
+    if (!m_undo_enabled) return; // undo is currently not enabled
+
     MutexGuard lock(m_undo_transaction_lock);
 
     // increase recursion level
@@ -979,13 +1066,13 @@ void SignalManager::startUndoTransaction(const QString &name)
 	flushRedoBuffer();
 	
 	m_undo_transaction = new UndoTransaction(name);
-	ASSERT(m_undo_transaction);
+	Q_ASSERT(m_undo_transaction);
 	if (!m_undo_transaction) return;
 	
 	// if it is the start of the transaction, also create one
 	// for the selection
 	UndoAction *selection = new UndoSelection(*this);
-	ASSERT(selection);
+	Q_ASSERT(selection);
 	if (selection) {
 	    selection->store(*this);
 	    m_undo_transaction->append(selection);
@@ -999,8 +1086,8 @@ void SignalManager::closeUndoTransaction()
     MutexGuard lock(m_undo_transaction_lock);
 
     // decrease recursion level
-    ASSERT(m_undo_transaction_level);
-    if (m_undo_transaction_level) m_undo_transaction_level--;
+    if (!m_undo_transaction_level) return; // undo was not enabled ?
+    m_undo_transaction_level--;
 
     if (!m_undo_transaction_level) {
 	// append the current transaction to the undo buffer if
@@ -1009,7 +1096,7 @@ void SignalManager::closeUndoTransaction()
 	    if (!m_undo_transaction->isEmpty()) {
 		m_undo_buffer.append(m_undo_transaction);
 	    } else {
-		debug("SignalManager::closeUndoTransaction(): empty");
+		qDebug("SignalManager::closeUndoTransaction(): empty");
 		delete m_undo_transaction;
 	    }
 	}
@@ -1030,7 +1117,7 @@ void SignalManager::enableUndo()
 //***************************************************************************
 void SignalManager::disableUndo()
 {
-    ASSERT(m_undo_transaction_level == 0);
+    Q_ASSERT(m_undo_transaction_level == 0);
 
     m_undo_enabled = false;
     flushUndoBuffers();
@@ -1041,7 +1128,7 @@ void SignalManager::flushUndoBuffers()
 {
     MutexGuard lock(m_undo_transaction_lock);
 
-    ASSERT(m_undo_transaction_level == 0);
+    Q_ASSERT(m_undo_transaction_level == 0);
 
     // close the current transaction
     if (m_undo_transaction) delete m_undo_transaction;
@@ -1085,7 +1172,7 @@ void SignalManager::flushRedoBuffer()
 bool SignalManager::registerUndoAction(UndoAction *action)
 {
     MutexGuard lock(m_undo_transaction_lock);
-    ASSERT(action);
+    Q_ASSERT(action);
     if (!action) return false;
 
     // if undo is not enabled, return a faked "ok"
@@ -1129,14 +1216,14 @@ bool SignalManager::registerUndoAction(UndoAction *action)
 }
 
 //***************************************************************************
-bool SignalManager::saveUndoDelete(QArray<unsigned int> &track_list,
+bool SignalManager::saveUndoDelete(QMemArray<unsigned int> &track_list,
                                    unsigned int offset, unsigned int length)
 {
     if (!m_undo_enabled) return true;
     if (track_list.isEmpty()) return true;
 
     unsigned int count = track_list.count();
-    QList<UndoDeleteAction> undo_list;
+    QPtrList<UndoDeleteAction> undo_list;
     undo_list.setAutoDelete(true);
 
     // loop over all tracks
@@ -1148,7 +1235,7 @@ bool SignalManager::saveUndoDelete(QArray<unsigned int> &track_list,
 	    undo_list.clear();
 	    return false;
 	}
-    };
+    }
 
     // do not delete the actions from the list, so it's important
     // to disable the auto-delete feature now!
@@ -1161,11 +1248,11 @@ unsigned int SignalManager::usedUndoRedoMemory()
 {
     unsigned int size = 0;
 
-    QListIterator<UndoTransaction> undo_it(m_undo_buffer);
+    QPtrListIterator<UndoTransaction> undo_it(m_undo_buffer);
     for ( ; undo_it.current(); ++undo_it ) {
 	size += undo_it.current()->undoSize();
     }
-    QListIterator<UndoTransaction> redo_it(m_redo_buffer);
+    QPtrListIterator<UndoTransaction> redo_it(m_redo_buffer);
     for ( ; redo_it.current(); ++redo_it ) {
 	size += redo_it.current()->undoSize();
     }
@@ -1239,7 +1326,7 @@ void SignalManager::undo()
     // get the last undo transaction and abort if none present
     if (m_undo_buffer.isEmpty()) return;
     UndoTransaction *undo_transaction = m_undo_buffer.last();
-    ASSERT(undo_transaction);
+    Q_ASSERT(undo_transaction);
     if (!undo_transaction) return;
 
     // remove the undo transaction from the list without deleting it
@@ -1257,7 +1344,7 @@ void SignalManager::undo()
     UndoTransaction *redo_transaction = 0;
     if (undo_size + redo_size > m_undo_limit) {
 	// not enough memory for redo
-	warning("SignalManager::undo(): not enough memory for redo !");
+	qWarning("SignalManager::undo(): not enough memory for redo !");
     } else {
 	// only free the memory if it will be used
 	freeUndoMemory(undo_size + redo_size);
@@ -1265,14 +1352,14 @@ void SignalManager::undo()
 	// create a new redo transaction
 	QString name = undo_transaction->description();
 	redo_transaction = new UndoTransaction(name);
-	ASSERT(redo_transaction);
+	Q_ASSERT(redo_transaction);
     }
 
     // if *one* redo fails, all following redoes will also fail or
     // produce inconsistent data -> remove all of them !
     if (!redo_transaction) {
 	flushRedoBuffer();
-	debug("SignalManager::undo(): redo buffer flushed!"); // ###
+	qDebug("SignalManager::undo(): redo buffer flushed!"); // ###
     } else {
 	m_redo_buffer.prepend(redo_transaction);
     }
@@ -1287,7 +1374,7 @@ void SignalManager::undo()
 	undo_transaction->setAutoDelete(false);
 	undo_action = undo_transaction->last();
 	undo_transaction->removeLast();
-	ASSERT(undo_action);
+	Q_ASSERT(undo_action);
 	if (!undo_action) continue;
 	
 	// execute the undo operation
@@ -1312,7 +1399,7 @@ void SignalManager::undo()
     if (redo_transaction && (redo_transaction->count() <= 1)) {
 	// if there is not more than the UndoSelection action,
 	// there are no real redo actions -> no redo possible
-	warning("SignalManager::undo(): no redo possible");
+	qWarning("SignalManager::undo(): no redo possible");
 	m_redo_buffer.setAutoDelete(true);
 	m_redo_buffer.remove(redo_transaction);
     }
@@ -1352,7 +1439,7 @@ void SignalManager::redo()
     UndoTransaction *undo_transaction = 0;
     if (undo_size + redo_size > m_undo_limit) {
 	// not enough memory for undo
-	warning("SignalManager::redo(): not enough memory for undo !");
+	qWarning("SignalManager::redo(): not enough memory for undo !");
     } else {
 	// only free the memory if it will be used
 	freeUndoMemory(undo_size + redo_size);
@@ -1360,7 +1447,7 @@ void SignalManager::redo()
 	// create a new undo transaction
 	QString name = redo_transaction->description();
 	undo_transaction = new UndoTransaction(name);
-	ASSERT(undo_transaction);
+	Q_ASSERT(undo_transaction);
     }
 
     // if *one* undo fails, all following undoes will also fail or
@@ -1368,7 +1455,7 @@ void SignalManager::redo()
     if (!undo_transaction) {
 	m_undo_buffer.setAutoDelete(true);
 	m_undo_buffer.clear();
-	debug("SignalManager::redo(): undo buffer flushed!");
+	qDebug("SignalManager::redo(): undo buffer flushed!");
     } else {
 	m_undo_buffer.append(undo_transaction);
     }
@@ -1383,7 +1470,7 @@ void SignalManager::redo()
 	redo_transaction->setAutoDelete(false);
 	redo_action = redo_transaction->first();
 	redo_transaction->removeFirst();
-	ASSERT(redo_action);
+	Q_ASSERT(redo_action);
 	if (!redo_action) continue;
 	
 	// execute the redo operation
@@ -1408,7 +1495,7 @@ void SignalManager::redo()
     if (undo_transaction && (undo_transaction->count() <= 1)) {
 	// if there is not more than the UndoSelection action,
 	// there are no real undo actions -> no undo possible
-	warning("SignalManager::redo(): no undo possible");
+	qWarning("SignalManager::redo(): no undo possible");
 	m_undo_buffer.setAutoDelete(true);
 	m_undo_buffer.remove(undo_transaction);
     }
@@ -1424,7 +1511,7 @@ void SignalManager::setModified(bool mod)
 
     if (m_modified != mod) {
 	m_modified = mod;
-	debug("SignalManager::setModified(%d)",mod);
+	qDebug("SignalManager::setModified(%d)",mod);
 	emit sigModified(m_modified);
     }
 }
@@ -1435,5 +1522,25 @@ void SignalManager::enableModifiedChange(bool en)
     m_modified_enabled = en;
 }
 
+//***************************************************************************
+void SignalManager::setFileInfo(FileInfo &new_info, bool with_undo)
+{
+    ThreadsafeX11Guard x11_guard;
+
+    if (with_undo) {
+	/* save data for undo */
+	UndoTransactionGuard undo_transaction(*this, i18n("modify file info"));
+	UndoFileInfo *undo = new UndoFileInfo(*this);
+	Q_ASSERT(undo);
+	if (!undo) return;
+	if (!registerUndoAction(undo)) return;
+    }
+
+    m_file_info = new_info;
+    setModified(true);
+    emitStatusInfo();
+    emitUndoRedoInfo();
+}
+
 //***************************************************************************
 //***************************************************************************
