@@ -19,15 +19,17 @@
 #define _SIGNAL_MANAGER_H_
 
 #include "config.h"
+#include <limits.h>
 #include <stdio.h>
 
 #include <qobject.h>
-#include <qarray.h>
-#include <qlist.h>
+#include <qmemarray.h>
+#include <qptrlist.h>
 #include <qstring.h>
 
 #include "mt/Mutex.h"
 #include "mt/SignalProxy.h"
+#include "libkwave/FileInfo.h"
 #include "libkwave/Selection.h"
 #include "libkwave/Signal.h"
 
@@ -95,13 +97,19 @@ public:
     /** Executes a Kwave text command */
     bool executeCommand(const QString &command);
 
+    /**
+     * Returns a reference to the FileInfo object associated with the
+     * currently opened file.
+     */
+    FileInfo &fileInfo() { return m_file_info; };
+
     /**
      * Returns the current sample resolution in bits per sample
      */
-    inline unsigned int bits() { return m_signal.bits(); };
+    inline unsigned int bits() const { return m_file_info.bits(); };
 
     /** Returns the current sample rate in samples per second */
-    inline int rate() { return m_signal.rate(); };
+    inline double rate() const { return m_file_info.rate(); };
 
     /** Returns the current number of tracks */
     inline unsigned int tracks() { return m_signal.tracks(); };
@@ -127,22 +135,21 @@ public:
     /**
      * Returns an array of indices of currently selected tracks.
      */
-    const QArray<unsigned int> selectedTracks();
+    const QMemArray<unsigned int> selectedTracks();
 
     /**
      * Returns an array of indices of all present tracks.
      */
-    const QArray<unsigned int> allTracks();
+    const QMemArray<unsigned int> allTracks();
 
     /**
      * Saves the signal to a file with a given resolution. If the file
      * already exists, it will be overwritten.
      * @param url URL with the name of the file to be saved.
-     * @param bits number of bits per sample
      * @param selection if true, only the selected range will be saved
      * @return zero if succeeded or negative error code
      */
-    int save(const KURL &url, unsigned int bits, bool selection);
+    int save(const KURL &url, bool selection);
 
     /**
      * Exports ascii file with one sample per line and only one track.
@@ -160,7 +167,7 @@ public:
      *         memory for undo
      */
     bool deleteRange(unsigned int offset, unsigned int length,
-                     const QArray<unsigned int> &track_list);
+                     const QMemArray<unsigned int> &track_list);
 
     /**
      * Deletes a range of samples and creates an undo action. Same as
@@ -203,7 +210,7 @@ public:
      * Selects multiple tracks, all other tracks will be disabled.
      * @param track_list list od track indices
      */
-    void selectTracks(QArray<unsigned int> &track_list);
+    void selectTracks(QMemArray<unsigned int> &track_list);
 
     /**
      * Sets the selection flag of a track.
@@ -260,7 +267,7 @@ public:
      * @see Signal::openMultiTrackWriter
      */
     void openMultiTrackReader(MultiTrackReader &readers,
-	const QArray<unsigned int> &track_list,
+	const QMemArray<unsigned int> &track_list,
 	unsigned int first, unsigned int last);
 
     /**
@@ -275,7 +282,7 @@ public:
      * @see Signal::openMultiTrackWriter
      */
     void openMultiTrackWriter(MultiTrackWriter &writers,
-	const QArray<unsigned int> &track_list, InsertMode mode,
+	const QMemArray<unsigned int> &track_list, InsertMode mode,
 	unsigned int left, unsigned int right);
 
     /** Returns true if undo/redo is currently enabled */
@@ -303,6 +310,11 @@ public:
      */
     void paste(ClipBoard &clipboard, unsigned int offset, unsigned int length);
 
+    /**
+     * Sets a complete set of file infos, including undo information
+     */
+    void setFileInfo(FileInfo &new_info, bool with_undo = true);
+
 signals:
 
     /**
@@ -334,7 +346,7 @@ signals:
      * @param bits resolution in bits
      */
     void sigStatusInfo(unsigned int length, unsigned int tracks,
-                       unsigned int rate, unsigned int bits);
+                       double rate, unsigned int bits);
 
     /**
      * Emitted if samples have been inserted into a track. This implies
@@ -373,17 +385,6 @@ signals:
      */
     void sigCommand(const QString &command);
 
-    /**
-     * Indicates a change in the position of the playback pointer
-     * during playback.
-     */
-    void sigPlaybackPos(unsigned int pos);
-
-    /**
-     * Indicates that playback is done.
-     */
-    void sigPlaybackDone();
-
     /**
      * Signals that a track has been selected or deselected.
      * @param track index of the track
@@ -422,7 +423,8 @@ private slots:
 
     /**
      * Connected to the signal's sigTrackInserted.
-     * @param track index of the inserted track
+     * @param index numeric index of the inserted track
+     * @param track reference to the track that has been inserted
      * @see Signal::sigTrackInserted
      * @internal
      */
@@ -430,7 +432,7 @@ private slots:
 
     /**
      * Connected to the signal's sigTrackInserted.
-     * @param track index of the inserted track
+     * @param index numeric index of the inserted track
      * @see Signal::sigTrackDeleted
      * @internal
      */
@@ -531,7 +533,7 @@ protected:
      * @param length number of samples to delete
      * @return true if successful, false if out of memory or aborted
      */
-    bool saveUndoDelete(QArray<unsigned int> &track_list,
+    bool saveUndoDelete(QMemArray<unsigned int> &track_list,
                         unsigned int offset, unsigned int length);
 
     /**
@@ -558,6 +560,12 @@ protected:
      */
     void flushRedoBuffer();
 
+    /**
+     * Sets the modified flag to a new value if m_modified_enabled is
+     * true, otherwise it will be ignored.
+     */
+    void setModified(bool mod);
+
 private:
 
     /** Shortcut for emitting a sigStatusInfo */
@@ -576,12 +584,6 @@ private:
      */
     void freeUndoMemory(unsigned int needed);
 
-    /**
-     * Sets the modified flag to a new value if m_modified_enabled is
-     * true, otherwise it will be ignored.
-     */
-    void setModified(bool mod);
-
     /**
      * Enables changes of the modified flag.
      * @param en new value for m_modified_enabled
@@ -633,10 +635,10 @@ private:
     bool m_undo_enabled;
 
     /** fifo used for storing all undo transactions */
-    QList<UndoTransaction> m_undo_buffer;
+    QPtrList<UndoTransaction> m_undo_buffer;
 
     /** fifo for storing all redo transactions */
-    QList<UndoTransaction> m_redo_buffer;
+    QPtrList<UndoTransaction> m_redo_buffer;
 
     /** the current undo transaction */
     UndoTransaction *m_undo_transaction;
@@ -653,6 +655,8 @@ private:
     /** maximum memory for undo */
     unsigned int m_undo_limit;
 
+    /** info about the file, @see class FileInfo */
+    FileInfo m_file_info;
 };
 
 #endif  /* _SIGNAL_MANAGER_H_ */
