@@ -16,6 +16,7 @@
  ***************************************************************************/
 
 #include "config.h"
+#include <errno.h>
 #include <math.h>
 #include <stdlib.h>
 
@@ -40,10 +41,10 @@
 #include "libkwave/SampleWriter.h"
 #include "libkwave/Signal.h"
 
-#include "libgui/Dialog.h"
 #include "libgui/MenuManager.h"
 #include "libgui/TrackPixmap.h"
 
+#include "CodecManager.h"
 #include "SignalWidget.h"
 #include "SignalManager.h"
 #include "MouseMark.h"
@@ -69,6 +70,12 @@
  */
 #define MINIMUM_SAMPLES_PER_SCREEN 5
 
+/**
+ * Default widht of the display in seconds when in streaming mode,
+ * where no initial length information is available
+ */
+#define DEFAULT_DISPLAY_TIME 60.0
+
 //***************************************************************************
 //***************************************************************************
 class KwaveFileDrag: public QUriDrag
@@ -82,12 +89,8 @@ public:
 	decodeLocalFiles(source, files);
 	QStringList::Iterator it;
 	for (it = files.begin(); it != files.end(); ++it) {
-	    QString f;
-	    f = (*it).lower();
-	    int len = (*it).length();
-	    /** @todo go through a central file type registry */
-	    if (f.findRev(".wav") == len-4) return true;
-	    if (f.findRev(".asc") == len-4) return true;
+	    QString mimetype = CodecManager::whatContains(*it);
+	    if (CodecManager::canDecode(mimetype)) return true;
 	}
 	return false;
     };
@@ -97,24 +100,15 @@ public:
 //***************************************************************************
 SignalWidget::SignalWidget(QWidget *parent)
     :QWidget(parent),
-    m_inhibit_repaint(0),
+    m_offset(0), m_width(0), m_height(0), m_last_width(0), m_last_height(0),
+    m_zoom(0.0), m_playpointer(-1), m_last_playpointer(-1), m_redraw(false),
+    m_inhibit_repaint(0), m_selection(0),
     m_signal_manager(this),
-    m_track_pixmaps(),
+    m_track_pixmaps(), m_pixmap(0),
     m_mouse_mode(MouseNormal),
     m_mouse_down_x(0)
 {
-//    debug("SignalWidget::SignalWidget()");
-    m_height = 0;
-    lastHeight = 0;
-    lastplaypointer = -1;
-    lastWidth = 0;
-    m_offset = 0;
-    m_pixmap = 0;
-    playpointer = -1;
-    redraw = false;
-    m_selection = 0;
-    m_width = 0;
-    m_zoom = 0.0;
+//    qDebug("SignalWidget::SignalWidget()");
 
     for (int i=0; i < 3; i++) {
 	m_layer[i] = 0;
@@ -123,7 +117,7 @@ SignalWidget::SignalWidget(QWidget *parent)
     }
 
     m_selection = new MouseMark();
-    ASSERT(m_selection);
+    Q_ASSERT(m_selection);
     if (!m_selection) return;
 
     // connect to the signal manager's signals
@@ -155,7 +149,7 @@ SignalWidget::SignalWidget(QWidget *parent)
             this, SLOT(updatePlaybackPointer(unsigned int)));
 
 //    labels = new LabelList();
-//    ASSERT(labels);
+//    Q_ASSERT(labels);
 //    if (!labels) return;
 //    labels->setAutoDelete (true);
 
@@ -170,12 +164,12 @@ SignalWidget::SignalWidget(QWidget *parent)
 
     setBackgroundColor(black);
     setBackgroundMode(NoBackground); // this avoids flicker :-)
-    setMouseTracking(true);
 
+    setMouseTracking(true);
     setAcceptDrops(true); // enable drag&drop
 
     setZoom(0.0);
-//    debug("SignalWidget::SignalWidget(): done.");
+//    qDebug("SignalWidget::SignalWidget(): done.");
 }
 
 //***************************************************************************
@@ -193,8 +187,8 @@ void SignalWidget::refreshSignalLayer()
 //***************************************************************************
 bool SignalWidget::isOK()
 {
-////    ASSERT(labels);
-    ASSERT(m_selection);
+////    Q_ASSERT(labels);
+    Q_ASSERT(m_selection);
     return ( /* labels && */ m_selection );
 }
 
@@ -218,16 +212,16 @@ SignalWidget::~SignalWidget()
 }
 
 //***************************************************************************
-int SignalWidget::saveFile(const KURL &url, unsigned int bits, bool selection)
+int SignalWidget::saveFile(const KURL &url, bool selection)
 {
-    return m_signal_manager.save(url, bits, selection);
+    return m_signal_manager.save(url, selection);
 }
 
 //***************************************************************************
 void SignalWidget::toggleTrackSelection(int track)
 {
     // here we have to convert to unsigned
-    ASSERT(track >= 0);
+    Q_ASSERT(track >= 0);
     if (track < 0) return;
     unsigned int t = static_cast<unsigned int>(track);
     bool select = !m_signal_manager.trackSelected(t);
@@ -279,7 +273,7 @@ bool SignalWidget::executeNavigationCommand(const QString &command)
 	if (len > ofs) len = ofs;
 	selectRange(ofs-len, len);
     CASE_COMMAND("selecttoleft")
-	selectRange(0, m_signal_manager.selection().last());
+	selectRange(0, m_signal_manager.selection().last()+1);
     CASE_COMMAND("selecttoright")
 	selectRange(m_signal_manager.selection().first(),
 	    m_signal_manager.length()-m_signal_manager.selection().first()
@@ -337,15 +331,12 @@ bool SignalWidget::executeCommand(const QString &command)
     InhibitRepaintGuard inhibit(*this);
 
     if (!command.length()) return true;
-    Parser parser(command);
-//    debug("SignalWidget::executeCommand(%s)", command.data());    // ###
 
-    if (false) {
-    } else if (executeNavigationCommand(command)) {
+    if (executeNavigationCommand(command)) {
 	return true;
     } else {
 	return m_signal_manager.executeCommand(command);
-    };
+    }
 
     return true;
 }
@@ -370,11 +361,11 @@ void SignalWidget::slotSelectionChanged(unsigned int offset,
                                         unsigned int length)
 {
     m_signal_manager.selectRange(offset, length);
+    offset = m_signal_manager.selection().offset();
+    length = m_signal_manager.selection().length();
+    
     refreshSelection();
-
-    unsigned int samples = m_signal_manager.selection().length();
-    double ms = samples2ms(samples);
-    emit selectedTimeInfo(samples, ms);
+    emit selectedTimeInfo(offset, length, m_signal_manager.rate());
 }
 
 //***************************************************************************
@@ -389,12 +380,6 @@ int SignalWidget::tracks()
     return m_signal_manager.tracks();
 }
 
-//***************************************************************************
-unsigned int SignalWidget::bits()
-{
-    return m_signal_manager.bits();
-}
-
 //***************************************************************************
 PlaybackController &SignalWidget::playbackController()
 {
@@ -416,11 +401,37 @@ int SignalWidget::loadFile(const KURL &url)
     // load a new signal
     int res = m_signal_manager.loadFile(url);
     if (m_signal_manager.isClosed() || (res)) {
-	warning("SignalWidget::loadFile() failed:"\
+	qWarning("SignalWidget::loadFile() failed:"\
 		" zero-length or out of memory?");
+		
+	QString reason;
+	switch (res) {
+	    case -ENOMEM:
+		reason = i18n("Out of memory");
+		break;
+	    case -EIO:
+		reason = i18n("unable to open '%1'").arg(url.prettyURL());
+		break;
+	    case -EMEDIUMTYPE:
+		reason = i18n("invalid or unknown file type: '%1'").arg(
+		              url.prettyURL());
+		break;
+	    default:
+		reason = "";
+	}
+
+        // show an error message box if the reason was known
+	if (reason.length()) {
+	    KMessageBox::error(this, reason);
+	}
+	
 	close();
     }
 
+    // if the signal is smaller than expected,
+    // zoom it to full size
+    if (m_zoom > getFullZoom()) setZoom(getFullZoom());
+    
     return res;
 }
 
@@ -469,7 +480,7 @@ void SignalWidget::setOffset(unsigned int new_offset)
     unsigned int n_tracks = m_track_pixmaps.count();
     for (unsigned int i = 0; i < n_tracks; i++) {
 	TrackPixmap *pix = m_track_pixmaps.at(i);
-	ASSERT(pix);
+	Q_ASSERT(pix);
 	if (!pix) continue;
 	
 	pix->setOffset(m_offset);
@@ -484,14 +495,22 @@ void SignalWidget::setOffset(unsigned int new_offset)
 //***************************************************************************
 double SignalWidget::getFullZoom()
 {
-    if (!m_signal_manager.length()) return 0.0;    // no zoom if no signal
+    if (m_signal_manager.isEmpty()) return 0.0;    // no zoom if no signal
+
+    unsigned int length = m_signal_manager.length();
+    if (!length) {
+        // no length: streaming mode -> start with a default
+        // zoom, use one minute (just guessed)
+        length = (unsigned int)ceil(DEFAULT_DISPLAY_TIME *
+                                    m_signal_manager.rate());
+    }
 
     // example: width = 100 [pixels] and length = 3 [samples]
     //          -> samples should be at positions 0, 49.5 and 99
     //          -> 49.5 [pixels / sample]
     //          -> zoom = 1 / 49.5 [samples / pixel]
     // => full zoom [samples/pixel] = (length-1) / (width-1)
-    return (double)(m_signal_manager.length()-1) / (double)(QWidget::width()-1);
+    return (double)(length-1) / (double)(QWidget::width()-1);
 }
 
 //***************************************************************************
@@ -508,7 +527,7 @@ void SignalWidget::setZoom(double new_zoom)
     unsigned int n_tracks = m_track_pixmaps.count();
     for (unsigned int i = 0; i < n_tracks; i++) {
 	TrackPixmap *pix = m_track_pixmaps.at(i);
-	ASSERT(pix);
+	Q_ASSERT(pix);
 	if (!pix) continue;
 	
 	pix->setOffset(m_offset);
@@ -531,6 +550,10 @@ void SignalWidget::fixZoomAndOffset()
     unsigned int length;
 
     length = m_signal_manager.length();
+    if (!length) {
+	// in streaming mode we have to use a guessed length
+	length = (unsigned int)ceil(width() * getFullZoom());
+    }
 
     if (!m_width) return;
 
@@ -552,21 +575,26 @@ void SignalWidget::fixZoomAndOffset()
     //          -> available space = pixels2samples(width-1) + 1
     //             = (99/49.5) + 1 = 3
     //          -> decrease offset by 3 - 2 = 1
+    Q_ASSERT(length >= m_offset);
     if (pixels2samples(m_width - 1) + 1 > length-m_offset) {
-	// there is space after the signal -> move offset left
-	int shift = pixels2samples(m_width - 1) + 1 - (length - m_offset);
-	if ((shift < 0) && (static_cast<unsigned int>(-shift) > m_offset))
+	// there is space after the signal -> move offset right
+	unsigned int shift = pixels2samples(m_width - 1) + 1 -
+	                     (length - m_offset);
+	if (shift >= m_offset) {
 	    m_offset = 0;
-	else
+	} else {
 	    m_offset -= shift;
+	}
     }
 
-    // if reducing the offset was not enough, zoom in
-    if (pixels2samples(m_width - 1) + 1 > length - m_offset) {
-	// there is still space after the signal -> zoom in
-	// (this should never happen as the zoom has been limited before)
-	m_zoom = max_zoom;
-    }
+// not really needed, has side-effects e.g. when a .ogg file
+// has been loaded
+//    // if reducing the offset was not enough, zoom in
+//    if (pixels2samples(m_width - 1) + 1 > length - m_offset) {
+//	// there is still space after the signal -> zoom in
+//	// (this should never happen as the zoom has been limited before)
+//	m_zoom = max_zoom;
+//    }
 
 // this made some strange effects, so I disabled it :-[
 //    // adjust the zoom factor in order to make a whole number
@@ -680,7 +708,7 @@ void SignalWidget::inhibitRepaint()
 //***************************************************************************
 void SignalWidget::allowRepaint(bool repaint)
 {
-    ASSERT(m_inhibit_repaint);
+    Q_ASSERT(m_inhibit_repaint);
     if (!m_inhibit_repaint) return;
 
     // decrease the number of repaint locks
@@ -700,28 +728,27 @@ void SignalWidget::refreshAllLayers()
 	m_update_layer[i] = true;
     }
 
-    fixZoomAndOffset();
-    redraw = true;
-};
+    m_redraw = true;
+}
 
 //***************************************************************************
 void SignalWidget::refreshLayer(int layer)
 {
     InhibitRepaintGuard inhibit(*this);
 
-    ASSERT(layer >= 0);
-    ASSERT(layer < 3);
+    Q_ASSERT(layer >= 0);
+    Q_ASSERT(layer < 3);
     if ((layer < 0) || (layer >= 3)) return;
 
     m_update_layer[layer] = true;
 
-    redraw = true;
+    m_redraw = true;
 }
 
 //***************************************************************************
 int SignalWidget::selectionPosition(const int x)
 {
-    ASSERT(m_selection);
+    Q_ASSERT(m_selection);
     if (!m_selection) return None;
 
     /** @todo selection tolerance should depend on some KDE setting,
@@ -730,8 +757,7 @@ int SignalWidget::selectionPosition(const int x)
     const unsigned int first = m_signal_manager.selection().first();
     const unsigned int last  = m_signal_manager.selection().last();
     const unsigned int ofs   = m_offset;
-    const unsigned int w     = pixels2samples(w);
-    ASSERT(first <= last);
+    Q_ASSERT(first <= last);
 
     // get pixel coordinates
     const int l = (first < ofs) ? -(2*tol) : (samples2pixels(first-ofs));
@@ -773,8 +799,8 @@ bool SignalWidget::isInSelection(int x)
 //***************************************************************************
 void SignalWidget::mousePressEvent(QMouseEvent *e)
 {
-    ASSERT(e);
-    ASSERT(m_selection);
+    Q_ASSERT(e);
+    Q_ASSERT(m_selection);
     if (!e) return;
     if (!m_selection) return;
 
@@ -790,7 +816,6 @@ void SignalWidget::mousePressEvent(QMouseEvent *e)
 	if (mx >= m_width) mx = m_width-1;
 	unsigned int x = m_offset + pixels2samples(mx);
 	unsigned int len = m_selection->right() - m_selection->left() + 1;
-	
 	switch (e->state() & KeyButtonMask) {
 	    case ShiftButton: {
 		// expand the selection to "here"
@@ -828,8 +853,8 @@ void SignalWidget::mousePressEvent(QMouseEvent *e)
 //***************************************************************************
 void SignalWidget::mouseReleaseEvent(QMouseEvent *e)
 {
-    ASSERT(e);
-    ASSERT(m_selection);
+    Q_ASSERT(e);
+    Q_ASSERT(m_selection);
     if (!e) return;
     if (!m_selection) return;
 
@@ -871,9 +896,9 @@ void SignalWidget::mouseReleaseEvent(QMouseEvent *e)
 //***************************************************************************
 void SignalWidget::mouseMoveEvent(QMouseEvent *e)
 {
-    ASSERT(e);
-    ASSERT(m_selection);
-    ASSERT(m_width);
+    Q_ASSERT(e);
+    Q_ASSERT(m_selection);
+    Q_ASSERT(m_width);
     if (!e) return;
     if (!m_selection) return;
     if (!m_width) return;
@@ -923,7 +948,7 @@ void SignalWidget::paintEvent(QPaintEvent *)
     InhibitRepaintGuard inhibit(*this, false); // avoid recursion
     QPainter p;
 
-//    debug("SignalWidget::paintEvent()");
+//    qDebug("SignalWidget::paintEvent()");
 //#ifdef DEBUG
 //    static struct timeval t_start;
 //    static struct timeval t_end;
@@ -941,11 +966,11 @@ void SignalWidget::paintEvent(QPaintEvent *)
     m_width = QWidget::width();
     m_height = QWidget::height();
 
-//    debug("SignalWidget::paintEvent(): width=%d, height=%d",m_width,m_height);
+//    qDebug("SignalWidget::paintEvent(): width=%d, height=%d",m_width,m_height);
 
     // --- detect size changes and refresh the whole display ---
-    if ((m_width != lastWidth) || (m_height != lastHeight)) {
-//	debug("SignalWidget::paintEvent(): window size changed from "
+    if ((m_width != m_last_width) || (m_height != m_last_height)) {
+//	qDebug("SignalWidget::paintEvent(): window size changed from "
 //	      "%dx%d to %dx%d",lastWidth,lastHeight,m_width,m_height);
 	for (int i=0; i<3; i++) {
 	    if (m_layer[i]) delete m_layer[i];
@@ -955,10 +980,10 @@ void SignalWidget::paintEvent(QPaintEvent *)
 	if (!m_pixmap) delete m_pixmap;
 	m_pixmap = 0;
 	update_pixmap = true;
-	
-	lastWidth = m_width;
-	lastHeight = m_height;
-	
+
+	m_last_width = m_width;
+	m_last_height = m_height;
+
 	// check and correct m_zoom and m_offset
 	setZoom(m_zoom);
     }
@@ -967,10 +992,10 @@ void SignalWidget::paintEvent(QPaintEvent *)
     if ( m_update_layer[LAYER_SIGNAL] || !m_layer[LAYER_SIGNAL]) {
 	if (!m_layer[LAYER_SIGNAL])
 	     m_layer[LAYER_SIGNAL] = new QPixmap(size());
-	ASSERT(m_layer[LAYER_SIGNAL]);
+	Q_ASSERT(m_layer[LAYER_SIGNAL]);
 	if (!m_layer[LAYER_SIGNAL]) return;
-	
-//	debug("SignalWidget::paintEvent(): - redraw of signal layer -");
+
+//	qDebug("SignalWidget::paintEvent(): - redraw of signal layer -");
 	p.begin(m_layer[LAYER_SIGNAL]);
 	p.setRasterOp(CopyROP);
 	
@@ -989,7 +1014,7 @@ void SignalWidget::paintEvent(QPaintEvent *)
 		pix->resize(m_width, track_height);
 	    }
 	    if (pix->isModified()) {
-//		debug("SignalWidget::paintEvent(): redrawing track %d",i); // ###
+//		qDebug("SignalWidget::paintEvent(): redrawing track %d",i); // ###
 		pix->repaint();
 	    }
 	
@@ -998,7 +1023,7 @@ void SignalWidget::paintEvent(QPaintEvent *)
 	
 	    top += track_height;
 	}
-	
+
 	p.end();
 
 	m_update_layer[LAYER_SIGNAL] = false;
@@ -1009,10 +1034,10 @@ void SignalWidget::paintEvent(QPaintEvent *)
     if ( m_update_layer[LAYER_MARKERS] || !m_layer[LAYER_MARKERS] ) {
 	if (!m_layer[LAYER_MARKERS])
 	     m_layer[LAYER_MARKERS] = new QPixmap(size());
-	ASSERT(m_layer[LAYER_MARKERS]);
+	Q_ASSERT(m_layer[LAYER_MARKERS]);
 	if (!m_layer[LAYER_MARKERS]) return;
 	
-//	debug("SignalWidget::paintEvent(): - redraw of markers layer -");
+//	qDebug("SignalWidget::paintEvent(): - redraw of markers layer -");
 	p.begin(m_layer[LAYER_MARKERS]);
 	p.fillRect(0, 0, m_width, m_height, black);
 	
@@ -1028,10 +1053,10 @@ void SignalWidget::paintEvent(QPaintEvent *)
     if (( m_update_layer[LAYER_SELECTION] || !m_layer[LAYER_SELECTION] )) {
 	if (!m_layer[LAYER_SELECTION])
 	    m_layer[LAYER_SELECTION] = new QPixmap(size());
-	ASSERT(m_layer[LAYER_SELECTION]);
+	Q_ASSERT(m_layer[LAYER_SELECTION]);
 	if (!m_layer[LAYER_SELECTION]) return;
 
-//	debug("SignalWidget::paintEvent(): - redraw of selection layer -");
+//	qDebug("SignalWidget::paintEvent(): - redraw of selection layer -");
 	
 	p.begin(m_layer[LAYER_SELECTION]);
 	p.fillRect(0, 0, m_width, m_height, black);
@@ -1067,7 +1092,7 @@ void SignalWidget::paintEvent(QPaintEvent *)
     // --- re-create the buffer pixmap if it has been deleted ---
     if (!m_pixmap) {
 	m_pixmap = new QPixmap(size());
-	ASSERT(m_pixmap);
+	Q_ASSERT(m_pixmap);
 	if (!m_pixmap) return;
 	update_pixmap = true;
     }
@@ -1078,31 +1103,31 @@ void SignalWidget::paintEvent(QPaintEvent *)
 	    bitBlt(m_pixmap, 0, 0, m_layer[i], 0, 0,
 		m_width, m_height, m_layer_rop[i]);
 	}
-	lastplaypointer = -2;
+	m_last_playpointer = -2;
     }
 
     // --- redraw the playpointer if a signal is present ---
-    playpointer = samples2pixels(
+    m_playpointer = samples2pixels(
 	m_signal_manager.playbackController().currentPos() - m_offset);
 
     if (n_tracks) {
 	p.begin(m_pixmap);
 	p.setPen(yellow);
 	p.setRasterOp(XorROP);
-	
-	if (lastplaypointer >= 0) p.drawLine(lastplaypointer, 0,
-	                                     lastplaypointer, m_height);
-	
+
+	if (m_last_playpointer >= 0)
+	    p.drawLine(m_last_playpointer, 0, m_last_playpointer, m_height);
+
 	if ( (m_signal_manager.playbackController().running() ||
 	      m_signal_manager.playbackController().paused() ) &&
-	     ((playpointer >= 0) && (playpointer < m_width)) )
+	     ((m_playpointer >= 0) && (m_playpointer < m_width)) )
 	{
-	    p.drawLine(playpointer, 0, playpointer, m_height);
-	    lastplaypointer = playpointer;
+	    p.drawLine(m_playpointer, 0, m_playpointer, m_height);
+	    m_last_playpointer = m_playpointer;
 	} else {
-	    lastplaypointer = -1;
+	    m_last_playpointer = -1;
 	}
-	
+
 	p.end();
     }
 
@@ -1112,7 +1137,7 @@ void SignalWidget::paintEvent(QPaintEvent *)
 //    gettimeofday(&t_end,0);
 //    t_elapsed = ((double)t_end.tv_sec*1.0E6+(double)t_end.tv_usec -
 //	((double)t_start.tv_sec*1.0E6+(double)t_start.tv_usec)) * 1E-3;
-//    debug("SignalWidget::paintEvent() -- done, t=%0.3fms --",
+//    qDebug("SignalWidget::paintEvent() -- done, t=%0.3fms --",
 //	t_elapsed); // ###
 //#endif
 }
@@ -1167,7 +1192,7 @@ LabelType *findMarkerType (const char */*txt*/)
 //	if (strcmp (act->name, txt) == 0) return act;
 //	cnt++;
 //    }
-//    warning("could not find Labeltype %s\n", txt);
+//    qWarning("could not find Labeltype %s\n", txt);
     return 0;
 }
 
@@ -1215,7 +1240,7 @@ LabelType *findMarkerType (const char */*txt*/)
 //    QString name = KFileDialog::getSaveFileName (0, "*.label", this);
 //    if (!name.isNull()) {
 //	FILE *out;
-//	out = fopen (name.data(), "w");
+//	out = fopen (name.latin1(), "w");
 //
 //	Parser parser (typestring);
 //	Label *tmp;
@@ -1352,7 +1377,7 @@ LabelType *findMarkerType (const char */*txt*/)
 //
 //	    QString name = KFileDialog::getSaveFileName (0, "*.dat", this);
 //	    if (!name.isNull()) {
-//		QFile out(name.data());
+//		QFile out(name.latin1());
 //		char buf[160];
 //		float freq = 0, time, lastfreq = 0;
 //		out.open (IO_WriteOnly);
@@ -1682,14 +1707,12 @@ void SignalWidget::slotTrackInserted(unsigned int index, Track &track)
 {
     // insert a new track into the track pixmap list
     TrackPixmap *pix = new TrackPixmap(track);
-    ASSERT(pix);
+    Q_ASSERT(pix);
     m_track_pixmaps.insert(index, pix);
     if (!pix) return;
 
-    if (tracks() == 1) {
-	// first track, start with full zoom
-	zoomAll();
-    }
+    // first track: start with full zoom
+    if (tracks() == 1) zoomAll();
 
     // emit the signal sigTrackInserted now, so that the signal widget
     // gets resized if needed, but the new pixmap is still empty
@@ -1721,7 +1744,7 @@ void SignalWidget::slotTrackDeleted(unsigned int index)
 void SignalWidget::slotSamplesInserted(unsigned int /*track*/,
     unsigned int /*offset*/, unsigned int /*length*/)
 {
-//    debug("SignalWidget(): slotSamplesInserted(%u, %u,%u)", track,
+//    qDebug("SignalWidget(): slotSamplesInserted(%u, %u,%u)", track,
 //	offset, length);
 }
 
@@ -1729,7 +1752,7 @@ void SignalWidget::slotSamplesInserted(unsigned int /*track*/,
 void SignalWidget::slotSamplesDeleted(unsigned int /*track*/,
     unsigned int /*offset*/, unsigned int /*length*/)
 {
-//    debug("SignalManager(): slotSamplesDeleted(%u, %u,%u)", track,
+//    qDebug("SignalManager(): slotSamplesDeleted(%u, %u,%u)", track,
 //	offset, length);
 }
 
@@ -1737,7 +1760,7 @@ void SignalWidget::slotSamplesDeleted(unsigned int /*track*/,
 void SignalWidget::slotSamplesModified(unsigned int /*track*/,
     unsigned int /*offset*/, unsigned int /*length*/)
 {
-//    debug("SignalWidget(): slotSamplesModified(%u, %u,%u)", track,
+//    qDebug("SignalWidget(): slotSamplesModified(%u, %u,%u)", track,
 //	offset, length);
 }
 
@@ -1748,13 +1771,13 @@ void SignalWidget::startDragging()
     if (!length) return;
 
     KwaveDrag *d = new KwaveDrag(this);
-    ASSERT(d);
+    Q_ASSERT(d);
     if (!d) return;
 
     MultiTrackReader src;
     const unsigned int first = m_signal_manager.selection().first();
     const unsigned int last  = m_signal_manager.selection().last();
-    const unsigned int rate  = m_signal_manager.rate();
+    const double       rate  = m_signal_manager.rate();
     const unsigned int bits  = m_signal_manager.bits();
 
     m_signal_manager.openMultiTrackReader(src,
@@ -1823,6 +1846,11 @@ void SignalWidget::dropEvent(QDropEvent* event)
 	    unsigned int pos = m_offset + pixels2samples(event->pos().x());
 	    unsigned int len = sig.length();
 	
+	    /**
+	     * @todo after the drop operation: enter the new file info into
+	     * the signal manager if our own file was empty
+	     */
+	
 	    sig.openMultiTrackReader(src, sig.allTracks(), 0, len-1);
 	    m_signal_manager.openMultiTrackWriter(dst,
 		m_signal_manager.selectedTracks(), Insert,
@@ -1833,7 +1861,7 @@ void SignalWidget::dropEvent(QDropEvent* event)
 	    // set selection to the new area where the drop was done
 	    selectRange(pos, len);
 	} else {
-	    debug("SignalWidget::dropEvent(%s): failed !", event->format(0));
+	    qDebug("SignalWidget::dropEvent(%s): failed !", event->format(0));
 	    /** @todo abort the current undo transaction */
 	}
     } else if (KwaveFileDrag::canDecode(event)) {
@@ -1845,7 +1873,7 @@ void SignalWidget::dropEvent(QDropEvent* event)
 	}
     }
 
-    debug("SignalWidget::dropEvent(): done");
+    qDebug("SignalWidget::dropEvent(): done");
     setMouseMode(MouseNormal);
 }
 
