@@ -20,7 +20,7 @@
 
 #include "config.h"
 #include <qdragobject.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qtimer.h>
 #include <qpainter.h>
 #include <qwidget.h>
@@ -103,7 +103,7 @@ public:
                    unsigned int bits, unsigned int tracks);
 
     /** @todo (re)implementation */
-    int saveFile(const KURL &url, unsigned int bits, bool selection = false);
+    int saveFile(const KURL &url, bool selection = false);
 
     /** @todo (re)implementation */
     void saveBlocks (int);
@@ -150,9 +150,6 @@ public:
      */
     int tracks();
 
-    /** returns the number of bits per sample of the current signal */
-    unsigned int bits();
-
     /** returns the signal manager of the current signal */
     SignalManager &signalManager();
 
@@ -176,6 +173,7 @@ public slots:
      */
     void selectRange(unsigned int offset, unsigned int length);
 
+    /** forward a sigCommand to the next layer */
     void forwardCommand(const QString &command);
 
     /**
@@ -264,7 +262,8 @@ private slots:
 
     /**
      * Connected to the signal's sigTrackInserted.
-     * @param track index of the inserted track
+     * @param index numeric index of the inserted track
+     * @param track reference to the inserted track
      * @see Signal::sigTrackInserted
      * @internal
      */
@@ -272,7 +271,7 @@ private slots:
 
     /**
      * Connected to the signal's sigTrackDeleted.
-     * @param track index of the deleted track
+     * @param index numeric index of the deleted track
      * @see Signal::sigTrackInserted
      * @internal
      */
@@ -347,10 +346,11 @@ signals:
                   unsigned int length);
 
     /**
-     * Emits the length of the current selection in
-     * samples and in milliseconds
+     * Emits the offset and length of the current selection and the
+     * sample rate for converting it into milliseconds
      */
-    void selectedTimeInfo(unsigned int samples, double ms);
+    void selectedTimeInfo(unsigned int offset, unsigned int length,
+                          double rate);
 
     /**
      * Emits a command to be processed by the next higher instance.
@@ -440,10 +440,19 @@ protected:
      */
     double getFullZoom();
 
+    /** slot for detecting resizing of the widget */
     void resizeEvent(QResizeEvent *);
+
+    /** slot for mouse press, used for selection and drag&drop */
     void mousePressEvent(QMouseEvent *);
+
+    /** slot for mouse release, used for selection and drag&drop */
     void mouseReleaseEvent(QMouseEvent *);
+
+    /** slot for mouse moves, used for selection and drag&drop */
     void mouseMoveEvent(QMouseEvent *);
+
+    /** slot for repainting the widget or portions of it */
     void paintEvent(QPaintEvent *);
 
 //    void loadLabel ();
@@ -455,7 +464,6 @@ protected:
 //    void markSignal (const char *);
 //    void markPeriods (const char *);
 //    void savePeriods ();
-
 //    bool executeLabelCommand(const QString &command);
 
     /**
@@ -491,7 +499,7 @@ private:
     /**
      * Converts a pixel offset into a sample index using the current zoom
      * value. Always rounds op or downwards.
-     * @param sample index of the sample
+     * @param samples number of samples to be converted
      * @return pixel offset
      */
     int samples2pixels(int samples);
@@ -525,19 +533,33 @@ private:
      */
     unsigned int m_offset;
 
+    /** width of the widget in pixels, cached value */
     int m_width;
-    int m_height;            //of this widget
-    int lastWidth;
-    int lastHeight;
+
+    /** height of the widget in pixels, cached value */
+    int m_height;
+
+    /** last/previous width of the widget, for detecting size changes */
+    int m_last_width;
+
+    /** last/previous height of the widget, for detecting size changes */
+    int m_last_height;
 
     /** number of samples per pixel */
     double m_zoom;
 
-    //vertical line on the screen
-    int playpointer, lastplaypointer;
+    /**
+     * position of the vertical line that indicates the current
+     * playback position in [pixels] from 0...m_width-1. If no playback
+     * is running the value is negative.
+     */
+    int m_playpointer;
 
-    // flag for redrawing pixmap
-    bool redraw;
+    /** last/previous value of m_playpointer, for detecting changes */
+    int m_last_playpointer;
+
+    /** if set, m_pixmap has to be redrawn */
+    bool m_redraw;
 
     /**
      * Counter for inhibiting repaints. If not zero, repaints should
@@ -553,7 +575,7 @@ private:
     SignalManager m_signal_manager;
 
     /** list of track pixmaps */
-    QList<TrackPixmap> m_track_pixmaps;
+    QPtrList<TrackPixmap> m_track_pixmaps;
 
     /** pixmap for avoiding flicker */
     QPixmap *m_pixmap;
