@@ -30,6 +30,7 @@
 #include <qdir.h>
 #include <qevent.h>
 #include <qframe.h>
+#include <qstringlist.h>
 #include <qtoolbutton.h>
 #include <qtooltip.h>
 
@@ -44,14 +45,13 @@
 #include <kstddirs.h>
 #include <ktoolbarbutton.h>
 
+#include "libkwave/KwavePlugin.h" // for some helper functions
 #include "libkwave/FileLoader.h"
 #include "libkwave/LineParser.h"
 #include "libkwave/Parser.h"
 
-#include "libgui/Dialog.h"
 #include "libgui/MenuManager.h"
 #include "libgui/KwaveFileDialog.h"
-#include "libgui/KwavePlugin.h" // for some helper functions
 
 #include "mt/ThreadsafeX11Guard.h"
 
@@ -87,12 +87,6 @@
 #include "toolbar/zoomnormal.xpm"
 #include "toolbar/zoomall.xpm"
 
-#ifdef HAVE_KDEVERSION_H
-#include <kdeversion.h>
-#else
-#define KDE_VERSION_MAJOR 2
-#endif
-
 #ifndef min
 #define min(x,y) (( (x) < (y) ) ? (x) : (y) )
 #endif
@@ -151,7 +145,6 @@ TopWidget::TopWidget(KwaveApp &main_app)
     int id=1000; // id of toolbar items
     KIconLoader icon_loader;
 
-    m_save_bits = 16;
     m_blink_on = false;
     m_id_undo = -1;
     m_id_redo = -1;
@@ -168,14 +161,14 @@ TopWidget::TopWidget(KwaveApp &main_app)
     m_zoomselect = 0;
 
     KMenuBar *menubar = menuBar();
-    ASSERT(menubar);
+    Q_ASSERT(menubar);
     if (!menubar) return;
     m_menu_manager = new MenuManager(this, *menubar);
-    ASSERT(m_menu_manager);
+    Q_ASSERT(m_menu_manager);
     if (!m_menu_manager) return;
 
     m_plugin_manager = new PluginManager(*this);
-    ASSERT(m_plugin_manager);
+    Q_ASSERT(m_plugin_manager);
     if (!m_plugin_manager) return;
     if (!m_plugin_manager->isOK()) {
 	delete m_plugin_manager;
@@ -194,7 +187,7 @@ TopWidget::TopWidget(KwaveApp &main_app)
 
 
     KStatusBar *status_bar = statusBar();
-    ASSERT(status_bar);
+    Q_ASSERT(status_bar);
     if (!status_bar) return;
     status_bar->insertItem("", STATUS_ID_SIZE);
     status_bar->insertItem("", STATUS_ID_MODE);
@@ -204,17 +197,17 @@ TopWidget::TopWidget(KwaveApp &main_app)
     // load the menu from file
     QString menufile = locate("data", "kwave/menus.config");
     FileLoader loader(menufile);
-    ASSERT(loader.buffer());
+    Q_ASSERT(loader.buffer());
     if (loader.buffer()) parseCommands(loader.buffer());
     updateMenu();
 
     updateRecentFiles();
 
     m_main_widget = new MainWidget(this);
-    ASSERT(m_main_widget);
+    Q_ASSERT(m_main_widget);
     if (!m_main_widget) return;
     if (!(m_main_widget->isOK())) {
-	warning("TopWidget::TopWidget(): failed at creating main widget");
+	qWarning("TopWidget::TopWidget(): failed at creating main widget");
 	delete m_main_widget;
 	m_main_widget=0;
 	return;
@@ -223,8 +216,10 @@ TopWidget::TopWidget(KwaveApp &main_app)
     // connect the main widget
     connect(m_main_widget, SIGNAL(sigCommand(const QString &)),
             this, SLOT(executeCommand(const QString &)));
-    connect(m_main_widget, SIGNAL(selectedTimeInfo(unsigned int, double)),
-            this, SLOT(setSelectedTimeInfo(unsigned int, double)));
+    connect(m_main_widget, SIGNAL(selectedTimeInfo(unsigned int,
+            unsigned int, double)),
+            this, SLOT(setSelectedTimeInfo(unsigned int, unsigned int,
+            double)));
     connect(m_main_widget, SIGNAL(sigTrackCount(unsigned int)),
             this, SLOT(setTrackInfo(unsigned int)));
     connect(m_main_widget, SIGNAL(sigMouseChanged(int)),
@@ -238,7 +233,7 @@ TopWidget::TopWidget(KwaveApp &main_app)
     // --- set up the toolbar ---
 
     m_toolbar = new KToolBar(this, "toolbar", true, true);
-    ASSERT(m_toolbar);
+    Q_ASSERT(m_toolbar);
     if (!m_toolbar) return;
     m_toolbar->setBarPos(KToolBar::Top);
     m_toolbar->setHorizontalStretchable(false);
@@ -267,7 +262,7 @@ TopWidget::TopWidget(KwaveApp &main_app)
 
     // separator between file and edit
     QFrame *separator1 = new QFrame(m_toolbar, "separator line");
-    ASSERT(separator1);
+    Q_ASSERT(separator1);
     if (!separator1) return;
     separator1->setFrameStyle(QFrame::VLine | QFrame::Sunken);
     separator1->setFixedWidth(separator1->sizeHint().width());
@@ -330,7 +325,7 @@ TopWidget::TopWidget(KwaveApp &main_app)
 
     // separator between edit and playback
     QFrame *separator = new QFrame(m_toolbar, "separator line");
-    ASSERT(separator);
+    Q_ASSERT(separator);
     if (!separator) return;
     separator->setFrameStyle(QFrame::VLine | QFrame::Sunken);
     separator->setFixedWidth(separator->sizeHint().width());
@@ -367,7 +362,7 @@ TopWidget::TopWidget(KwaveApp &main_app)
 
     // separator between playback and zoom
     QFrame *separator3 = new QFrame(m_toolbar, "separator line");
-    ASSERT(separator3);
+    Q_ASSERT(separator3);
     if (!separator3) return;
     separator3->setFrameStyle(QFrame::VLine | QFrame::Sunken);
     separator3->setFixedWidth(separator3->sizeHint().width());
@@ -409,13 +404,9 @@ TopWidget::TopWidget(KwaveApp &main_app)
 	i18n("zoom to all"));
     m_id_zoomall = id++;
 
-#if KDE_VERSION_MAJOR >= 3
     // add a dummy placeholder, otherwise the minimum size will be wrong
     QStringList factors(m_zoom_factors);
     factors.append(" 99:99 min ");
-#else
-    QStringList &factors = m_zoom_factors;
-#endif
     m_id_zoomselect = id++;
     m_toolbar->insertCombo(factors, m_id_zoomselect,
 	true, SIGNAL(activated(int)),
@@ -424,19 +415,10 @@ TopWidget::TopWidget(KwaveApp &main_app)
     connect(m_main_widget, SIGNAL(sigZoomChanged(double)),
             this, SLOT(setZoomInfo(double)));
     m_zoomselect = m_toolbar->getCombo(m_id_zoomselect);
-    ASSERT(m_zoomselect);
+    Q_ASSERT(m_zoomselect);
     if (!m_zoomselect) return;
 
-#if KDE_VERSION_MAJOR < 3
-    m_zoomselect->adjustSize();
     int h = m_zoomselect->sizeHint().height();
-    m_zoomselect->setFixedHeight(h);
-    m_zoomselect->setMinimumWidth(
-        max(m_zoomselect->sizeHint().width()+20,3*h));
-    m_zoomselect->setAutoResize(false);
-#else
-    int h = m_zoomselect->sizeHint().height();
-#endif
     m_zoomselect->setFocusPolicy(QWidget::NoFocus);
 
     m_toolbar->setMinimumHeight(max(m_zoomselect->sizeHint().height()+2,
@@ -458,9 +440,9 @@ TopWidget::TopWidget(KwaveApp &main_app)
     // connect the signal manager
     SignalManager *signal_manager = &(m_main_widget->signalManager());
     connect(signal_manager, SIGNAL(sigStatusInfo(unsigned int, unsigned int,
-	unsigned int, unsigned int)),
+	double, unsigned int)),
 	this, SLOT(setStatusInfo(unsigned int, unsigned int,
-	unsigned int, unsigned int)));
+	double, unsigned int)));
     connect(signal_manager, SIGNAL(sigUndoRedoInfo(const QString&,
 	const QString&)),
 	this, SLOT(setUndoRedoInfo(const QString&, const QString&)));
@@ -492,22 +474,29 @@ TopWidget::TopWidget(KwaveApp &main_app)
 	}
     }
 
+    // load previous window size
+    KConfig *cfg = KGlobal::config();
+    cfg->setGroup(settingsGroup());
+    restoreWindowSize(cfg);
+
     // set a nice initial size
     w = wmax;
     w = max(w, m_main_widget->minimumSize().width());
     w = max(w, m_main_widget->sizeHint().width());
     w = max(w, m_toolbar->sizeHint().width());
+    w = max(w, width());
     h = max(m_main_widget->sizeHint().height(), w*6/10);
+    h = max(h, height());
     resize(w, h);
 
     setStatusInfo(0,0,0,0);
     setUndoRedoInfo(0,0);
-    setSelectedTimeInfo(0,0);
+    setSelectedTimeInfo(0,0,0);
 
     // check if the aRts dispatcher is functional. if not, we better
     // should exit now, as most of the plugins would not work
     if (!m_plugin_manager->artsDispatcher()) {
-	warning("no aRts dispatcher found -> exit !!!");
+	qWarning("no aRts dispatcher found -> exit !!!");
 	KMessageBox::error(this, i18n(
 	    "<b>Sorry, but since version 0.6.2 you need a running "\
 	    "aRts sound server for using kwave.</b><br>"\
@@ -519,7 +508,7 @@ TopWidget::TopWidget(KwaveApp &main_app)
 	));
 	qApp->exit();
 	return;
-    };
+    }
 
     // now we are initialized, load all plugins now
     statusBar()->message(i18n("Loading plugins..."));
@@ -529,20 +518,33 @@ TopWidget::TopWidget(KwaveApp &main_app)
     setTrackInfo(0);
     updateMenu();
 
-#if KDE_VERSION_MAJOR >= 3
     // layout is finished, remove dummy/placeholder zoom entry
     m_zoomselect->removeItem(m_zoomselect->count()-1);
-#endif
+
+    // make sure that everything of our window is visible
+    QRect desk = qApp->desktop()->rect();
+    QRect g    = this->geometry();
+    if (!desk.contains(g)) {
+	// KDE's stupid geometry management has failed ?
+	// this happens when one passes "-geometry <WIDTH>x<HEIGTH>" without
+	// specifying a target position!?
+	// passing "-geometry <WIDTH>x<HEIGHT>-<LEFT>-<TOP>" works...
+	g = desk.intersect(g);
+	setGeometry(g);
+    }
+
+    // enable saving of window size and position for next startup
+    setAutoSaveSettings();
 }
 
 //***************************************************************************
 bool TopWidget::isOK()
 {
-    ASSERT(m_menu_manager);
-    ASSERT(m_main_widget);
-    ASSERT(m_plugin_manager);
-    ASSERT(m_toolbar);
-    ASSERT(m_zoomselect);
+    Q_ASSERT(m_menu_manager);
+    Q_ASSERT(m_main_widget);
+    Q_ASSERT(m_plugin_manager);
+    Q_ASSERT(m_toolbar);
+    Q_ASSERT(m_zoomselect);
 
     return ( m_menu_manager && m_main_widget &&
 	m_plugin_manager && m_toolbar && m_zoomselect &&
@@ -554,6 +556,11 @@ TopWidget::~TopWidget()
 {
     ThreadsafeX11Guard x11_guard;
 
+    // save the window size
+    KConfig *cfg = KGlobal::config();
+    cfg->setGroup(settingsGroup());
+    saveWindowSize(cfg);
+
     // close the current file (no matter what the user wants)
     closeFile();
 
@@ -580,7 +587,7 @@ int TopWidget::executeCommand(const QString &line)
     bool use_recorder = true;
     QString command = line;
 
-//    debug("TopWidget::executeCommand(%s)", command.data()); // ###
+//    qDebug("TopWidget::executeCommand(%s)", command.latin1()); // ###
     if (!command.length()) return 0; // empty line -> nothing to do
     if (command.stripWhiteSpace().startsWith("#")) return 0; // only a comment
 
@@ -591,15 +598,15 @@ int TopWidget::executeCommand(const QString &line)
 	QStringList macro = parse_list.commandList();
 	for (QStringList::Iterator it=macro.begin(); it!=macro.end(); ++it) {
 	    result = executeCommand("nomacro:"+(*it));
-	    ASSERT(!result);
+	    Q_ASSERT(!result);
 	    if (result) {
-		warning("macro execution of '%s' failed: %d",
-		        (*it).data(), result);
+		qWarning("macro execution of '%s' failed: %d",
+		        (*it).latin1(), result);
 		return result; // macro failed :-(
 	    }
 	
 	    // wait until the command has completed !
-	    ASSERT(m_plugin_manager);
+	    Q_ASSERT(m_plugin_manager);
 	    if (m_plugin_manager) m_plugin_manager->sync();
 	}
 	return result;
@@ -623,17 +630,17 @@ int TopWidget::executeCommand(const QString &line)
 	int cnt=parser.count();
 	if (cnt > 1) {
 	    params = new QStringList();
-	    ASSERT(params);
+	    Q_ASSERT(params);
 	    while (params && cnt--) {
 		const QString &par = parser.nextParam();
-		debug("TopWidget::executeCommand(): %s", par.data());
+		qDebug("TopWidget::executeCommand(): %s", par.latin1());
 		params->append(par);
 	    }
 	}
-	debug("TopWidget::executeCommand(): loading plugin '%s'",name.data());
-	debug("TopWidget::executeCommand(): with %d parameter(s)",
+	qDebug("TopWidget::executeCommand(): loading plugin '%s'",name.latin1());
+	qDebug("TopWidget::executeCommand(): with %d parameter(s)",
 		(params) ? params->count() : 0);
-	ASSERT(m_plugin_manager);
+	Q_ASSERT(m_plugin_manager);
 	if (m_plugin_manager)
 	    result = m_plugin_manager->executePlugin(name, params);
     CASE_COMMAND("plugin:execute")
@@ -643,17 +650,17 @@ int TopWidget::executeCommand(const QString &line)
 	while (--cnt > 0) {
 	    params.append(parser.nextParam());
 	}
-	ASSERT(m_plugin_manager);
+	Q_ASSERT(m_plugin_manager);
 	result = (m_plugin_manager) ?
 	          m_plugin_manager->executePlugin(name, &params) : -ENOMEM;
     CASE_COMMAND("plugin:setup")
 	QString name(parser.firstParam());
-	ASSERT(m_plugin_manager);
+	Q_ASSERT(m_plugin_manager);
 	if (m_plugin_manager) result = m_plugin_manager->setupPlugin(name);
     CASE_COMMAND("menu")
-	ASSERT(m_menu_manager);
+	Q_ASSERT(m_menu_manager);
 	if (m_menu_manager) /*result = */m_menu_manager->executeCommand(command);
-    CASE_COMMAND("newsignal");
+    CASE_COMMAND("newsignal")
 	unsigned int samples = parser.toUInt();
 	double       rate    = parser.toDouble();
 	unsigned int bits    = parser.toUInt();
@@ -676,8 +683,6 @@ int TopWidget::executeCommand(const QString &line)
 	result = saveFile();
     CASE_COMMAND("close")
 	result = closeFile();
-    CASE_COMMAND("resolution")
-	result = resolution(command);
     CASE_COMMAND("revert")
 	result = revert();
     CASE_COMMAND("saveas")
@@ -689,7 +694,7 @@ int TopWidget::executeCommand(const QString &line)
     CASE_COMMAND("quit")
 	result = close();
     } else {
-	ASSERT(m_main_widget);
+	Q_ASSERT(m_main_widget);
 	result = (m_main_widget &&
 	    m_main_widget->executeCommand(command)) ? 0 : -1;
     }
@@ -713,7 +718,7 @@ int TopWidget::loadBatch(const QString &str)
 //***************************************************************************
 int TopWidget::executePlaybackCommand(const QString &command)
 {
-    ASSERT(m_main_widget);
+    Q_ASSERT(m_main_widget);
     if (!m_main_widget) return -1;
 
     PlaybackController &controller = m_main_widget->playbackController();
@@ -736,7 +741,7 @@ int TopWidget::executePlaybackCommand(const QString &command)
 //***************************************************************************
 SignalManager &TopWidget::signalManager()
 {
-    ASSERT(m_main_widget);
+    Q_ASSERT(m_main_widget);
     return m_main_widget->signalManager();
 }
 
@@ -757,34 +762,19 @@ int TopWidget::parseCommands(const QByteArray &buffer)
 //***************************************************************************
 int TopWidget::revert()
 {
-    ASSERT(m_url.isValid() && !m_url.isMalformed());
+    Q_ASSERT(m_url.isValid() && !m_url.isMalformed());
     if (!m_url.isValid() || m_url.isMalformed()) return -EINVAL;
 
     KURL url(m_url);
     return loadFile(url);
 }
 
-//***************************************************************************
-int TopWidget::resolution(const QString &str)
-{
-    Parser parser (str);
-    int bps = parser.toInt();
-
-    if ( (bps >= 0) && (bps <= 24) && (bps % 8 == 0)) {
-	m_save_bits = bps;
-	return 0;
-    } else {
-	warning("out of range");
-	return -EINVAL;
-    }
-}
-
 //***************************************************************************
 bool TopWidget::closeFile()
 {
     ThreadsafeX11Guard x11_guard;
 
-    ASSERT(m_main_widget);
+    Q_ASSERT(m_main_widget);
     if (signalManager().isModified()) {
 	int res =  KMessageBox::warningYesNoCancel(this,
 	    i18n("This file has been modified.\nDo you want to save it?"));
@@ -792,7 +782,7 @@ bool TopWidget::closeFile()
 	if (res == KMessageBox::Yes) {
 	    // user decided to save
 	    res = saveFile();
-	    debug("TopWidget::closeFile()::saveFile, res=%d",res);
+	    qDebug("TopWidget::closeFile()::saveFile, res=%d",res);
 	    if (res) return false;
 	}
     }
@@ -814,11 +804,11 @@ bool TopWidget::closeFile()
 //***************************************************************************
 int TopWidget::loadFile(const KURL &url)
 {
-    ASSERT(m_main_widget);
+    Q_ASSERT(m_main_widget);
     if (!m_main_widget) return -1;
 
     // abort if new file not valid and local
-    ASSERT(url.isLocalFile());
+    Q_ASSERT(url.isLocalFile());
     if (!url.isLocalFile()) return -1;
 
     // try to close the previous file
@@ -830,7 +820,6 @@ int TopWidget::loadFile(const KURL &url)
 	// succeeded
 	m_url = url;
 	updateCaption();
-	m_save_bits = m_main_widget->bits();
     } else {
 	// load failed
 	closeFile();
@@ -853,7 +842,7 @@ int TopWidget::openRecent(const QString &str)
 int TopWidget::openFile()
 {
     KwaveFileDialog dlg(":<kwave_open_dir>", CodecManager::decodingFilter(),
-        this, "Kwave open file", true);
+        this, "Kwave open file", true, 0, "*.wav");
     dlg.setMode(static_cast<KFile::Mode>(KFile::File | KFile::ExistingOnly));
     dlg.setOperationMode(KFileDialog::Opening);
     dlg.setCaption(i18n("Open"));
@@ -865,11 +854,15 @@ int TopWidget::openFile()
 int TopWidget::saveFile()
 {
     int res = 0;
-    ASSERT(m_main_widget);
+    Q_ASSERT(m_main_widget);
     if (!m_main_widget) return -EINVAL;
 
     if (signalName() != NEW_FILENAME) {
-	res = m_main_widget->saveFile(m_url, m_save_bits, false);
+	res = m_main_widget->saveFile(m_url, false);
+
+	// if saving in current format is not possible (no encoder),
+	// then try to "save/as" instead...
+	if (res == -EMEDIUMTYPE) res = saveFileAs(false);
     } else res = saveFileAs(false);
 
     updateCaption();
@@ -882,29 +875,27 @@ int TopWidget::saveFile()
 int TopWidget::saveFileAs(bool selection)
 {
     int res = 0;
-    ASSERT(m_main_widget);
+    Q_ASSERT(m_main_widget);
     if (!m_main_widget) return -EINVAL;
 
-    KwaveFileDialog dlg(":<kwave_save_dir>", CodecManager::encodingFilter(),
-        this, "Kwave save file", true);
-    dlg.setKeepLocation(true);
-//    dlg.setMode(static_cast<KFile::Mode>(KFile::));
+    KwaveFileDialog dlg(":<kwave_save_as>", CodecManager::encodingFilter(),
+        this, "Kwave save file", true, m_url.prettyURL(), "*.wav");
+    // dlg.setKeepLocation(true);
     dlg.setOperationMode(KFileDialog::Saving);
     dlg.setCaption(i18n("Save As"));
     if (dlg.exec() != QDialog::Accepted) return -1;
 
     KURL url = dlg.selectedURL();
-//    getSaveURL(":<kwave-savedir>",
-//	CodecManager::encodingFilter(), m_main_widget,
-//	"Kwave open file", true);
-
     if (!url.isEmpty()) {
 	QString name = url.path();
 	QFileInfo path(name);
 	
-	// add the (default) extension .wav if necessary
-	if (path.extension(false) == "") {
-	    name += ".wav";
+	// add the correct extension if necessary
+	if (!path.extension(false).length()) {
+	    QString ext = dlg.selectedExtension();
+	    QStringList extensions = QStringList::split(" ", ext);
+	    ext = extensions.first();
+	    name += ext.mid(1);
 	    path = name;
 	    url.setPath(name);
 	}
@@ -921,7 +912,46 @@ int TopWidget::saveFileAs(bool selection)
 	}
 	
 	m_url = url;
-	res = m_main_widget->saveFile(m_url, m_save_bits, selection);
+	
+	// maybe we now have a new mime type
+	QString previous_mimetype_name = signalManager().fileInfo().get(
+	    INF_MIMETYPE).toString();
+	
+	QString new_mimetype_name;
+	new_mimetype_name = CodecManager::whatContains(m_url);
+	
+	if (new_mimetype_name != previous_mimetype_name) {
+	    // saving to a different mime type
+	    // now we have to do as if the mime type and file name
+	    // has already been selected to satisfy the fileinfo
+	    // plugin
+	    qDebug("TopWidget::saveAs(%s) - [%s] (previous:'%s')",
+		m_url.prettyURL().latin1(), new_mimetype_name.latin1(),
+		previous_mimetype_name.latin1() );
+	
+	    // set the new mimetype
+	    signalManager().fileInfo().set(INF_MIMETYPE,
+	        new_mimetype_name);
+	    // save the old filename and set the new one
+	    QString old_filename = signalManager().fileInfo().get(
+	        INF_FILENAME).toString();
+	    signalManager().fileInfo().set(INF_FILENAME,
+	        m_url.prettyURL());
+	
+	    // now call the fileinfo plugin with the new filename and
+	    // mimetype
+	    Q_ASSERT(m_plugin_manager);
+	    res = (m_plugin_manager) ?
+	        res = m_plugin_manager->setupPlugin("fileinfo") : -1;
+	
+	    // restore the mime type and the filename
+	    signalManager().fileInfo().set(INF_MIMETYPE,
+	        previous_mimetype_name);
+	    signalManager().fileInfo().set(INF_FILENAME,
+	        m_url.prettyURL());
+	}
+	
+	if (!res) res = m_main_widget->saveFile(m_url, selection);
 	
 	updateCaption();
 	m_app.addRecentFile(signalName());
@@ -944,7 +974,6 @@ int TopWidget::newSignal(unsigned int samples, double rate,
     m_main_widget->newSignal(samples, rate, bits, tracks);
 
     updateCaption();
-    m_save_bits = bits;
     updateMenu();
     updateToolbar();
 
@@ -961,7 +990,7 @@ QString TopWidget::signalName()
 //***************************************************************************
 void TopWidget::selectZoom(int index)
 {
-    ASSERT(m_main_widget);
+    Q_ASSERT(m_main_widget);
     if (!m_main_widget) return;
 
     if (index < 0) return;
@@ -971,7 +1000,7 @@ void TopWidget::selectZoom(int index)
     const double rate = signalManager().rate();
     const double ms = m_zoom_factors.ms(index);
     unsigned int width = m_main_widget->displayWidth();
-    ASSERT(width > 1);
+    Q_ASSERT(width > 1);
     if (width <= 1) width = 2;
     const double new_zoom = rint(((rate*ms)/1E3)-1) / (double)(width-1);
     m_main_widget->setZoom(new_zoom);
@@ -985,16 +1014,16 @@ void TopWidget::selectZoom(int index)
 //***************************************************************************
 void TopWidget::setZoomInfo(double zoom)
 {
-    ASSERT(zoom >= 0);
-    ASSERT(m_zoomselect);
+    Q_ASSERT(zoom >= 0);
+    Q_ASSERT(m_zoomselect);
 
     if (zoom <= 0.0) return; // makes no sense or signal is empty
     if (!m_zoomselect) return;
 
     QString strZoom;
     if ((m_main_widget) && (m_main_widget->tracks())) {
-	unsigned int rate = signalManager().rate();
-	if (rate) {
+	double rate = signalManager().rate();
+	if (rate > 0) {
 	    // time display mode
 	    double ms = m_main_widget->displaySamples()*1E3/(double)rate;
 	    int s = (int)floor(ms / 1000.0);
@@ -1022,10 +1051,10 @@ void TopWidget::setZoomInfo(double zoom)
 
 //***************************************************************************
 void TopWidget::setStatusInfo(unsigned int length, unsigned int /*tracks*/,
-                              unsigned int rate, unsigned int bits)
+                              double rate, unsigned int bits)
 {
-    ASSERT(statusBar());
-    ASSERT(m_menu_manager);
+    Q_ASSERT(statusBar());
+    Q_ASSERT(m_menu_manager);
     if (!statusBar() || !m_menu_manager) return;
     double ms;
     QString txt;
@@ -1035,7 +1064,7 @@ void TopWidget::setStatusInfo(unsigned int length, unsigned int /*tracks*/,
 	txt = " "+i18n("Length: %1")+" "+i18n("(%2 samples)")+" ";
 	ms = (rate) ? (((double)length / (double)rate) * 1E3) : 0;
 	txt = txt.arg(KwavePlugin::ms2string(ms));
-	txt = txt.arg(length);
+	txt = txt.arg(KwavePlugin::dottedNumber(length));
     } else txt = "";
     statusBar()->changeItem(txt, STATUS_ID_SIZE);
 
@@ -1051,7 +1080,7 @@ void TopWidget::setStatusInfo(unsigned int length, unsigned int /*tracks*/,
 //***************************************************************************
 void TopWidget::setTrackInfo(unsigned int tracks)
 {
-    ASSERT(m_menu_manager);
+    Q_ASSERT(m_menu_manager);
     if (!m_menu_manager) return;
 
     // update the list of deletable tracks
@@ -1068,14 +1097,34 @@ void TopWidget::setTrackInfo(unsigned int tracks)
 }
 
 //***************************************************************************
-void TopWidget::setSelectedTimeInfo(unsigned int samples, double ms)
+void TopWidget::setSelectedTimeInfo(unsigned int offset, unsigned int length,
+                                    double rate)
 {
-    ASSERT(statusBar());
+    Q_ASSERT(statusBar());
     if (!statusBar()) return;
 
-    if (samples > 1) {
-	QString txt = " "+i18n("Selected: %1 (%2 samples)").arg(
-	    KwavePlugin::ms2string(ms)).arg(samples)+" ";
+    if (length > 1) {
+// show offset and length
+// Selected: 02:00...05:00 (3 min)
+// Selected: 2000...3000 (1000 samples)
+	bool sample_mode = false;
+	
+	unsigned int last = offset + ((length) ? length-1 : 0);
+	if (rate == 0) sample_mode = true; // force sample mode if rate==0
+	QString txt = " "+i18n("Selected")+": %1...%2 (%3) ";
+	if (sample_mode) {
+	    txt = txt.arg(offset).arg(last).arg(
+	          KwavePlugin::dottedNumber(length) + " " +
+	          i18n("samples"));
+	} else {
+	    double ms_first = (double)offset * 1E3 / rate;
+	    double ms_last  = (double)(last+1)   * 1E3 / rate;
+	    double ms = (ms_last - ms_first);
+	    txt = txt.arg(KwavePlugin::ms2string(ms_first)).arg(
+		KwavePlugin::ms2string(ms_last)).arg(
+		KwavePlugin::ms2string(ms));
+	}
+	
 	statusBar()->message(txt, 4000);
 	m_menu_manager->setItemEnabled("@SELECTION", true);
     } else {
@@ -1086,7 +1135,7 @@ void TopWidget::setSelectedTimeInfo(unsigned int samples, double ms)
 //***************************************************************************
 void TopWidget::setUndoRedoInfo(const QString &undo, const QString &redo)
 {
-    ASSERT(m_toolbar);
+    Q_ASSERT(m_toolbar);
     if (!m_toolbar) return;
 
     QString txt;
@@ -1099,7 +1148,7 @@ void TopWidget::setUndoRedoInfo(const QString &undo, const QString &redo)
     txt = i18n("Undo");
     if (undo_enabled) txt += " (" + undo + ")";
     button = m_toolbar->getButton(m_id_undo);
-    ASSERT(button);
+    Q_ASSERT(button);
     if (button) {
 	QToolTip::remove(button);
 	QToolTip::add(button, txt);
@@ -1110,13 +1159,13 @@ void TopWidget::setUndoRedoInfo(const QString &undo, const QString &redo)
     txt = i18n("Redo");
     if (redo_enabled) txt += " (" + redo + ")";
     button = m_toolbar->getButton(m_id_redo);
-    ASSERT(button);
+    Q_ASSERT(button);
     if (button) {
 	QToolTip::remove(button);
 	QToolTip::add(button, txt);
     }
 
-    ASSERT(m_menu_manager);
+    Q_ASSERT(m_menu_manager);
     if (!m_menu_manager) return;
 
     // set new enable and text of the undo menu entry
@@ -1139,21 +1188,21 @@ void TopWidget::mouseChanged(int mode)
 	case (SignalWidget::MouseAtSelectionBorder) :
 	case (SignalWidget::MouseInSelection) :
 	{
-	    unsigned int rate = signalManager().rate();
-	    if (!rate) break;
-	    unsigned int samples = signalManager().selection().length();
-	    double ms = samples * 1E3 / rate;
-	    setSelectedTimeInfo(samples, ms);
+	    double rate         = signalManager().rate();
+	    unsigned int offset = signalManager().selection().offset();
+	    unsigned int length = signalManager().selection().length();
+	    setSelectedTimeInfo(offset, length, rate);
 	    break;
 	}
-	default: ;
+	default:
+	    ;
     }
 }
 
 //***************************************************************************
 void TopWidget::updateRecentFiles()
 {
-    ASSERT(m_menu_manager);
+    Q_ASSERT(m_menu_manager);
     if (!m_menu_manager) return;
 
     m_menu_manager->clearNumberedMenu("ID_FILE_OPEN_RECENT");
@@ -1161,7 +1210,7 @@ void TopWidget::updateRecentFiles()
     QStringList recent_files = m_app.recentFiles();
     QStringList::Iterator it;
     for (it = recent_files.begin(); it != recent_files.end(); ++it) {
-	ASSERT(it != 0);
+	Q_ASSERT(it != 0);
 	if (it == 0) break;
 	m_menu_manager->addNumberedMenuEntry("ID_FILE_OPEN_RECENT", *it);
     }
@@ -1170,12 +1219,9 @@ void TopWidget::updateRecentFiles()
 //***************************************************************************
 void TopWidget::updateMenu()
 {
-    ASSERT(m_menu_manager);
+    Q_ASSERT(m_menu_manager);
     if (!m_menu_manager) return;
 
-    QString bps = QString("ID_FILE_SAVE_RESOLUTION_%1").arg(m_save_bits);
-    m_menu_manager->selectItem("@BITS_PER_SAMPLE", bps);
-
     // enable/disable all items that depend on having a file
     bool have_file = (signalName().length() != 0);
     m_menu_manager->setItemEnabled("@NOT_CLOSED", have_file);
@@ -1184,8 +1230,8 @@ void TopWidget::updateMenu()
 //***************************************************************************
 void TopWidget::updateToolbar()
 {
-    ASSERT(m_toolbar);
-    ASSERT(m_main_widget);
+    Q_ASSERT(m_toolbar);
+    Q_ASSERT(m_main_widget);
     if (!m_toolbar) return;
     if (!m_main_widget) return;
 
@@ -1204,8 +1250,8 @@ void TopWidget::updateToolbar()
 //***************************************************************************
 void TopWidget::updatePlaybackControls()
 {
-    ASSERT(m_toolbar);
-    ASSERT(m_main_widget);
+    Q_ASSERT(m_toolbar);
+    Q_ASSERT(m_main_widget);
     if (!m_toolbar) return;
     if (!m_main_widget) return;
 
@@ -1221,7 +1267,7 @@ void TopWidget::updatePlaybackControls()
 	// NOTE: working with toolbar->getButton is ugly and NOT
 	//       recommended, but the only way this works in KDE3 :-(
 	KToolBarButton *button = m_toolbar->getButton(m_id_pause);
-	ASSERT(button);
+	Q_ASSERT(button);
 	if (!button) return;
 	button->setDefaultPixmap(xpm_pause);
 	
@@ -1256,7 +1302,7 @@ void TopWidget::playbackPaused()
 
     if (!m_pause_timer) {
 	m_pause_timer = new QTimer(this);
-	ASSERT(m_pause_timer);
+	Q_ASSERT(m_pause_timer);
 	if (!m_pause_timer) return;
 
 	m_pause_timer->start(500, false);
@@ -1270,13 +1316,13 @@ void TopWidget::playbackPaused()
 //***************************************************************************
 void TopWidget::blinkPause()
 {
-    ASSERT(m_toolbar);
+    Q_ASSERT(m_toolbar);
     if (!m_toolbar) return;
 
     // NOTE: working with toolbar->getButton is ugly and NOT
     //       recommended, but the only way this works in KDE3 :-(
     KToolBarButton *button = m_toolbar->getButton(m_id_pause);
-    ASSERT(button);
+    Q_ASSERT(button);
     if (!button) return;
     button->setDefaultPixmap(m_blink_on ? xpm_pause2 : xpm_pause);
 
@@ -1291,7 +1337,7 @@ void TopWidget::blinkPause()
 //***************************************************************************
 void TopWidget::pausePressed()
 {
-    ASSERT(m_main_widget);
+    Q_ASSERT(m_main_widget);
     if (!m_main_widget) return;
 
     bool have_signal = (m_main_widget->tracks());
