@@ -20,7 +20,7 @@
 #define _UNDO_DELETE_TRACK_H_
 
 #include "config.h"
-#include <qarray.h>
+#include <qmemarray.h>
 #include <qstring.h>
 #include "libkwave/Sample.h"
 #include "kwave/UndoAction.h"
@@ -74,7 +74,7 @@ protected:
     unsigned int m_length;
 
     /** Buffer with undo data */
-    QArray<sample_t> m_buffer;
+    QMemArray<sample_t> m_buffer;
 
 };
 
