@@ -29,10 +29,10 @@
 #include <klocale.h>
 #include <kcmdlineargs.h>
 
-#include <artsc/artsc.h> // for arts_init()
 #include <arts/artsflow.h>
 
 #include "KwaveApp.h"
+#include "KwaveSplash.h"
 
 static KCmdLineOptions options[] =
 {
@@ -69,8 +69,12 @@ void addDataStrings(KAboutData& aboutdata)
                     "rwaspe@web.de",
                     0);
     aboutdata.addAuthor("Caulier Gilles",
-                     i18n("french translation"),
+                     i18n("french translations, splashscreen, tests and bugsfix"),
                      "caulier.gilles@free.fr",
+                     "http://caulier.gilles.free.fr");
+    aboutdata.addAuthor("Dave Flogeras",
+                     i18n("notch filter plugin"),
+                     "d.flogeras@unb.ca",
                      0);
 
     // people who helped
@@ -86,6 +90,14 @@ void addDataStrings(KAboutData& aboutdata)
                      i18n("debian packager"),
                      "aurel32@debian.org",
                      0);
+    aboutdata.addCredit("Robert Leslie",
+                     i18n("author of the 'mad' mp3 decoder library"),
+                     "rob@mars.org",
+                     "http://www.mars.org/home/rob/proj/mpeg");
+    aboutdata.addCredit("T.H.F. Klok and Cedric Tefft",
+                     i18n("maintainers of the 'id3lib' library"),
+                     0,
+                     "http://www.id3lib.org/");
     aboutdata.addCredit("Michael Pruett",
                      i18n("author of the 'audiofile' library"),
                      "mpruett@sgi.com",
@@ -100,26 +112,11 @@ void addDataStrings(KAboutData& aboutdata)
 //***************************************************************************
 int main( int argc, char **argv )
 {
-    /*
-     * This is a work-around to avoid problems/crashes with the aRts
-     * dispatcher. Maybe this can be removed when it gets possible
-     * to create/delete Arts::Dispatcher objects without crashing in
-     * Arts::GlobalX11Comm.  (maybe in KDE-3 ?)
-     *
-     * Meanwhile we avoid the creation of new new dispatchers and only
-     * use the one that is created implicitely by this call to the artsc
-     * interface.
-     */
-    int errorcode = arts_init();
-    if (errorcode < 0) {
-	warning("arts_init error: %s", arts_error_text(errorcode));
-    }
-
     KAboutData about(
 	PACKAGE,
 	"Kwave",
-	VERSION,
-	i18n("sound editor for KDE2"),
+	PACKAGE_VERSION,
+	i18n("sound editor for KDE3"),
 	KAboutData::License_GPL_V2,
         "(c) 2002, Thomas Eschenbacher",
 	"", //TODO : i18n("");
@@ -134,12 +131,18 @@ int main( int argc, char **argv )
 
 #ifdef UNIQUE_APP
     if (!KUniqueApplication::start()) {
-	warning("Kwave is already running!");
+	qWarning("Kwave is already running!");
 	exit(0);
     }
 #endif // UNIQUE_APP
 
+
     KwaveApp app;
+
+    static KwaveSplash *splash = new KwaveSplash("pics/kwave-splash.png");
+    Q_ASSERT(splash);
+    if (splash) splash->show();
+
     return app.exec();
 }
 
