@@ -31,30 +31,28 @@
 #include <kmessagebox.h>
 #include <kprogress.h>
 
-#include "libgui/KwavePlugin.h"  // for ms2string
+#include "libkwave/KwavePlugin.h"  // for ms2string
 #include "libgui/FileProgress.h"
 
-#ifndef HAVE_KDEVERSION_H
-#define KDE_VERSION_MAJOR 2
-#else
-#include <kdeversion.h>
-#endif
-
 //***************************************************************************
 FileProgress::FileProgress(QWidget *parent,
 	const QUrl &url, unsigned int size,
-	unsigned int samples, unsigned int rate, unsigned int bits,
+	unsigned int samples, double rate, unsigned int bits,
 	unsigned int tracks)
-    :QSemiModal(parent, "FileProgress", true),
+    :KDialog(parent, "FileProgress", true),
     m_url(url),
     m_size(size),
     m_lbl_url(0),
+    m_lbl_length(0),
     m_progress(0),
     m_stat_transfer(0),
     m_stat_bytes(0),
     m_time(),
     m_cancelled(true),
-    m_last_percent(0)
+    m_last_percent(0),
+    m_bits_per_sample(bits),
+    m_sample_rate(rate),
+    m_tracks(tracks)
 {
     QString text;
 
@@ -66,12 +64,12 @@ FileProgress::FileProgress(QWidget *parent,
 
     // toplevel uses a vbox layout
     QVBoxLayout *top_layout = new QVBoxLayout(this, 10, 10);
-    ASSERT(top_layout);
+    Q_ASSERT(top_layout);
     if (!top_layout) return;
 
     // sublayout for the lines with the file info
     QGridLayout *info_layout = new QGridLayout(5, 2, 0);
-    ASSERT(info_layout);
+    Q_ASSERT(info_layout);
     if (!info_layout) return;
     info_layout->setColStretch(0,0);
     info_layout->setColStretch(1,100);
@@ -85,16 +83,10 @@ FileProgress::FileProgress(QWidget *parent,
 
     // label with "length"
     if (!addInfoLabel(info_layout, i18n("length: "), 1, 0)) return;
-
-    // length in samples -> h:m:s
-    if (rate) {
-	// length in ms
-	text = KwavePlugin::ms2string((float)samples/(float)rate*1000.0);
-    } else {
-	// fallback if no rate: length in samples
-        text = i18n("%1 samples").arg(samples);
-    }
-    if (!addInfoLabel(info_layout, text, 1, 1)) return;
+    
+    m_lbl_length = addInfoLabel(info_layout, "", 1, 1);
+    if (!m_lbl_length) return;
+    setLength(samples*tracks);
 
     // label with "rate:"
     if (!addInfoLabel(info_layout, i18n("sample rate: "), 2, 0)) return;
@@ -124,18 +116,14 @@ FileProgress::FileProgress(QWidget *parent,
     if (!addInfoLabel(info_layout, text, 4, 1)) return;
 
     // progress bar
-#if KDE_VERSION_MAJOR < 3
-    m_progress = new KProgress(0, 100, 0, Horizontal, this);
-#else
     m_progress = new KProgress(100, this);
-#endif
-    ASSERT(m_progress);
+    Q_ASSERT(m_progress);
     if (!m_progress) return;
     top_layout->addWidget(m_progress, 0, 0);
 
     // sublayout for the line with estimated time
     QGridLayout *status_layout = new QGridLayout(1, 3, 1);
-    ASSERT(status_layout);
+    Q_ASSERT(status_layout);
     if (!status_layout) return;
     status_layout->addColSpacing(1, 20);
     top_layout->addLayout(status_layout);
@@ -157,7 +145,7 @@ FileProgress::FileProgress(QWidget *parent,
 
     // right lower edge: the "cancel" button
     KPushButton *bt_cancel = new KPushButton(this);
-    ASSERT(bt_cancel);
+    Q_ASSERT(bt_cancel);
     if (!bt_cancel) return;
     bt_cancel->setText(i18n("&Cancel"));
     bt_cancel->setFixedSize(bt_cancel->sizeHint());
@@ -187,7 +175,7 @@ void FileProgress::resizeEvent(QResizeEvent *)
 //***************************************************************************
 void FileProgress::closeEvent(QCloseEvent *e)
 {
-    ASSERT(e);
+    Q_ASSERT(e);
     if (!e) return;
 
     // if not already cancelled -> ask user to confirm
@@ -236,7 +224,7 @@ QLabel *FileProgress::addInfoLabel(QGridLayout *layout, const QString text,
 	int row, int col)
 {
     QLabel *label = new QLabel(this);
-    ASSERT(label);
+    Q_ASSERT(label);
     if (!label) return 0;
 
     label->setText(text);
@@ -287,6 +275,13 @@ void FileProgress::updateStatistics(double rate, double rest,
 
 //***************************************************************************
 void FileProgress::setValue(unsigned int pos)
+{
+    // position is in samples, we need bytes
+    setBytePosition(pos * (m_bits_per_sample >> 3));
+}
+
+//***************************************************************************
+void FileProgress::setBytePosition(unsigned int pos)
 {
     if (!m_progress) return;
 
@@ -324,6 +319,23 @@ void FileProgress::setValue(unsigned int pos)
     sched_yield();
 }
 
+//***************************************************************************
+void FileProgress::setLength(unsigned int samples)
+{
+    QString text;
+    
+    // length in samples -> h:m:s
+    if (m_sample_rate) {
+	// length in ms
+	text = KwavePlugin::ms2string((float)(samples/m_tracks)/
+	                              (float)m_sample_rate*1000.0);
+    } else {
+	// fallback if no rate: length in samples
+        text = i18n("%1 samples").arg(samples);
+    }
+    m_lbl_length->setText(text);
+}
+
 //***************************************************************************
 void FileProgress::cancel()
 {
