@@ -64,7 +64,7 @@ OverViewWidget::~OverViewWidget()
 //*****************************************************************************
 void OverViewWidget::mousePressEvent(QMouseEvent *e)
 {
-    ASSERT(e);
+    Q_ASSERT(e);
     if (!e) return;
 
     int x = offset2pixels(m_view_offset);
@@ -93,7 +93,7 @@ void OverViewWidget::mouseDoubleClickEvent(QMouseEvent *e)
 {
     unsigned int old_offset = m_view_offset;
 
-    ASSERT(e);
+    Q_ASSERT(e);
     if (!e) return;
 
     m_mouse_pos = e->x();
@@ -215,8 +215,8 @@ unsigned int OverViewWidget::pixels2offset(int pixels)
 //****************************************************************************
 void OverViewWidget::mouseMoveEvent( QMouseEvent *e)
 {
-    ASSERT(e);
-    ASSERT(m_width);
+    Q_ASSERT(e);
+    Q_ASSERT(m_width);
     if (!e) return;
     if (!m_width) return;
 
@@ -253,7 +253,7 @@ void OverViewWidget::setRange(unsigned int new_pos, unsigned int new_width,
     if ( (new_pos == m_view_offset) && (new_length == m_view_length) &&
 	(new_width == m_view_width) && (width() == m_width)) return;
 
-//    debug("OverViewWidget::setRange(%u,%u,%u)",new_pos,new_width,new_length);
+//    qDebug("OverViewWidget::setRange(%u,%u,%u)",new_pos,new_width,new_length);
 
     if ( (m_view_length == new_length) && (m_view_width == new_width) &&
 	(width() == m_width))
@@ -266,7 +266,7 @@ void OverViewWidget::setRange(unsigned int new_pos, unsigned int new_width,
 	m_view_offset = min(new_pos, new_length-new_width);
 	m_view_length = new_length;
 	m_slider_width = offset2pixels(m_view_width);
-//	debug("OverViewWidget::setRange(): slider_width=%d",m_slider_width);
+//	qDebug("OverViewWidget::setRange(): slider_width=%d",m_slider_width);
 	m_slider_width = max(m_slider_width, MIN_SLIDER_WIDTH);
 	m_slider_width = min(m_slider_width, m_width-1);
 	m_redraw=true;
@@ -287,7 +287,7 @@ void OverViewWidget::setValue(unsigned int newval)
 //*****************************************************************************
 void OverViewWidget::paintEvent(QPaintEvent *)
 {
-//    debug("OverViewWidget::paintEvent(QPaintEvent *)");
+//    qDebug("OverViewWidget::paintEvent(QPaintEvent *)");
     QPainter p;
 
     // if pixmap has to be resized ...
@@ -299,7 +299,7 @@ void OverViewWidget::paintEvent(QPaintEvent *)
 	m_pixmap = new QPixmap(size());
     }
     if (!m_bitmap.width() || !m_bitmap.height()) refreshBitmap();
-    ASSERT(m_pixmap);
+    Q_ASSERT(m_pixmap);
     if (!m_pixmap) return;
 
     // --- background of the widget ---
