@@ -93,12 +93,12 @@ void TrackPixmap::setOffset(unsigned int offset)
     if (m_minmax_mode) {
 	// move content of min and max buffer
 	// one buffer element = one screen pixel
-	ASSERT(buflen == m_min_buffer.size());
-	ASSERT(buflen == m_max_buffer.size());
+	Q_ASSERT(buflen == m_min_buffer.size());
+	Q_ASSERT(buflen == m_max_buffer.size());
 	if ((buflen != m_min_buffer.size()) || (buflen != m_max_buffer.size())) {
-	    debug("TrackPixmap::setOffset(): buflen = %u", buflen);
-	    debug("TrackPixmap::setOffset(): min_buffer : %u", m_min_buffer.size());
-	    debug("TrackPixmap::setOffset(): max_buffer : %u", m_max_buffer.size());
+	    qDebug("TrackPixmap::setOffset(): buflen = %u", buflen);
+	    qDebug("TrackPixmap::setOffset(): min_buffer : %u", m_min_buffer.size());
+	    qDebug("TrackPixmap::setOffset(): max_buffer : %u", m_max_buffer.size());
 	}
 	
 	// check for misaligned offset changes
@@ -107,22 +107,22 @@ void TrackPixmap::setOffset(unsigned int offset)
 
 #ifdef CURRENTLY_UNUSED
 // this will become interesting later, with the offset/zoom optimizations
-	    warning("TrackPixmap::setOffset(): oh nooo, "\
+	    qWarning("TrackPixmap::setOffset(): oh nooo, "\
 	    	"offset %u is misaligned by %u sample(s), please fix this!",
 	    	offset, offset % pixels2samples(1));
-	    warning("TrackPixmap::setOffset(): "\
+	    qWarning("TrackPixmap::setOffset(): "\
 	    	"now I have to throw away the whole buffer :-((");
 	
-	    debug("TrackPixmap::setOffset(%u): "\
+	    qDebug("TrackPixmap::setOffset(%u): "\
 		"misaligned->invalidating buffer", offset);
 #endif
 	    invalidateBuffer();
 	} else if (offset > m_offset) {
 	    // move left
 	    diff = samples2pixels(offset - m_offset);
-//	    debug("TrackPixmap::setOffset(): moving left (min/max): %u",diff);
-	    ASSERT(diff);
-	    ASSERT(buflen);
+//	    qDebug("TrackPixmap::setOffset(): moving left (min/max): %u",diff);
+	    Q_ASSERT(diff);
+	    Q_ASSERT(buflen);
 	    if (diff && buflen) {
 		for (src = diff, dst = 0; src < buflen; ++dst, ++src) {
 		    m_min_buffer[dst] = m_min_buffer[src];
@@ -134,9 +134,9 @@ void TrackPixmap::setOffset(unsigned int offset)
 	} else {
 	    // move right
 	    diff = samples2pixels(m_offset - offset);
-//	    debug("TrackPixmap::setOffset(): moving right (min/max): %u",diff);
-	    ASSERT(diff);
-	    ASSERT(buflen);
+//	    qDebug("TrackPixmap::setOffset(): moving right (min/max): %u",diff);
+	    Q_ASSERT(diff);
+	    Q_ASSERT(buflen);
 	    if (diff && buflen) {
 		for (dst=buflen-1, src=dst-diff; dst>=diff; --dst, --src) {
 		    m_min_buffer[dst] = m_min_buffer[src];
@@ -150,11 +150,11 @@ void TrackPixmap::setOffset(unsigned int offset)
     } else {
 	// move content of sample buffer
 	// one buffer element = one sample
-	ASSERT(buflen == m_sample_buffer.size());
+	Q_ASSERT(buflen == m_sample_buffer.size());
 	
 	if (offset > m_offset) {
 	    // move left
-//	    debug("TrackPixmap::setOffset(): moving left (normal)"); // ###
+//	    qDebug("TrackPixmap::setOffset(): moving left (normal)"); // ###
 	    diff = offset - m_offset;
 	    for (src=diff, dst=0; src<buflen; ++dst, ++src) {
 		m_sample_buffer[dst] = m_sample_buffer[src];
@@ -163,9 +163,9 @@ void TrackPixmap::setOffset(unsigned int offset)
 	    while (dst < buflen) m_valid[dst++] = 0;
 	} else {
 	    // move right
-//	    debug("TrackPixmap::setOffset(): moving right (normal)"); // ###
+//	    qDebug("TrackPixmap::setOffset(): moving right (normal)"); // ###
 	    diff = m_offset - offset;
-	    ASSERT(buflen);
+	    Q_ASSERT(buflen);
 	    if (buflen) {
 		for (dst=buflen-1, src=dst-diff; dst>=diff; --dst, --src) {
 		    m_sample_buffer[dst] = m_sample_buffer[src];
@@ -207,15 +207,15 @@ void TrackPixmap::setZoom(double zoom)
 
     if (zoom == m_zoom) return; // no change
 
-//    debug("TrackPixmap::setZoom(%0.3f)", zoom);
+//    qDebug("TrackPixmap::setZoom(%0.3f)", zoom);
     if ((zoom > 1.0) && !m_minmax_mode) {
 	// switch to min/max mode
-//	debug("TrackPixmap::setZoom(): switch to min/max mode");
+//	qDebug("TrackPixmap::setZoom(): switch to min/max mode");
 	invalidateBuffer();
 	m_minmax_mode = true;
     } else if ((zoom <= 1.0) && m_minmax_mode) {
 	// switch to normal mode
-//	debug("TrackPixmap::setZoom(): switch to normal mode");
+//	qDebug("TrackPixmap::setZoom(): switch to normal mode");
 	invalidateBuffer();
 	m_minmax_mode = false;
     }
@@ -265,10 +265,10 @@ bool TrackPixmap::validateBuffer()
     unsigned int buflen = m_valid.size();
 
     if (m_minmax_mode) {
-	ASSERT(m_min_buffer.size() == buflen);
-	ASSERT(m_max_buffer.size() == buflen);
+	Q_ASSERT(m_min_buffer.size() == buflen);
+	Q_ASSERT(m_max_buffer.size() == buflen);
     } else {
-	ASSERT(m_sample_buffer.size() == buflen);
+	Q_ASSERT(m_sample_buffer.size() == buflen);
     }
 
     // ### FIXME:
@@ -304,12 +304,12 @@ bool TrackPixmap::validateBuffer()
 
 	    // open a reader for the whole modified range	
 	    SampleReader *in = m_track.openSampleReader(s1, s2);
-	    ASSERT(in);
+	    Q_ASSERT(in);
 	    if (!in) break;
 	
 	    // allocate a buffer for one more sample (pixels2samples may
 	    // vary by +/-1 !
-	    QArray<sample_t> buffer(ceil(m_zoom)/*pixels2samples(1) + 1*/);
+	    QMemArray<sample_t> buffer((int)ceil(m_zoom));
 	    sample_t min;
 	    sample_t max;
 	
@@ -347,7 +347,7 @@ bool TrackPixmap::validateBuffer()
 	    // each index is one sample
 	    SampleReader *in = m_track.openSampleReader(
 		m_offset+first, m_offset+last);
-	    ASSERT(in);
+	    Q_ASSERT(in);
 	    if (!in) break;
 	
 	    // read directly into the buffer
@@ -364,12 +364,12 @@ bool TrackPixmap::validateBuffer()
 	    delete in;
 	}
 	
-	ASSERT(first >= last);
+	Q_ASSERT(first >= last);
         ++last;
     }
 
     for (first=0; first < m_valid.size(); first++) {
-	if (!m_valid[first]) warning("TrackPixmap::validateBuffer(): "\
+	if (!m_valid[first]) qWarning("TrackPixmap::validateBuffer(): "\
 		"still invalid index: %u", first);
     }
 
@@ -433,9 +433,9 @@ bool TrackPixmap::isModified()
 void TrackPixmap::drawOverview(QPainter &p, int middle, int height,
 	int first, int last)
 {
-    ASSERT(m_minmax_mode);
-    ASSERT(width() <= (int)m_min_buffer.size());
-    ASSERT(width() <= (int)m_max_buffer.size());
+    Q_ASSERT(m_minmax_mode);
+    Q_ASSERT(width() <= (int)m_min_buffer.size());
+    Q_ASSERT(width() <= (int)m_max_buffer.size());
 
     // scale_y: pixels per unit
     double scale_y = (double)height / (1 << 24);
@@ -443,7 +443,7 @@ void TrackPixmap::drawOverview(QPainter &p, int middle, int height,
 
     p.setPen(m_color_sample);
     for (int i = first; i <= last; i++) {
-	ASSERT(m_valid[i]);
+	Q_ASSERT(m_valid[i]);
 	max = (int)(m_max_buffer[i] * scale_y);
 	min = (int)(m_min_buffer[i] * scale_y);
 	p.drawLine(i, middle - max, i, middle - min);
@@ -458,7 +458,7 @@ void TrackPixmap::calculateInterpolation()
     int k;
     int N;
 
-//    debug("TrackPixmap::calculateInterpolation()");
+//    qDebug("TrackPixmap::calculateInterpolation()");
 
     // remove all previous coefficents and signal buffer
     if (m_interpolation_alpha != 0) {
@@ -466,7 +466,7 @@ void TrackPixmap::calculateInterpolation()
 	m_interpolation_alpha = 0;
     }
 
-    ASSERT(m_zoom != 0.0);
+    Q_ASSERT(m_zoom != 0.0);
     if (m_zoom == 0.0) return;
 
     // offset: index of first visible sample (left) [0...length-1]
@@ -486,7 +486,7 @@ void TrackPixmap::calculateInterpolation()
     m_interpolation_alpha = new float[N + 1];
     m_interpolation_order = N;
 
-    ASSERT(m_interpolation_alpha);
+    Q_ASSERT(m_interpolation_alpha);
     if (!m_interpolation_alpha) return;
 
     // calculate the raw coefficients and
@@ -525,9 +525,9 @@ void TrackPixmap::drawInterpolatedSignal(QPainter &p, int width,
     int x;
     int buflen = m_valid.size();
 
-//    debug("TrackPixmap::drawInterpolatedSignal()");
+//    qDebug("TrackPixmap::drawInterpolatedSignal()");
 
-    ASSERT(m_zoom);
+    Q_ASSERT(m_zoom);
     if (m_zoom == 0.0) return;
 
     // scale_y: pixels per unit
@@ -544,17 +544,17 @@ void TrackPixmap::drawInterpolatedSignal(QPainter &p, int width,
 	N = m_interpolation_order;
     }
 
-    ASSERT(m_interpolation_alpha);
+    Q_ASSERT(m_interpolation_alpha);
     if (!m_interpolation_alpha) return;
 
     // buffer for intermediate resampled data
     sig_buffer = new float[width + N + 2];
-    ASSERT(sig_buffer);
+    Q_ASSERT(sig_buffer);
     if (!sig_buffer) return;
 
     // array with sample points
     QPointArray *points = new QPointArray(width);
-    ASSERT(points);
+    Q_ASSERT(points);
     if (!points) {
 	delete[] sig_buffer;
 	return;
@@ -627,7 +627,7 @@ void TrackPixmap::drawPolyLineSignal(QPainter &p, int width,
 
     // array with sample points
     QPointArray *points = new QPointArray(width + 1);
-    ASSERT(points);
+    Q_ASSERT(points);
     if (!points) return;
 
     // display the original samples
@@ -689,8 +689,8 @@ void TrackPixmap::slotSamplesInserted(Track &, unsigned int offset,
 	convertOverlap(offset, length);
 	if (!length) return; // false alarm
 	
-	ASSERT(offset < m_valid.size());
-	ASSERT(offset + length <= m_valid.size());
+	Q_ASSERT(offset < m_valid.size());
+	Q_ASSERT(offset + length <= m_valid.size());
 	
 	// mark all positions from here to right end as "invalid"
 	while (offset < m_valid.size()) m_valid.clearBit(offset++);
@@ -713,8 +713,8 @@ void TrackPixmap::slotSamplesDeleted(Track &, unsigned int offset,
 	convertOverlap(offset, length);
 	if (!length) return; // false alarm
 	
-	ASSERT(offset < m_valid.size());
-	ASSERT(offset + length <= m_valid.size());
+	Q_ASSERT(offset < m_valid.size());
+	Q_ASSERT(offset + length <= m_valid.size());
 	
 	// mark all positions from here to right end as "invalid"
 	while (offset < m_valid.size()) m_valid.clearBit(offset++);
@@ -737,8 +737,8 @@ void TrackPixmap::slotSamplesModified(Track &, unsigned int offset,
 	convertOverlap(offset, length);
 	if (!length) return; // false alarm
 	
-	ASSERT(offset < m_valid.size());
-	ASSERT(offset + length <= m_valid.size());
+	Q_ASSERT(offset < m_valid.size());
+	Q_ASSERT(offset + length <= m_valid.size());
 	
 	// mark all overlapping positions as "invalid"
 	while (length--) m_valid.clearBit(offset++);
@@ -754,9 +754,8 @@ void TrackPixmap::slotSamplesModified(Track &, unsigned int offset,
 //***************************************************************************
 void TrackPixmap::convertOverlap(unsigned int &offset, unsigned int &length)
 {
-    ASSERT(m_zoom);
+    Q_ASSERT(m_zoom != 0.0);
     if (m_zoom == 0.0) length = 0;
-
     if (!length) return;
     if ((offset + length) <= m_offset) {
 	length = 0;
@@ -764,6 +763,7 @@ void TrackPixmap::convertOverlap(unsigned int &offset, unsigned int &length)
     }
 
     unsigned int buflen = m_valid.size();
+    Q_ASSERT(buflen);
 
     // calculate the length
     if (m_minmax_mode) {
@@ -798,7 +798,7 @@ void TrackPixmap::convertOverlap(unsigned int &offset, unsigned int &length)
     // limit the length to the end of the buffer
     if (offset+length > buflen) length = buflen-offset;
 
-    ASSERT(length);
+    Q_ASSERT(length);
 }
 
 //***************************************************************************
