@@ -20,8 +20,8 @@
 
 #include "config.h"
 #include <string.h>
-#include <qglobal.h> // for warning()
-#include <qvector.h>
+#include <qglobal.h> // for qWarning()
+#include <qptrvector.h>
 
 #include <arts/artsflow.h>
 #include <arts/connect.h>
@@ -46,11 +46,11 @@ public:
 	    m_filter.insert(i, 0);
 	
 	    FILTER_IMPL *f = new FILTER_IMPL();
-	    ASSERT(f);
+	    Q_ASSERT(f);
 	    if (f) m_filter.insert(i, new FILTER(FILTER::_from_base(f)));
 	
 	    if (!m_filter[i]) {
-		warning("ArtsMultiTrackFilter: filter creation failed!!!");
+		qWarning("ArtsMultiTrackFilter: filter creation failed!!!");
 		m_count = i;
 		break;
 	    }
@@ -124,6 +124,38 @@ public:
 	                  *(sink[i]),     input_name);
     };
 
+    /**
+     * Set all input of the filters to the same constant value.
+     * @param input_name name of the input of the sinks
+     * @param value float value to be set
+     */
+    virtual void setValue(
+	const std::string &input_name,
+	const float value)
+    {
+	for (unsigned int i=0; i < m_count; ++i)
+	    Arts::setValue(*(m_filter[i]), input_name, value);
+    };
+
+    /**
+     * Set all attributes of the filters to the same constant value.
+     * @param attribute name of the attribute to set
+     * @param value float value to be set
+     */
+    virtual void setAttribute(
+	const std::string &attribute,
+	const float value)
+    {
+	std::string command;
+	command = "_set_";
+	command += attribute;
+	for (unsigned int i=0; i < m_count; ++i) {
+	    Arts::Object &object(*(m_filter[i]));
+	    Arts::DynamicRequest(object).method(
+	        command).param(value).invoke();
+	}
+    };
+
     /** Starts all filters. */
     virtual void start() {
 	for (unsigned int i=0; i < m_count; ++i) m_filter[i]->start();
@@ -140,7 +172,7 @@ private:
     unsigned int m_count;
 
     /** list of the filters */
-    QVector<FILTER> m_filter;
+    QPtrVector<FILTER> m_filter;
 };
 
 #endif /* _ARTS_KWAVE_MULTI_TRACK_FILTER_H_ */
