@@ -19,11 +19,10 @@
 #include <float.h>
 #include <math.h>
 
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qstring.h>
 
 #include "Parser.h"
-#include "PointSet.h"
 #include "Interpolation.h"
 #include "Curve.h"
 
@@ -86,7 +85,7 @@ Interpolation &Curve::interpolation()
 };
 
 //***************************************************************************
-QArray<double> Curve::interpolation(unsigned int points)
+QMemArray<double> Curve::interpolation(unsigned int points)
 {
     m_interpolation.prepareInterpolation(this);
     return m_interpolation.interpolation(this, points);
@@ -154,7 +153,7 @@ void Curve::insert(double x, double y)
     }
 
     Point *ins = new Point;
-    ASSERT(ins);
+    Q_ASSERT(ins);
     if (!ins) return;
     ins->x = x;
     ins->y = y;
@@ -164,18 +163,18 @@ void Curve::insert(double x, double y)
     while (tmp->x < x) tmp = m_points.next();
 
     if (tmp) m_points.insert(m_points.at(), ins);
-    else warning("Curve::insert(%0.2f,%0.2f): out of range !",x,y);
+    else qWarning("Curve::insert(%0.2f,%0.2f): out of range !",x,y);
 }
 
 //***************************************************************************
-Point *Curve::previous(Point *act)
+Curve::Point *Curve::previous(Curve::Point *act)
 {
     m_points.findRef(act);
     return m_points.prev();
 }
 
 //***************************************************************************
-Point *Curve::next(Point *act)
+Curve::Point *Curve::next(Curve::Point *act)
 {
     m_points.findRef(act);
     return m_points.next();
@@ -185,7 +184,7 @@ Point *Curve::next(Point *act)
 void Curve::append(double x, double y)
 {
     Point *insert = new Point;
-    ASSERT(insert);
+    Q_ASSERT(insert);
     if (!insert) return;
 
     insert->x = x;
@@ -238,7 +237,7 @@ void Curve::scaleFit(unsigned int range)
 
     Interpolation interpolation(m_interpolation.type());
 
-    QArray<double> y = interpolation.interpolation(this, range);
+    QMemArray<double> y = interpolation.interpolation(this, range);
     for (unsigned int i = 0; i < range; i++) {
 	if (y[i] > max) max = y[i];
 	if (y[i] < min) min = y[i];
@@ -253,7 +252,7 @@ void Curve::scaleFit(unsigned int range)
 }
 
 //***************************************************************************
-Point *Curve::findPoint(double px, double py, double tol)
+Curve::Point *Curve::findPoint(double px, double py, double tol)
 {
     Point *tmp;
     Point *best=0;
@@ -272,7 +271,7 @@ Point *Curve::findPoint(double px, double py, double tol)
 }
 
 //***************************************************************************
-Point *Curve::first()
+Curve::Point *Curve::first()
 {
     return m_points.first();
 }
@@ -284,13 +283,13 @@ unsigned int Curve::count()
 }
 
 //***************************************************************************
-Point *Curve::at(int x)
+Curve::Point *Curve::at(int x)
 {
     return m_points.at(x);
 }
 
 //***************************************************************************
-Point *Curve::last()
+Curve::Point *Curve::last()
 {
     return m_points.last();
 }
