@@ -1,13 +1,11 @@
-// I/O Functions such as loading/saving are in sampleio.cpp
 
 #include <math.h>
-#include <limits.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <dlfcn.h>
 
-#include <qarray.h>
-#include <qlist.h>
+#include <qmemarray.h>
+#include <qptrlist.h>
 
 #include <klocale.h>
 #include <kmessagebox.h>
@@ -26,40 +24,16 @@
 
 #include "mt/SharedLockGuard.h"
 
-#define MAXPRIME 512
-
-//**********************************************************
-//void Signal::getMaxMin (int &max, int &min, int begin, int len) {
-//    int c, first, last;
-//    min =  INT_MAX;
-//    max =  INT_MIN;
-//
-//    // first assign left and right margin
-//    first = begin;
-//    last = begin + len - 1;
-//
-//    // then do some range checking
-//    if (first < 0) first = 0;
-//    if (first >= length) first = length - 1;
-//    if (last < first) last = first;
-//    if (last >= length) last = length - 1;
-//
-//    for (int i = first; i <= last; i++) {
-//	c = sample[i];
-//	if (c > max) max = c;
-//	if (c < min) min = c;
-//    }
-//}
 
 //***************************************************************************
 Signal::Signal()
-    :m_tracks(), m_lock_tracks(), m_rate(0), m_bits(0)
+    :m_tracks(), m_lock_tracks()
 {
 }
 
 //***************************************************************************
 Signal::Signal(unsigned int tracks, unsigned int length)
-    :m_tracks(), m_lock_tracks(), m_rate(0), m_bits(0)
+    :m_tracks(), m_lock_tracks()
 {
     while (tracks--) {
 	appendTrack(length);
@@ -81,8 +55,6 @@ void Signal::close()
     while (m_tracks.count()) {
 	m_tracks.remove(m_tracks.last());
     }
-    m_bits = 0;
-    m_rate = 0;
 }
 
 //***************************************************************************
@@ -94,7 +66,7 @@ Track *Signal::insertTrack(unsigned int index, unsigned int length)
 	SharedLockGuard lock(m_lock_tracks, true);
 	
 	t = new Track(length);
-	ASSERT(t);
+	Q_ASSERT(t);
 	if (!t) return 0;
 	
 	if (index < m_tracks.count()) {
@@ -164,13 +136,13 @@ SampleWriter *Signal::openSampleWriter(unsigned int track,
 {
     SharedLockGuard lock(m_lock_tracks, false);
 
-    ASSERT(track < m_tracks.count());
+    Q_ASSERT(track < m_tracks.count());
     if (track >= m_tracks.count()) {
 	return 0; // track does not exist !
     }
 
     Track *t = m_tracks.at(track);
-    ASSERT(t);
+    Q_ASSERT(t);
     return (t) ? t->openSampleWriter(mode, left, right) : 0;
 }
 
@@ -180,17 +152,17 @@ SampleReader *Signal::openSampleReader(unsigned int track,
 {
     SharedLockGuard lock(m_lock_tracks, false);
 
-    ASSERT(track < m_tracks.count());
+    Q_ASSERT(track < m_tracks.count());
     if (track >= m_tracks.count()) return 0; // track does not exist !
 
     Track *t = m_tracks.at(track);
-    ASSERT(t);
+    Q_ASSERT(t);
     return (t) ? t->openSampleReader(left, right) : 0;
 }
 
 //***************************************************************************
 void Signal::openMultiTrackReader(MultiTrackReader &readers,
-    const QArray<unsigned int> &track_list,
+    const QMemArray<unsigned int> &track_list,
     unsigned int first, unsigned int last)
 {
     unsigned int count = track_list.count();
@@ -201,7 +173,7 @@ void Signal::openMultiTrackReader(MultiTrackReader &readers,
     for (unsigned int i=0; i < count; i++) {
 	track = track_list[i];
 	SampleReader *s = openSampleReader(track, first, last);
-	ASSERT(s);
+	Q_ASSERT(s);
 	readers.insert(i, s);
     }
 
@@ -209,7 +181,7 @@ void Signal::openMultiTrackReader(MultiTrackReader &readers,
 
 //***************************************************************************
 void Signal::openMultiTrackWriter(MultiTrackWriter &writers,
-    const QArray<unsigned int> &track_list, InsertMode mode,
+    const QMemArray<unsigned int> &track_list, InsertMode mode,
     unsigned int left, unsigned int right)
 {
     unsigned int count = track_list.count();
@@ -224,7 +196,7 @@ void Signal::openMultiTrackWriter(MultiTrackWriter &writers,
 	    writers.insert(i, s);
 	} else {
 	    // out of memory or aborted
-	    debug("Signal::openMultiTrackWriter: "\
+	    qDebug("Signal::openMultiTrackWriter: "\
 	          "out of memory or aborted");
 	    writers.clear();
 	    return;
@@ -233,10 +205,10 @@ void Signal::openMultiTrackWriter(MultiTrackWriter &writers,
 }
 
 //***************************************************************************
-const QArray<unsigned int> Signal::allTracks()
+const QMemArray<unsigned int> Signal::allTracks()
 {
     unsigned int track;
-    QArray<unsigned int> list(tracks());
+    QMemArray<unsigned int> list(tracks());
 
     for (track=0; track < list.count(); track++) {
 	list[track] = track;
@@ -251,11 +223,11 @@ void Signal::deleteRange(unsigned int track, unsigned int offset,
 {
     SharedLockGuard lock(m_lock_tracks, false);
 
-    ASSERT(track < m_tracks.count());
+    Q_ASSERT(track < m_tracks.count());
     if (track >= m_tracks.count()) return; // track does not exist !
 
     Track *t = m_tracks.at(track);
-    ASSERT(t);
+    Q_ASSERT(t);
     if (t) t->deleteRange(offset, length);
 }
 
@@ -272,14 +244,11 @@ unsigned int Signal::length()
     SharedLockGuard lock(m_lock_tracks, false);
 
     unsigned int max = 0;
-    unsigned int len;
-
-    QListIterator<Track> it(m_tracks);
+    QPtrListIterator<Track> it(m_tracks);
     for ( ; it.current(); ++it) {
-	len = it.current()->length();
+	unsigned int len = it.current()->length();
 	if (len > max) max = len;
     }
-//    debug("Signal::length() = %d", max);
     return max;
 }
 
@@ -299,23 +268,17 @@ void Signal::selectTrack(unsigned int track, bool select)
 {
     SharedLockGuard lock(m_lock_tracks, false);
 
-    ASSERT(track < m_tracks.count());
+    Q_ASSERT(track < m_tracks.count());
     if (track >= m_tracks.count()) return;
-    ASSERT(m_tracks.at(track));
+    Q_ASSERT(m_tracks.at(track));
     if (!m_tracks.at(track)) return;
 
     m_tracks.at(track)->select(select);
 }
 
-////**********************************************************
-//int Signal::getSingleSample(int offset) {
-//    if ((offset < 0) || (offset >= length)) return 0;
-//    return sample[offset];
-//}
-//
-
 //// now follow the various editing and effects functions
 ////**********************************************************
+//#define MAXPRIME 512
 //int Signal::getChannelMaximum () {
 //    int max = 0;
 //    for (int i = 0; i < length; i++)
@@ -339,7 +302,7 @@ void Signal::selectTrack(unsigned int track, bool select)
 //	for (int i = 0; i < length; i++)
 //	    points->append (((double) i) / length, (double) sample[i]);
 //
-//	QArray<double> *y = interpolation.interpolation(points, newlen);
+//	QMemArray<double> *y = interpolation.interpolation(points, newlen);
 //	if (y) {
 //	    delete points;
 //	    points = 0;
@@ -510,7 +473,7 @@ void Signal::selectTrack(unsigned int track, bool select)
 //{
 //    Interpolation interpolation (0);
 //
-//    QArray<double> *move = interpolation.interpolation (points, len);
+//    QMemArray<double> *move = interpolation.interpolation (points, len);
 //    if (move) {
 //	for (int i = 0; i < len; i++)
 //	    //rescale range of filtermovement...
@@ -612,7 +575,7 @@ unsigned int Signal::trackIndex(const Track &track)
     SharedLockGuard lock(m_lock_tracks, false);
 
     int index = m_tracks.findRef(&track);
-    ASSERT(index >= 0);
+    Q_ASSERT(index >= 0);
     return (index >= 0) ? index : m_tracks.count();
 }
 
