@@ -5,8 +5,9 @@
 #define PROGRESS_SIZE 512*3*5
 
 #include "config.h"
+#include <limits.h>
 #include <pthread.h>
-#include <qlist.h>
+#include <qptrlist.h>
 
 #include "mt/SharedLock.h"
 #include "libkwave/InsertMode.h"
@@ -77,7 +78,7 @@ public:
     /**
      * Returns an array of indices of all present tracks.
      */
-    const QArray<unsigned int> allTracks();
+    const QMemArray<unsigned int> allTracks();
 
     /**
      * Opens an input stream for a track, starting at a specified sample
@@ -119,7 +120,7 @@ public:
      * @see SampleReader
      */
     void openMultiTrackReader(MultiTrackReader &readers,
-	const QArray<unsigned int> &track_list,
+	const QMemArray<unsigned int> &track_list,
 	unsigned int first, unsigned int last);
 
     /**
@@ -134,7 +135,7 @@ public:
      * @see InsertMode
      */
     void openMultiTrackWriter(MultiTrackWriter &writers,
-	const QArray<unsigned int> &track_list, InsertMode mode,
+	const QMemArray<unsigned int> &track_list, InsertMode mode,
 	unsigned int left, unsigned int right);
 
     /**
@@ -151,25 +152,6 @@ public:
     void deleteRange(unsigned int track, unsigned int offset,
                      unsigned int length);
 
-//    Signal *copyRange ();
-//    Signal *cutRange ();
-//    void cropRange ();
-//    void deleteRange ();
-//    void overwritePaste (Signal *);
-//    void insertPaste (Signal *);
-//    void mixPaste (Signal *);
-//
-//    void getMaxMin ( int& max, int& min, int begin, int len);
-//    int getSingleSample (int offset);
-
-    inline unsigned int rate() {
-	return m_rate;
-    };
-
-    inline unsigned int bits() {
-	return m_bits;
-    };
-
     /**
      * Returns the length of the signal. This is determined by
      * searching for the highest sample position of all tracks.
@@ -190,19 +172,6 @@ public:
      */
     void selectTrack(unsigned int track, bool select);
 
-    inline void setRate(const int rate) {
-	m_rate = rate;
-    };
-
-    inline void setBits(const int bits) {
-	m_bits = bits;
-    };
-
-//    int getChannelMaximum ();
-//
-//    void setMarkers (int, int);
-//    void resample (const char *);   //int
-
 signals:
 
     /**
@@ -304,20 +273,11 @@ private:
 //    void averageFFT (int points, window_function_t windowtype);
 
     /** list of tracks */
-    QList<Track> m_tracks;
+    QPtrList<Track> m_tracks;
 
     /** mutex for access to the track list */
     SharedLock m_lock_tracks;
 
-    /** number of samples */
-    unsigned int m_length;
-
-    /** sample rate [samples per second] */
-    unsigned int m_rate;
-
-    /** resolution in bits per sample */
-    unsigned int m_bits;
-
 };
 
 //**********************************************************************
