@@ -22,6 +22,7 @@
 #include <qmap.h>
 #include <qobject.h>
 #include <qstring.h>
+#include <qstringlist.h>
 #include <klocale.h>
 #include "libkwave/Triple.h"
 
@@ -49,6 +50,7 @@ public:
     /**
      * Appends a new type into the map.
      * @param index unique index within the map
+     * @param data the data associated with the entry
      * @param name string representation of the type, for
      *             internal usage in Kwave commands.
      * @param description text for the user interface
@@ -58,7 +60,7 @@ public:
     {
 	Triple<DATA, QString, QString> *triple;
 	triple = new Triple<DATA, QString, QString>(data, name, description);
-	ASSERT(triple);
+	Q_ASSERT(triple);
 	if (triple) m_list.insert(index, *triple);
     };
 
@@ -114,10 +116,10 @@ public:
 	unsigned int cnt = count();
 	while (cnt--) {
 	    if (localized) {
-		if (m_list[it].second() == description)
+		if (m_list[it].third() == description)
 		    return it;
 	    } else {
-		if (i18n(m_list[it].second()) == i18n(description))
+		if (i18n(m_list[it].third()) == i18n(description))
 		    return it;
 	    }
 	    ++it;
@@ -142,7 +144,7 @@ public:
     /**
      * Returns the description of a type.
      * @param type index of the type
-     * @param if true, the returned description is localized
+     * @param localized if true, the returned description is localized
      */
     QString description(IDX type, bool localized)
     {
@@ -151,6 +153,21 @@ public:
 	return (localized) ? i18n(s) : s;
     };
 
+    /**
+     * Returns a string list with all names,
+     */
+    QStringList allNames()
+    {
+	IDX it = IDX(0);
+	unsigned int cnt = count();
+	QStringList names;
+	while (cnt--) {
+	    names.append(m_list[it].second());
+	    ++it;
+	}
+	return names;
+    };
+
 private:
     /** map with index and triples of data, name and description */
     TripleMap m_list;
