@@ -22,16 +22,17 @@
 #include <kaboutapplication.h>
 #include <kaboutkde.h>
 
-#include "libgui/KwavePlugin.h"
+#include "libkwave/KwavePlugin.h"
 #include "AboutPlugin.h"
 #include "AboutKwaveDialog.h"
 
-KWAVE_PLUGIN(AboutPlugin,"about","Ralf Waspe");
+KWAVE_PLUGIN(AboutPlugin,"about","Ralf Waspe & Gilles Caulier");
 
 //***************************************************************************
 AboutPlugin::AboutPlugin(PluginContext &c)
     :KwavePlugin(c)
 {
+    i18n("about");
 }
 
 //***************************************************************************
@@ -41,7 +42,7 @@ int AboutPlugin::start(QStringList& params)
         // create a new "about kde" dialog and show it
         KAboutKDE *dlg = new KAboutKDE(parentWidget());
 
-        ASSERT(dlg);
+        Q_ASSERT(dlg);
         if (!dlg) return ENOMEM;
         dlg->exec();
         delete dlg;
@@ -49,7 +50,7 @@ int AboutPlugin::start(QStringList& params)
         // create a new "about" dialog and show it
         AboutKwaveDialog *dlg = new AboutKwaveDialog(parentWidget());
 
-        ASSERT(dlg);
+        Q_ASSERT(dlg);
         if (!dlg) return ENOMEM;
         dlg->exec();
         delete dlg;
