@@ -40,6 +40,7 @@ KWAVE_PLUGIN(AmplifyFreePlugin,"amplifyfree","Thomas Eschenbacher");
 AmplifyFreePlugin::AmplifyFreePlugin(PluginContext &context)
     :KwavePlugin(context), m_params(), m_curve(), m_stop(false)
 {
+    i18n("amplifyfree");
 }
 
 //***************************************************************************
@@ -76,13 +77,13 @@ QStringList *AmplifyFreePlugin::setup(QStringList &previous_params)
 
     // create the setup dialog
     AmplifyFreeDialog *dialog = new AmplifyFreeDialog(parentWidget());
-    ASSERT(dialog);
+    Q_ASSERT(dialog);
     if (!dialog) return 0;
 
     if (!m_params.isEmpty()) dialog->setParams(m_params);
 
     QStringList *list = new QStringList();
-    ASSERT(list);
+    Q_ASSERT(list);
     if (list && dialog->exec()) {
 	// user has pressed "OK"
 	QString cmd = dialog->getCommand();
@@ -106,7 +107,7 @@ void AmplifyFreePlugin::run(QStringList params)
 
     Arts::Dispatcher *dispatcher = manager().artsDispatcher();
     dispatcher->lock();
-    ASSERT(dispatcher);
+    Q_ASSERT(dispatcher);
     if (!dispatcher) close();
 
     UndoTransactionGuard undo_guard(*this, i18n("amplify free"));
@@ -146,11 +147,11 @@ void AmplifyFreePlugin::run(QStringList params)
     arts_sink.start();
 
     // transport the samples
-    debug("AmplifyFreePlugin: filter started...");
+    qDebug("AmplifyFreePlugin: filter started...");
     while (!m_stop && !(arts_source.done())) {
 	arts_sink.goOn();
     }
-    debug("AmplifyFreePlugin: filter done.");
+    qDebug("AmplifyFreePlugin: filter done.");
 
     // shutdown
     curve_adapter.stop();
