@@ -29,6 +29,7 @@ KWAVE_PLUGIN(WavCodecPlugin,"codec_wav","Thomas Eschenbacher");
 WavCodecPlugin::WavCodecPlugin(PluginContext &c)
     :KwavePlugin(c), m_decoder(0), m_encoder(0)
 {
+    i18n("codec_wav");
 }
 
 /***************************************************************************/
@@ -40,11 +41,11 @@ WavCodecPlugin::~WavCodecPlugin()
 void WavCodecPlugin::load(QStringList &/* params */)
 {
     if (!m_encoder) m_encoder = new WavEncoder();
-    ASSERT(m_encoder);
+    Q_ASSERT(m_encoder);
     if (m_encoder) CodecManager::registerEncoder(*m_encoder);
 
     if (!m_decoder) m_decoder = new WavDecoder();
-    ASSERT(m_decoder);
+    Q_ASSERT(m_decoder);
     if (m_decoder) CodecManager::registerDecoder(*m_decoder);
 }
 
