@@ -21,11 +21,16 @@
 #include <stdlib.h>
 
 extern "C" {
-#include "libaudiofile/audiofile.h" // from libaudiofile
-#include "libaudiofile/af_vfs.h"    // from libaudiofile
+#ifdef USE_BUILTIN_LIBAUDIOFILE
+#include "libaudiofile/audiofile.h" // from Kwave's copy of libaudiofile
+#include "libaudiofile/af_vfs.h"    // from Kwave's copy of libaudiofile
+#else /* USE_BUILTIN_LIBAUDIOFILE */
+#include <audiofile.h> // from system
+#include <af_vfs.h>    // from system
+#endif /* USE_BUILTIN_LIBAUDIOFILE */
 }
 
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qprogressdialog.h>
 
 #include <klocale.h>
@@ -49,13 +54,42 @@ extern "C" {
 #include "WavFileFormat.h"
 #include "WavFormatMap.h"
 
-#define CHECK(cond) ASSERT(cond); if (!(cond)) { src.close(); return false; }
+#define CHECK(cond) Q_ASSERT(cond); if (!(cond)) { src.close(); return false; }
 
 //***************************************************************************
 WavDecoder::WavDecoder()
-    :Decoder(), m_source(0), m_src_adapter(0)
+    :Decoder(), m_source(0), m_src_adapter(0), m_known_chunks(),
+     m_property_map()
 {
     LOAD_MIME_TYPES;
+
+    // native WAVE chunk names
+    m_known_chunks.append("cue "); /* Markers */
+    m_known_chunks.append("data"); /* Sound Data */
+    m_known_chunks.append("fmt "); /* Format */
+    m_known_chunks.append("inst"); /* Instrument */
+    m_known_chunks.append("labl"); /* label */
+    m_known_chunks.append("ltxt"); /* labeled text */
+    m_known_chunks.append("note"); /* note chunk */
+    m_known_chunks.append("plst"); /* Play List */
+    m_known_chunks.append("smpl"); /* Sampler */
+
+    // add all sub-chunks of the LIST chunk (properties)
+    QMap<QCString, FileProperty>::Iterator it;
+    for (it=m_property_map.begin(); it!=m_property_map.end(); ++it) {
+	m_known_chunks.append( it.key() );
+    }
+
+    // some chunks known from AIFF format
+    m_known_chunks.append("FVER");
+    m_known_chunks.append("COMM");
+    m_known_chunks.append("wave");
+    m_known_chunks.append("SSND");
+
+    // chunks of .lbm image files, IFF format
+    m_known_chunks.append("BMHD");
+    m_known_chunks.append("CMAP");
+    m_known_chunks.append("BODY");
 }
 
 //***************************************************************************
@@ -75,13 +109,13 @@ Decoder *WavDecoder::instance()
 bool WavDecoder::open(QWidget *widget, QIODevice &src)
 {
     info().clear();
-    ASSERT(!m_source);
+    Q_ASSERT(!m_source);
     bool need_repair = false;
-    if (m_source) warning("WavDecoder::open(), already open !");
+    if (m_source) qWarning("WavDecoder::open(), already open !");
 
     // try to open the source
     if (!src.open(IO_ReadOnly)) {
-	warning("failed to open source !");
+	qWarning("failed to open source !");
 	return false;
     }
 
@@ -92,45 +126,7 @@ bool WavDecoder::open(QWidget *widget, QIODevice &src)
     main_chunks.append("LIST"); /* additional information */
     main_chunks.append("adtl"); /* Associated Data */
 
-    QStringList known_chunks;
-
-    // native WAVE chunk names
-    known_chunks.append("cue "); /* Markers */
-    known_chunks.append("data"); /* Sound Data */
-    known_chunks.append("fmt "); /* Format */
-    known_chunks.append("inst"); /* Instrument */
-    known_chunks.append("labl"); /* label */
-    known_chunks.append("ltxt"); /* labeled text */
-    known_chunks.append("note"); /* note chunk */
-    known_chunks.append("plst"); /* Play List */
-    known_chunks.append("smpl"); /* Sampler */
-
-    // some sub-chunks from the LIST chunk
-    known_chunks.append("IART");
-    known_chunks.append("ICMT");
-    known_chunks.append("ICOP");
-    known_chunks.append("IENG");
-    known_chunks.append("IGNR");
-    known_chunks.append("IKEY");
-    known_chunks.append("IMED");
-    known_chunks.append("INAM");
-    known_chunks.append("ISRC");
-    known_chunks.append("ITCH");
-    known_chunks.append("ISBJ");
-    known_chunks.append("ISRF");
-
-    // some chunks known from AIFF format
-    known_chunks.append("FVER");
-    known_chunks.append("COMM");
-    known_chunks.append("wave");
-    known_chunks.append("SSND");
-
-    // chunks of .lbm image files, IFF format
-    known_chunks.append("BMHD");
-    known_chunks.append("CMAP");
-    known_chunks.append("BODY");
-
-    RIFFParser parser(src, main_chunks, known_chunks);
+    RIFFParser parser(src, main_chunks, m_known_chunks);
 
     // prepare a progress dialog
     QProgressDialog progress(widget, "Auto-Repair", true);
@@ -152,7 +148,7 @@ bool WavDecoder::open(QWidget *widget, QIODevice &src)
     progress.reset();
     if (progress.wasCancelled()) return false;
 
-    debug("--- RIFF file structure after first pass ---");
+    qDebug("--- RIFF file structure after first pass ---");
     parser.dumpStructure();
 
     // check if there is a RIFF chunk at all...
@@ -196,7 +192,8 @@ bool WavDecoder::open(QWidget *widget, QIODevice &src)
     }
 
     // not everything found -> need heavy repair actions !
-    if (!fmt_chunk || !data_chunk) {
+    if (!fmt_chunk || !data_chunk || need_repair) {
+	qDebug("doing heavy repair actions...");
 	parser.dumpStructure();
 	parser.repair();
 	parser.dumpStructure();
@@ -211,14 +208,14 @@ bool WavDecoder::open(QWidget *widget, QIODevice &src)
 
     u_int32_t fmt_offset = 0;
     if (fmt_chunk) fmt_offset = fmt_chunk->dataStart();
-    debug("fmt chunk starts at 0x%08X", fmt_offset);
+    qDebug("fmt chunk starts at 0x%08X", fmt_offset);
 
     u_int32_t data_offset = 0;
     u_int32_t data_size = 0;
     if (data_chunk) {
 	data_offset = data_chunk->dataStart();
 	data_size   = data_chunk->physLength();
-	debug("data chunk at 0x%08X (%u byte)", data_offset, data_size);
+	qDebug("data chunk at 0x%08X (%u byte)", data_offset, data_size);
     }
 
     if (data_size <= 4) {
@@ -258,7 +255,6 @@ bool WavDecoder::open(QWidget *widget, QIODevice &src)
 
     // read the wave header
     wav_fmt_header_t header;
-    // readWavHeader(src, fmt_offset, fmt_size, &header);
 
     unsigned int rate = 0;
     unsigned int bits = 0;
@@ -285,36 +281,36 @@ bool WavDecoder::open(QWidget *widget, QIODevice &src)
     WavFormatMap known_formats;
     QString format_name = known_formats.findName(header.min.format);
 
-    debug("-------------------------");
-    debug("wav header:");
-    debug("mode        = 0x%04X, (%s)", header.min.format, format_name.data());
-    debug("channels    = %d", header.min.channels);
-    debug("rate        = %u", header.min.samplerate);
-    debug("bytes/s     = %u", header.min.bytespersec);
-    debug("block align = %d", header.min.blockalign);
-    debug("bits/sample = %d", header.min.bitwidth);
-    debug("-------------------------");
+    qDebug("-------------------------");
+    qDebug("wav header:");
+    qDebug("mode        = 0x%04X, (%s)", header.min.format, format_name.latin1());
+    qDebug("channels    = %d", header.min.channels);
+    qDebug("rate        = %u", header.min.samplerate);
+    qDebug("bytes/s     = %u", header.min.bytespersec);
+    qDebug("block align = %d", header.min.blockalign);
+    qDebug("bits/sample = %d", header.min.bitwidth);
+    qDebug("-------------------------");
 
     // open the file through libaudiofile :)
     if (need_repair) {
-	QList<RecoverySource> *repair_list = new QList<RecoverySource>();
-	ASSERT(repair_list);
+	QPtrList<RecoverySource> *repair_list = new QPtrList<RecoverySource>();
+	Q_ASSERT(repair_list);
 	if (!repair_list) return false;
 	
 	RIFFChunk *root = (riff_chunk) ? riff_chunk : parser.findChunk("");
 	parser.dumpStructure();
-	debug("riff chunk = %p, parser.findChunk('')=%p", riff_chunk,
-	    parser.findChunk(""));
+//	qDebug("riff chunk = %p, parser.findChunk('')=%p", riff_chunk,
+//	    parser.findChunk(""));
 	repair(repair_list, root, fmt_chunk, data_chunk);
 	m_src_adapter = new RepairVirtualAudioFile(*m_source, repair_list);
     } else {
 	m_src_adapter = new VirtualAudioFile(*m_source);
     }
 
-    ASSERT(m_src_adapter);
+    Q_ASSERT(m_src_adapter);
     if (!m_src_adapter) return false;
 
-    m_src_adapter->open(m_src_adapter);
+    m_src_adapter->open(m_src_adapter, 0);
 
     AFfilehandle fh = m_src_adapter->handle();
     if (!fh || (m_src_adapter->lastError() >= 0)) {
@@ -362,37 +358,44 @@ bool WavDecoder::open(QWidget *widget, QIODevice &src)
     afGetVirtualSampleFormat(fh, AF_DEFAULT_TRACK, &sample_format,
 	(int *)(&bits));
 
-    QString sample_format_name;
-    switch (sample_format) {
-	case AF_SAMPFMT_TWOSCOMP:
-	    sample_format_name = "linear two's complement";
-	    break;
-	case AF_SAMPFMT_UNSIGNED:
-	    sample_format_name = "unsigned integer";
-	    break;
-	case AF_SAMPFMT_FLOAT:
-	    sample_format_name = "32-bit IEEE floating-point";
-	    break;
-	case AF_SAMPFMT_DOUBLE:
-	    sample_format_name = "64-bit IEEE double-precision floating-point";
-	    break;
-	default:
-	    sample_format_name = "(unknown)";
-    }
+    int compression = afGetCompression(fh, AF_DEFAULT_TRACK);
     if (static_cast<signed int>(bits) < 0) bits = 0;
 
     info().setRate(rate);
     info().setBits(bits);
     info().setTracks(tracks);
     info().setLength(length);
-    debug("-------------------------");
-    debug("info:");
-    debug("channels    = %d", info().tracks());
-    debug("rate        = %0.0f", info().rate());
-    debug("bits/sample = %d", info().bits());
-    debug("length      = %d samples", info().length());
-    debug("format      = %d (%s)", sample_format, sample_format_name.data());
-    debug("-------------------------");
+    info().set(INF_SAMPLE_FORMAT, sample_format);
+    info().set(INF_COMPRESSION, compression);
+
+    // read in all info from the LIST (INFO) chunk
+    RIFFChunk *info_chunk = parser.findChunk("/RIFF/LIST");
+    if (info_chunk && info_chunk->format() == "INFO") {
+	// found info chunk !
+	RIFFChunkList &list = info_chunk->subChunks();
+	QPtrListIterator<RIFFChunk> it(list);
+	for (; it.current(); ++it) {
+	    RIFFChunk &chunk = (*it.current());
+	    if (!m_property_map.contains(chunk.name())) continue;
+	
+	    // read the content into a QString
+	    FileProperty prop = m_property_map[chunk.name()];
+	    unsigned int offset = chunk.dataStart();
+	    unsigned int length = chunk.dataLength();
+	    char *buffer = (char*)malloc(length+1);
+	    Q_ASSERT(buffer);
+	    if (!buffer) continue;
+	
+	    src.at(offset);
+	    src.readBlock(buffer, length);
+	    buffer[length] = 0;
+	    QString value;
+	    value = QString::fromUtf8(buffer);
+	    info().set(prop, value);
+	
+	    delete buffer;
+	}
+    }
 
     // set up libaudiofile to produce Kwave's internal sample format
 #if defined(IS_BIG_ENDIAN)
@@ -409,22 +412,24 @@ bool WavDecoder::open(QWidget *widget, QIODevice &src)
 //***************************************************************************
 bool WavDecoder::decode(QWidget */*widget*/, MultiTrackWriter &dst)
 {
-    ASSERT(m_src_adapter);
-    ASSERT(m_source);
+    Q_ASSERT(m_src_adapter);
+    Q_ASSERT(m_source);
     if (!m_source) return false;
     if (!m_src_adapter) return false;
 
     AFfilehandle fh = m_src_adapter->handle();
-    ASSERT(fh);
+    Q_ASSERT(fh);
     if (!fh) return false;
 
+    info().dump(); // ###
+
     unsigned int frame_size = (unsigned int)afGetVirtualFrameSize(fh,
 	AF_DEFAULT_TRACK, 1);
 
     // allocate a buffer for input data
     const unsigned int buffer_frames = (8*1024);
     int32_t *buffer = (int32_t *)malloc(buffer_frames * frame_size);
-    ASSERT(buffer);
+    Q_ASSERT(buffer);
     if (!buffer) return false;
 
     // read in from the audiofile source
@@ -437,7 +442,7 @@ bool WavDecoder::decode(QWidget */*widget*/, MultiTrackWriter &dst)
 	    AF_DEFAULT_TRACK, (char *)buffer, frames);
 	
 	// break if eof reached	
-	ASSERT(buffer_used);
+	Q_ASSERT(buffer_used);
 	if (!buffer_used) break;
 	rest -= buffer_used;
 	
@@ -446,7 +451,7 @@ bool WavDecoder::decode(QWidget */*widget*/, MultiTrackWriter &dst)
 	unsigned int count = buffer_used;
 	while (count--) {
 	    for (unsigned int track = 0; track < tracks; track++) {
-		register int32_t s = *p++;
+		int32_t s = *p++;
 		
 		// adjust precision
 		if (SAMPLE_STORAGE_BITS != SAMPLE_BITS) {
@@ -469,12 +474,12 @@ bool WavDecoder::decode(QWidget */*widget*/, MultiTrackWriter &dst)
 }
 
 //***************************************************************************
-bool WavDecoder::repairChunk(QList<RecoverySource> *repair_list,
+bool WavDecoder::repairChunk(QPtrList<RecoverySource> *repair_list,
     RIFFChunk *chunk, u_int32_t &offset)
 {
-    ASSERT(chunk);
-    ASSERT(m_source);
-    ASSERT(repair_list);
+    Q_ASSERT(chunk);
+    Q_ASSERT(m_source);
+    Q_ASSERT(repair_list);
     if (!chunk) return false;
     if (!m_source) return false;
     if (!repair_list) return false;
@@ -494,17 +499,17 @@ bool WavDecoder::repairChunk(QList<RecoverySource> *repair_list,
     if (chunk->type() == RIFFChunk::Main) {
 	strncpy(&(buffer[8]), chunk->format().data(), 4);
 	repair = new RecoveryBuffer(offset, 12, buffer);
-	debug("[0x%08X-0x%08X] - main header '%s' (%s), len=%u",
+	qDebug("[0x%08X-0x%08X] - main header '%s' (%s), len=%u",
 	      offset, offset+11, chunk->name().data(),
 	      chunk->format().data(), length);
 	offset += 12;
     } else {
 	repair = new RecoveryBuffer(offset, 8, buffer);
-	debug("[0x%08X-0x%08X] - sub header '%s', len=%u",
+	qDebug("[0x%08X-0x%08X] - sub header '%s', len=%u",
 	      offset, offset+7, chunk->name().data(), length);
 	offset += 8;
     }
-    ASSERT(repair);
+    Q_ASSERT(repair);
     if (!repair) return false;
     repair_list->append(repair);
 
@@ -514,10 +519,10 @@ bool WavDecoder::repairChunk(QList<RecoverySource> *repair_list,
     {
 	repair = new RecoveryMapping(offset, chunk->physLength(),
 	                             *m_source, chunk->dataStart());
-	debug("[0x%08X-0x%08X] - restoring from offset 0x%08X (%u)",
+	qDebug("[0x%08X-0x%08X] - restoring from offset 0x%08X (%u)",
 	      offset, offset+chunk->physLength()-1, chunk->dataStart(),
 	      chunk->physLength());
-	ASSERT(repair);
+	Q_ASSERT(repair);
 	if (!repair) return false;
 	repair_list->append(repair);
 	
@@ -526,7 +531,7 @@ bool WavDecoder::repairChunk(QList<RecoverySource> *repair_list,
 
     // recursively go over all sub-chunks
     RIFFChunkList &list = chunk->subChunks();
-    QListIterator<RIFFChunk> it(list);
+    QPtrListIterator<RIFFChunk> it(list);
     bool ok = true;
     for (; ok && it.current(); ++it) {
 	RIFFChunk *chunk = it.current();
@@ -537,11 +542,11 @@ bool WavDecoder::repairChunk(QList<RecoverySource> *repair_list,
 }
 
 //***************************************************************************
-bool WavDecoder::repair(QList<RecoverySource> *repair_list,
+bool WavDecoder::repair(QPtrList<RecoverySource> *repair_list,
     RIFFChunk *riff_chunk, RIFFChunk *fmt_chunk, RIFFChunk *data_chunk)
 {
-    ASSERT(fmt_chunk);
-    ASSERT(data_chunk);
+    Q_ASSERT(fmt_chunk);
+    Q_ASSERT(data_chunk);
     if (!fmt_chunk || !data_chunk) return false;
 
     // --- first create a chunk tree for the structure ---
@@ -553,14 +558,14 @@ bool WavDecoder::repair(QList<RecoverySource> *repair_list,
     // create a new "fmt " chunk
     RIFFChunk *new_fmt = new RIFFChunk(&new_root, "fmt ",0,0,
 	fmt_chunk->physStart(), fmt_chunk->physLength());
-    ASSERT(new_fmt);
+    Q_ASSERT(new_fmt);
     if (!new_fmt) return false;
     new_root.subChunks().append(new_fmt);
 
     // create a new "data" chunk
     RIFFChunk *new_data = new RIFFChunk(&new_root, "data",0,0,
 	data_chunk->physStart(), data_chunk->physLength());
-    ASSERT(new_data);
+    Q_ASSERT(new_data);
     if (!new_data) return false;
     new_root.subChunks().append(new_data);
 
@@ -570,7 +575,7 @@ bool WavDecoder::repair(QList<RecoverySource> *repair_list,
     // NOTE: The sizes might be re-assigned and get invalid afterwards!!!
     if (riff_chunk) {
 	RIFFChunkList &list = riff_chunk->subChunks();
-	QListIterator<RIFFChunk> it(list);
+	QPtrListIterator<RIFFChunk> it(list);
 	for (; it.current(); ++it) {
 	    RIFFChunk *chunk = it.current();
 	    if (chunk->name() == "fmt ") continue;
@@ -602,13 +607,6 @@ bool WavDecoder::repair(QList<RecoverySource> *repair_list,
     delete new_fmt;
     delete new_data;
 
-//    QListIterator<RecoverySource> it(repair_list);
-//    for (; it.current(); ++it) {
-//	RecoverySource *src = it.current();
-//	QString name = "";
-//	debug("[0x%08X-0x%08X] - %s", src->offset(), src->end(), name.data());
-//    }
-
     return (repaired);
 }
 
