@@ -33,7 +33,8 @@ public:
     /**
      * Constructor.
      * @param parent the parent widget the dialog belongs to
-     * @param samples default sample rate
+     * @param samples default resolution in bits per sample
+     * @param rate default sample rate
      * @param bits default resolution
      * @param tracks default tracks
      * @param by_time if true: select by time, if false: select by samples
@@ -67,17 +68,14 @@ private slots:
 
     /**
      * Checks for modifications of the sample number edit.
-     * That stupid KDoubleNumInput doesn't notify us about changes :-[
+     * That stupid KIntNumInput doesn't notify us about changes :-[
      */
     void checkNewSampleEdit();
 
     /** Checks for changes in the samples or time info */
     void checkTimeAndLengthInfo(int);
 
-    /** updates rbTime if rbSamples has been toggled */
-    void rbSamplesToggled(bool);
-
-    /** updates rbSignal if rbTime has been toggled */
+    /** starts/stops the sample edit's timer if rbTime has been toggled */
     void rbTimeToggled(bool);
 
     /** updates the number of samples if the time changed */
@@ -90,7 +88,7 @@ private slots:
     void tracksChanged(int);
 
     /** number of samples changed */
-    void samplesChanged(double);
+    void samplesChanged(int);
 
     /** updates the file size */
     void updateFileSize();
@@ -108,7 +106,7 @@ private:
      * with the current settings, based on the maximum file size of a .wav
      * file and the header sizes.
      */
-    double maxSamples();
+    unsigned int maxSamples();
 
     /**
      * Sets hours, minutes and seconds according to a given
