@@ -30,6 +30,7 @@ NewSignalPlugin::NewSignalPlugin(PluginContext &context)
     :KwavePlugin(context), m_samples(2646000), m_rate(44100),
     m_bits(16), m_tracks(2), m_bytime(true)
 {
+    i18n("newsignal");
 }
 
 //***************************************************************************
@@ -44,36 +45,31 @@ int NewSignalPlugin::interpreteParameters(QStringList &params)
     QString param;
 
     // evaluate the parameter list
-    ASSERT(params.count() == 5);
-    if (params.count() != 5) {
-	warning("NewSignalPlugin::interpreteParams(): params.count()=%d",
-	      params.count());
-	return -EINVAL;
-    }
+    if (params.count() != 5) return -EINVAL;
 
     param = params[0];
     m_samples = param.toUInt(&ok);
-    ASSERT(ok);
+    Q_ASSERT(ok);
     if (!ok) return -EINVAL;
 
     param = params[1];
     m_rate = (unsigned int)param.toDouble(&ok);
-    ASSERT(ok);
+    Q_ASSERT(ok);
     if (!ok) return -EINVAL;
 
     param = params[2];
     m_bits = param.toUInt(&ok);
-    ASSERT(ok);
+    Q_ASSERT(ok);
     if (!ok) return -EINVAL;
 
     param = params[3];
     m_tracks = param.toUInt(&ok);
-    ASSERT(ok);
+    Q_ASSERT(ok);
     if (!ok) return -EINVAL;
 
     param = params[4];
     m_bytime = (param.toUInt(&ok) != 0);
-    ASSERT(ok);
+    Q_ASSERT(ok);
     if (!ok) return -EINVAL;
 
     return 0;
@@ -88,11 +84,11 @@ QStringList *NewSignalPlugin::setup(QStringList &previous_params)
     // create the setup dialog
     NewSignalDialog *dialog = new NewSignalDialog(parentWidget(),
         m_samples, m_rate, m_bits, m_tracks, m_bytime);
-    ASSERT(dialog);
+    Q_ASSERT(dialog);
     if (!dialog) return 0;
 
     QStringList *list = new QStringList();
-    ASSERT(list);
+    Q_ASSERT(list);
     if (list && dialog->exec()) {
 	// user has pressed "OK"
 	*list << QString::number(dialog->samples());
