@@ -22,7 +22,7 @@
 #include <qstring.h>
 #include <qstringlist.h>
 
-#include "libgui/KwavePlugin.h"
+#include "libkwave/KwavePlugin.h"
 
 class NoisePlugin: public KwavePlugin
 {
