@@ -21,6 +21,7 @@
 #include <stdlib.h>
 #include <sys/ioctl.h>
 #include <linux/soundcard.h>
+#include <math.h>
 
 #include <klocale.h>
 
@@ -54,12 +55,12 @@ PlayBackOSS::~PlayBackOSS()
 }
 
 //***************************************************************************
-QString PlayBackOSS::open(const QString &device, unsigned int rate,
+QString PlayBackOSS::open(const QString &device, double rate,
                           unsigned int channels, unsigned int bits,
                           unsigned int bufbase)
 {
-    debug("PlayBackOSS::open(device=%s,rate=%u,channels=%u,"\
-	"bits=%u, bufbase=%u)", device.data(), rate, channels,
+    qDebug("PlayBackOSS::open(device=%s,rate=%f,channels=%u,"\
+	"bits=%u, bufbase=%u)", device.latin1(), rate, channels,
 	bits, bufbase);
 
     m_device_name = device;
@@ -73,8 +74,8 @@ QString PlayBackOSS::open(const QString &device, unsigned int rate,
 
     // prepeare for playback by opening the sound device
     // and initializing with the proper settings
-    m_handle = ::open(m_device_name.data(), O_WRONLY | O_NONBLOCK);
-    debug("PlayBackOSS::open(): file descriptor=%u", m_handle);
+    m_handle = ::open(m_device_name.latin1(), O_WRONLY | O_NONBLOCK);
+    qDebug("PlayBackOSS::open(): file descriptor=%u", m_handle);
     if (m_handle == -1) {
 	QString reason;
 	switch (errno) {
@@ -124,13 +125,14 @@ QString PlayBackOSS::open(const QString &device, unsigned int rate,
     }
 
     // playback rate
-    if (ioctl(m_handle, SNDCTL_DSP_SPEED, &m_rate) == -1) {
-	return i18n("playback rate %1 Hz is not supported").arg(m_rate);
+    int int_rate = (int)m_rate;
+    if (ioctl(m_handle, SNDCTL_DSP_SPEED, &int_rate) == -1) {
+	return i18n("playback rate %1 Hz is not supported").arg(int_rate);
     }
 
     // buffer size
-    ASSERT(bufbase >= MIN_PLAYBACK_BUFFER);
-    ASSERT(bufbase <= MAX_PLAYBACK_BUFFER);
+    Q_ASSERT(bufbase >= MIN_PLAYBACK_BUFFER);
+    Q_ASSERT(bufbase <= MAX_PLAYBACK_BUFFER);
     if (bufbase < MIN_PLAYBACK_BUFFER) bufbase = MIN_PLAYBACK_BUFFER;
     if (bufbase > MAX_PLAYBACK_BUFFER) bufbase = MAX_PLAYBACK_BUFFER;
     if (ioctl(m_handle, SNDCTL_DSP_SETFRAGMENT, &bufbase) == -1) {
@@ -147,11 +149,11 @@ QString PlayBackOSS::open(const QString &device, unsigned int rate,
 }
 
 //***************************************************************************
-int PlayBackOSS::write(QArray<sample_t> &samples)
+int PlayBackOSS::write(QMemArray<sample_t> &samples)
 {
-    ASSERT (m_buffer_used < m_buffer_size);
+    Q_ASSERT (m_buffer_used < m_buffer_size);
     if (m_buffer_used >= m_buffer_size) {
-	warning("PlayBackOSS::write(): buffer overflow ?!");
+	qWarning("PlayBackOSS::write(): buffer overflow ?!");
 	return -EIO;
     }
 
