@@ -23,27 +23,28 @@
 #include <stdlib.h>
 #include <errno.h>
 
-#include <qarray.h>
-#include <qvector.h>
+#include <qmemarray.h>
+#include <qfile.h>
+#include <qptrvector.h>
 #include <qstring.h>
 
 #include <kapp.h>
 #include <kmessagebox.h>
 
 #include "mt/Mutex.h"
+#include "mt/ThreadsafeX11Guard.h"
 
+#include "libkwave/KwavePlugin.h"
 #include "libkwave/Matrix.h"
+#include "libkwave/PlayBackDevice.h"
 #include "libkwave/Sample.h"
 #include "libkwave/SampleReader.h"
 #include "libkwave/MultiTrackReader.h"
 
-#include "libgui/KwavePlugin.h"
-
 #include "kwave/PlaybackController.h"
 #include "kwave/PluginManager.h"
 #include "kwave/SignalManager.h"
 
-#include "PlayBackDevice.h"
 #include "PlayBack-OSS.h"
 #include "PlayBack-aRts.h"
 
@@ -61,8 +62,8 @@ KWAVE_PLUGIN(PlayBackPlugin,"playback","Thomas Eschenbacher");
 /** Pattern for recognizing that aRts playback is selected */
 #define MAGIC_ARTS "aRts"
 
-///** Mutex for the aRts daemon, it seems to be not threadsafe */
-//static Mutex g_arts_lock;
+/** Mutex for the aRts daemon, it seems to be not threadsafe */
+static Mutex *g_arts_lock;
 
 #ifndef min
 #define min(x,y) (( (x) < (y) ) ? (x) : (y) )
@@ -91,11 +92,18 @@ PlayBackPlugin::PlayBackPlugin(PluginContext &context)
     m_playback_params.bufbase = 10;
 
     m_spx_playback_pos.setLimit(8); // limit for the queue
+
+    // register as a factory for playback devices
+    manager().registerPlaybackDeviceFactory(this);
+    i18n("playback");
 }
 
 //***************************************************************************
 PlayBackPlugin::~PlayBackPlugin()
 {
+    // unregister from the list playback factories
+    manager().unregisterPlaybackDeviceFactory(this);
+
     // close the device now if it accidentally is still open
     MutexGuard lock_for_delete(m_lock_device);
     m_stop = true;
@@ -110,23 +118,18 @@ int PlayBackPlugin::interpreteParameters(QStringList &params)
     QString param;
 
     // evaluate the parameter list
-    ASSERT(params.count() == 4);
-    if (params.count() != 4) {
-	debug("PlayBackPlugin::interpreteParams(): params.count()=%d",
-	      params.count());
-	return -EINVAL;
-    }
+    if (params.count() != 4) return -EINVAL;
 
     // parameter #0: number of channels [1 | 2]
     param = params[0];
     m_playback_params.channels = param.toUInt(&ok);
-    ASSERT(ok);
+    Q_ASSERT(ok);
     if (!ok) return -EINVAL;
 
     // parameter #1: bits per sample [8 | 16 ]
     param = params[1];
     m_playback_params.bits_per_sample = param.toUInt(&ok);
-    ASSERT(ok);
+    Q_ASSERT(ok);
     if (!ok) return -EINVAL;
 
     // parameter #2: playback device [/dev/dsp , ... ]
@@ -136,7 +139,7 @@ int PlayBackPlugin::interpreteParameters(QStringList &params)
     // parameter #3: base of buffer size [4...16]
     param = params[3];
     m_playback_params.bufbase = param.toUInt(&ok);
-    ASSERT(ok);
+    Q_ASSERT(ok);
     if (!ok) return -EINVAL;
 
     return 0;
@@ -162,13 +165,13 @@ QStringList *PlayBackPlugin::setup(QStringList &previous_params)
     if (previous_params.count()) interpreteParameters(previous_params);
 
     PlayBackDialog *dlg = new PlayBackDialog(*this, m_playback_params);
-    ASSERT(dlg);
+    Q_ASSERT(dlg);
     if (!dlg) return 0;
 
     if (dlg->exec() == QDialog::Accepted) {
 	// get the new parameters and let them take effect
 	result = new QStringList();
-	ASSERT(result);
+	Q_ASSERT(result);
 	if (result) {
 	    dlg->parameters(*result);
 	    interpreteParameters(*result);
@@ -180,57 +183,89 @@ QStringList *PlayBackPlugin::setup(QStringList &previous_params)
 }
 
 //***************************************************************************
-void PlayBackPlugin::openDevice()
+bool PlayBackPlugin::supportsDevice(const QString &name)
 {
-    MutexGuard lock_for_delete(m_lock_device);
+    // we know about the "default" device !
+    if (name == "") return true; 
 
-    // remove the old device if still one exists
-    if (m_device) {
-	warning("PlayBackPlugin::openDevice(): removing stale instance");
-	delete m_device;
+    // we support aRts playback
+    if (name.contains(MAGIC_ARTS)) return true;
+
+    // if it is a device name -> suggest OSS/ALSA output
+    QFile file(name);
+    if (file.exists()) return true;
+    
+    // default: not supported by us
+    return false;
+}
+
+//***************************************************************************
+PlayBackDevice *PlayBackPlugin::openDevice(const QString &name,
+    const PlayBackParam *playback_params)
+{
+    QString device_name = name;
+    PlayBackParam params;
+    PlayBackDevice *device = 0;
+
+    if (!playback_params) {
+	// use default parameters if none given
+	params          = m_playback_params;
+	params.rate     = fileInfo().rate();
+	params.channels = selectedTracks().count();
+    } else {
+	// use given parameters
+	params = *playback_params;
     }
 
-    // create the playback device
-
+    // use default device if no name is given
+    if (!device_name.length()) device_name = params.device;
+    
     // here comes the switch for different playback devices...
-    if (m_playback_params.device.contains(MAGIC_ARTS)) {
-	static Mutex g_arts_lock;
-	m_device = new PlayBackArts(g_arts_lock);
+    if (device_name.contains(MAGIC_ARTS)) {
+	ThreadsafeX11Guard x11_guard;
+	
+	// if no mutex exists: make a new one, parent is the global app!
+	/** @todo this mutex is actually never deleted ! */
+	if (!g_arts_lock) g_arts_lock = new Mutex();
+	Q_ASSERT(g_arts_lock);
+	
+	device = new PlayBackArts(*g_arts_lock);
     } else {
 	// default is OSS or similar device
-	m_device = new PlayBackOSS();
+	device = new PlayBackOSS();
     }
 
-    ASSERT(m_device);
-    if (!m_device) {
-	warning("PlayBackPlugin::openDevice(): "\
+    Q_ASSERT(device);
+    if (!device) {
+	qWarning("PlayBackPlugin::openDevice(): "\
 		"creating device failed.");
-	return;
+	return 0;
     }
 
     // open and initialize the device
-    QString result = m_device->open(
-	m_playback_params.device,
-	m_playback_params.rate,
-	m_playback_params.channels,
-	m_playback_params.bits_per_sample,
-	m_playback_params.bufbase
+    QString result = device->open(
+	params.device,
+	params.rate,
+	params.channels,
+	params.bits_per_sample,
+	params.bufbase
     );
-    ASSERT(!result.length());
+    Q_ASSERT(!result.length());
     if (result.length()) {
-	warning("PlayBackPlugin::openDevice(): "\
+	qWarning("PlayBackPlugin::openDevice(): "\
 	        "opening the device failed.");
 	
 	// delete the device if it did not open
-	delete m_device;
-	m_device = 0;
+	delete device;
+	device = 0;
 	
 	// show an error message box
 	KMessageBox::error(parentWidget(), result,
 	    i18n("unable to open '%1'").arg(
-	    m_playback_params.device));
-	return;
+	    params.device));
     }
+
+    return device;    
 }
 
 //***************************************************************************
@@ -239,7 +274,7 @@ void PlayBackPlugin::closeDevice()
     MutexGuard lock_for_delete(m_lock_device);
 
     if (!m_device) return; // already closed
-    if (m_device) delete m_device;
+    delete m_device;
     m_device = 0;
     m_old_first = 0;
     m_old_last = 0;
@@ -251,8 +286,18 @@ void PlayBackPlugin::startDevicePlayBack()
     // set the real sample rate for playback from the signal itself
     m_playback_params.rate = signalRate();
 
+    MutexGuard lock_for_delete(m_lock_device);
+
+    // remove the old device if still one exists
+    if (m_device) {
+	qWarning("PlayBackPlugin::openDevice(): removing stale instance");
+	delete m_device;
+    }
+
     // open the device and abort if not possible
-    openDevice();
+    qDebug("PlayBackPlugin::startDevicePlayBack(), device='%s'",
+          m_playback_params.device.latin1());
+    m_device = openDevice(m_playback_params.device, &m_playback_params);
     if (!m_device) {
 	// simulate a "playback done" on errors
 	playbackDone();
@@ -271,7 +316,7 @@ void PlayBackPlugin::startDevicePlayBack()
 		// something selected -> set new range
 		m_playback_controller.setStartPos(first);
 		m_playback_controller.setEndPos(last);
-		
+
 		unsigned int pos = m_playback_controller.currentPos();
 		if ((pos < first) || (pos > last)) {
 		    // completely new area selected, or the right margin
@@ -304,7 +349,8 @@ void PlayBackPlugin::startDevicePlayBack()
     m_old_last = last;
     m_stop = false;
 
-    static QStringList empty_list;
+    QStringList empty_list;
+    use();
     execute(empty_list);
 }
 
@@ -325,11 +371,11 @@ void PlayBackPlugin::run(QStringList)
     unsigned int out_channels = m_playback_params.channels;
 
     // get the list of selected channels
-    QArray<unsigned int> audible_tracks = selectedTracks();
+    QMemArray<unsigned int> audible_tracks = selectedTracks();
     unsigned int audible_count = audible_tracks.count();
     if (!audible_count) {
 	// not even one selected track
-	debug("PlayBackPlugin::run(): no audible track(s) !");
+	qDebug("PlayBackPlugin::run(): no audible track(s) !");
 	playbackDone();
 	return;
     }
@@ -346,16 +392,16 @@ void PlayBackPlugin::run(QStringList)
 	unsigned int m1, m2;
 	m1 = y * audible_count;
 	m2 = (y+1) * audible_count;
-	
+
 	for (x=0; x < audible_count; x++) {
 	    unsigned int n1, n2;
 	    n1 = x * out_channels;
 	    n2 = n1 + out_channels;
-	
+
 	    // get the common area of [n1..n2] and [m1..m2]
 	    unsigned int l  = max(n1, m1);
 	    unsigned int r = min(n2, m2);
-	
+
 	    matrix[x][y] = (r > l) ?
 		(double)(r-l) / (double)audible_count : 0.0;
 	}
@@ -363,8 +409,8 @@ void PlayBackPlugin::run(QStringList)
 
     // loop until process is stopped
     // or run once if not in loop mode
-    QArray<sample_t> in_samples(audible_count);
-    QArray<sample_t> out_samples(out_channels);
+    QMemArray<sample_t> in_samples(audible_count);
+    QMemArray<sample_t> out_samples(out_channels);
     unsigned int pos = m_playback_controller.currentPos();
 
     // counter for refresh of the playback position
@@ -381,20 +427,20 @@ void PlayBackPlugin::run(QStringList)
 		if (stream) stream->skip(pos-first);
 	    }
 	}
-	
+
 	while ((pos++ <= last) && !m_stop) {
 	    unsigned int x;
 	    for (x=0; x < audible_count; x++) {
 		in_samples[x] = 0;
 		SampleReader *stream = input[x];
-		ASSERT(stream);
+		Q_ASSERT(stream);
 		if (!stream) continue;
-		
+
 		sample_t act;
 		(*stream) >> act;
 		in_samples[x] = act;
 	    }
-		
+
 	    // multiply matrix with input to get output
 	    unsigned int y;
 	    for (y=0; y < out_channels; y++) {
@@ -404,31 +450,28 @@ void PlayBackPlugin::run(QStringList)
 		}
 		out_samples[y] = (sample_t)sum;
 	    }
-	
+
 	    // write samples to the playback device
 	    int result = m_device->write(out_samples);
 	    if (result) {
 		m_stop = true;
 		pos = last;
 	    }
-	
+
 	    // update the playback position if timer elapsed
 	    if (!pos_countdown) {
-		pos_countdown = m_playback_params.rate /
-			SCREEN_REFRESHES_PER_SECOND;
+		pos_countdown = (unsigned int)ceil(m_playback_params.rate /
+			SCREEN_REFRESHES_PER_SECOND);
 		m_spx_playback_pos.enqueue(pos);
 	    } else {
 		--pos_countdown;
 	    }
 	}
-	
+
 	// maybe we loop. in this case the playback starts
 	// again from the left marker
 	if (m_playback_controller.loop() && !m_stop) {
-	    for (x=0; x < audible_count; x++) {
-		SampleReader *stream = input[x];
-		if (stream) stream->reset();
-	    }
+	    input.reset();
 	    pos = m_playback_controller.startPos();
 	}
 
@@ -441,7 +484,7 @@ void PlayBackPlugin::run(QStringList)
 
     // playback is done
     playbackDone();
-    debug("PlayBackPlugin::run() done.");
+//    qDebug("PlayBackPlugin::run() done.");
 }
 
 //***************************************************************************
@@ -454,7 +497,7 @@ void PlayBackPlugin::updatePlaybackPos()
     if (!count) return;
     while (count--) {
 	unsigned int *ppos = m_spx_playback_pos.dequeue();
-	ASSERT(ppos);
+	Q_ASSERT(ppos);
 	if (!ppos) continue;
 	pos = *ppos;
 	delete ppos;
