@@ -25,7 +25,7 @@
 #include "kwave/PluginManager.h"
 #include "kwave/SignalManager.h"
 #include "kwave/UndoTransactionGuard.h"
-#include "libgui/KwavePlugin.h"
+#include "libkwave/KwavePlugin.h"
 #include "SelectRangePlugin.h"
 #include "SelectRangeDialog.h"
 
@@ -33,8 +33,10 @@ KWAVE_PLUGIN(SelectRangePlugin,"selectrange","Thomas Eschenbacher");
 
 //***************************************************************************
 SelectRangePlugin::SelectRangePlugin(PluginContext &c)
-    :KwavePlugin(c), m_mode(bySamples), m_range(0)
+    :KwavePlugin(c), m_start_mode(SelectTimeWidget::bySamples),
+     m_range_mode(SelectTimeWidget::bySamples), m_range(0)
 {
+     i18n("selectrange");
 }
 
 //***************************************************************************
@@ -55,19 +57,23 @@ QStringList *SelectRangePlugin::setup(QStringList &previous_params)
     unsigned int length = signalLength();
 
     SelectRangeDialog *dialog = new SelectRangeDialog(parentWidget(),
-        m_mode, m_range, rate, offset, length);
-    ASSERT(dialog);
+        m_start_mode, m_range_mode, m_range, rate, offset, length);
+    Q_ASSERT(dialog);
     if (!dialog) return 0;
 
     QStringList *list = new QStringList();
-    ASSERT(list);
+    Q_ASSERT(list);
     if (list && dialog->exec()) {
 	// user has pressed "OK"
-	*list << QString::number(dialog->mode());
+	*list << QString::number(dialog->startMode());
+	*list << QString::number(dialog->rangeMode());
+	*list << QString::number(dialog->start());
 	*list << QString::number(dialog->range());
 	
 	emitCommand("plugin:execute(selectrange,"+
-	    QString::number(dialog->mode())+","+
+	    QString::number(dialog->startMode())+","+
+	    QString::number(dialog->rangeMode())+","+
+	    QString::number(dialog->start())+","+
 	    QString::number(dialog->range())+
 	    ")"
 	);
@@ -90,23 +96,41 @@ int SelectRangePlugin::start(QStringList &params)
 
     // get current offset of the signal
     unsigned int offset = 0;
-    selection(&offset, 0, false);
+    switch (m_start_mode) {
+	case SelectTimeWidget::byTime: {
+	    // convert from ms to samples
+	    double rate = signalRate();
+	    offset = (unsigned int)rint(m_start / 1E3 * rate);
+	    break;
+	}
+	case SelectTimeWidget::bySamples: {
+	    // simple case -> already in samples
+	    offset = (unsigned int)rint(m_start);
+	    break;
+	}
+	case SelectTimeWidget::byPercents: {
+	    // by percentage of whole signal
+	    unsigned sig_length = signalLength();
+	    offset = (unsigned int)rint((double)sig_length*(m_start/100.0));
+	    break;
+	}
+    }
 
     // transform into offset and length [samples]
     unsigned int length = 0;
-    switch (m_mode) {
-	case byTime: {
+    switch (m_range_mode) {
+	case SelectTimeWidget::byTime: {
 	    // convert from ms to samples
 	    double rate = signalRate();
 	    length = (unsigned int)rint(m_range / 1E3 * rate);
 	    break;
 	}
-	case bySamples: {
+	case SelectTimeWidget::bySamples: {
 	    // simple case -> already in samples
 	    length = (unsigned int)rint(m_range);
 	    break;
 	}
-	case byPercents: {
+	case SelectTimeWidget::byPercents: {
 	    // by percentage of whole signal
 	    unsigned sig_length = signalLength();
 	    length = (unsigned int)rint((double)sig_length*(m_range/100.0));
@@ -132,33 +156,56 @@ int SelectRangePlugin::interpreteParameters(QStringList &params)
 {
     bool ok;
     QString param;
+    int mode;
 
     // evaluate the parameter list
-    ASSERT(params.count() == 2);
-    if (params.count() != 2) {
-	warning("SelectRangePlugin::interpreteParams(): params.count()=%d",
-	      params.count());
+    if (params.count() != 4) {
 	return -EINVAL;
     }
 
-    // selection mode
+    // selection mode for start
     param = params[0];
-    int mode = param.toInt(&ok);
-    ASSERT(ok);
+    mode = param.toInt(&ok);
+    Q_ASSERT(ok);
     if (!ok) return -EINVAL;
-    ASSERT((mode == (int)byTime) || (mode == (int)bySamples) ||
-           (mode == (int)byPercents));
-    if ((mode != (int)byTime) && (mode != (int)bySamples) &&
-        (mode != (int)byPercents))
+    Q_ASSERT((mode == (int)SelectTimeWidget::byTime) ||
+           (mode == (int)SelectTimeWidget::bySamples) ||
+           (mode == (int)SelectTimeWidget::byPercents));
+    if ((mode != (int)SelectTimeWidget::byTime) &&
+        (mode != (int)SelectTimeWidget::bySamples) &&
+        (mode != (int)SelectTimeWidget::byPercents))
     {
 	return -EINVAL;
     }
-    m_mode = (SelectionMode)mode;
+    m_start_mode = (SelectTimeWidget::Mode)mode;
+
+
+    // selection mode
+    param = params[1];
+    mode = param.toInt(&ok);
+    Q_ASSERT(ok);
+    if (!ok) return -EINVAL;
+    Q_ASSERT((mode == (int)SelectTimeWidget::byTime) ||
+           (mode == (int)SelectTimeWidget::bySamples) ||
+           (mode == (int)SelectTimeWidget::byPercents));
+    if ((mode != (int)SelectTimeWidget::byTime) &&
+        (mode != (int)SelectTimeWidget::bySamples) &&
+        (mode != (int)SelectTimeWidget::byPercents))
+    {
+	return -EINVAL;
+    }
+    m_range_mode = (SelectTimeWidget::Mode)mode;
+
+    // offset in ms, samples or percent
+    param = params[2];
+    m_start = (unsigned int)param.toDouble(&ok);
+    Q_ASSERT(ok);
+    if (!ok) return -EINVAL;
 
     // range in ms, samples or percent
-    param = params[1];
+    param = params[3];
     m_range = (unsigned int)param.toDouble(&ok);
-    ASSERT(ok);
+    Q_ASSERT(ok);
     if (!ok) return -EINVAL;
 
     return 0;
