@@ -30,11 +30,11 @@
 
 #include "mt/SignalProxy.h"
 #include "libkwave/gsl_fft.h"
+#include "libkwave/KwavePlugin.h"
 #include "libkwave/MultiTrackReader.h"
 #include "libkwave/Sample.h"
 #include "libkwave/SampleReader.h"
 #include "libkwave/WindowFunction.h"
-#include "libgui/KwavePlugin.h"
 #include "libgui/OverViewCache.h"
 #include "kwave/PluginManager.h"
 #include "kwave/SignalManager.h"
@@ -78,6 +78,7 @@ SonagramPlugin::SonagramPlugin(PluginContext &c)
 {
     m_spx_insert_stripe = new SignalProxy1< StripeInfoPrivate >
 	(this, SLOT(insertStripe()));
+    i18n("sonagram");
 }
 
 //***************************************************************************
@@ -102,7 +103,7 @@ QStringList *SonagramPlugin::setup(QStringList &previous_params)
     if (previous_params.count()) interpreteParameters(previous_params);
 
     SonagramDialog *dlg = new SonagramDialog(*this);
-    ASSERT(dlg);
+    Q_ASSERT(dlg);
     if (!dlg) return 0;
 
     dlg->setWindowFunction(m_window_type);
@@ -112,7 +113,7 @@ QStringList *SonagramPlugin::setup(QStringList &previous_params)
 
     if (dlg->exec() == QDialog::Accepted) {
 	result = new QStringList();
-	ASSERT(result);
+	Q_ASSERT(result);
 	if (result) dlg->parameters(*result);
     };
 
@@ -127,38 +128,33 @@ int SonagramPlugin::interpreteParameters(QStringList &params)
     QString param;
 
     // evaluate the parameter list
-    ASSERT(params.count() == 5);
-    if (params.count() != 5) {
-	warning("SonagramPlugin::interpreteParams(): params.count()=%d",
-	      params.count());
-	return -EINVAL;
-    }
+    if (params.count() != 5) return -EINVAL;
 	
     param = params[0];
     m_fft_points = param.toUInt(&ok);
-    ASSERT(ok);
+    Q_ASSERT(ok);
     if (!ok) return -EINVAL;
-    ASSERT(m_fft_points <= 32767);
+    Q_ASSERT(m_fft_points <= 32767);
     if (m_fft_points > 32767) m_fft_points=32767;
 
     param = params[1];
     m_window_type = WindowFunction::findFromName(param);
-    ASSERT(ok);
+    Q_ASSERT(ok);
     if (!ok) return -EINVAL;
 
     param = params[2];
     m_color = (param.toUInt(&ok) != 0);
-    ASSERT(ok);
+    Q_ASSERT(ok);
     if (!ok) return -EINVAL;
 
     param = params[3];
     m_track_changes = false; // (param.toUInt(&ok) != 0);
-    ASSERT(ok);
+    Q_ASSERT(ok);
     if (!ok) return -EINVAL;
 
     param = params[4];
     m_follow_selection = false; // (param.toUInt(&ok) != 0);
-    ASSERT(ok);
+    Q_ASSERT(ok);
     if (!ok) return -EINVAL;
 
     return 0;
@@ -173,7 +169,7 @@ int SonagramPlugin::start(QStringList &params)
 
     // create an empty sonagram window
     m_sonagram_window = new SonagramWindow(signalName());
-    ASSERT(m_sonagram_window);
+    Q_ASSERT(m_sonagram_window);
     if (!m_sonagram_window) return -ENOMEM;
 
     unsigned int input_length = selection(&m_first_sample, &m_last_sample);
@@ -186,7 +182,7 @@ int SonagramPlugin::start(QStringList &params)
     // calculate the number of stripes (width of image)
     m_stripes = (unsigned int)
 	(ceil((double)input_length/(double)m_fft_points));
-    ASSERT(m_stripes <= 32767);
+    Q_ASSERT(m_stripes <= 32767);
     if (m_stripes > 32767) m_stripes = 32767;
 
     // create a new empty image
@@ -195,11 +191,11 @@ int SonagramPlugin::start(QStringList &params)
     // set the overview
     m_selected_channels = selectedTracks();
     SignalManager &sig_mgr = manager().topWidget().signalManager();
-    QArray<unsigned int> tracks = sig_mgr.selectedTracks();
+    QMemArray<unsigned int> tracks = sig_mgr.selectedTracks();
     m_overview_cache = new OverViewCache(sig_mgr,
         m_first_sample, m_last_sample-m_first_sample+1,
         tracks.isEmpty() ? 0 : &tracks);
-    ASSERT(m_overview_cache);
+    Q_ASSERT(m_overview_cache);
     if (!m_overview_cache) return -ENOMEM;
 
     refreshOverview();
@@ -223,7 +219,7 @@ int SonagramPlugin::start(QStringList &params)
 
     // connect all needed signals
     connect(m_sonagram_window, SIGNAL(destroyed()),
-	    this, SLOT(windowClosed()));
+	    this, SLOT(windowDestroyed()));
 
     if (m_track_changes) {
 	QObject::connect((QObject*)&(manager()),
@@ -231,6 +227,10 @@ int SonagramPlugin::start(QStringList &params)
 	    m_sonagram_window, SLOT(setName(const QString &)));
     }
 
+    // increment the usage counter and release the plugin when the
+    // sonagram window closed
+    use();
+
     m_cmd_shutdown = false; // ###
     return 0;
 }
@@ -245,26 +245,26 @@ int SonagramPlugin::stop()
 //***************************************************************************
 void SonagramPlugin::run(QStringList /* params */)
 {
-//    debug("SonagramPlugin::run()");
+//    qDebug("SonagramPlugin::run()");
 
-    ASSERT(m_spx_insert_stripe);
+    Q_ASSERT(m_spx_insert_stripe);
     if (!m_spx_insert_stripe) return;
 
     MultiTrackReader source;
     manager().openMultiTrackReader(source, selectedTracks(),
 	m_first_sample, m_last_sample);
-//    debug("SonagramPlugin::run(), first=%u, last=%u",m_first_sample,m_last_sample);
+//    qDebug("SonagramPlugin::run(), first=%u, last=%u",m_first_sample,m_last_sample);
 
     while (!m_cmd_shutdown) {
 	QByteArray *stripe_data;
 	unsigned int stripe_nr;
 	for (stripe_nr = 0; stripe_nr < m_stripes; stripe_nr++) {
-//	    debug("SonagramPlugin::run(): calculating stripe %d of %d",
+//	    qDebug("SonagramPlugin::run(): calculating stripe %d of %d",
 //	        stripe_nr,m_stripes);
 	
 	    // create a new stripe data array
 	    stripe_data = new QByteArray(m_fft_points/2);
-	    ASSERT(stripe_data);
+	    Q_ASSERT(stripe_data);
 	    if (!stripe_data) continue;
 	
 	    // calculate one stripe
@@ -295,25 +295,24 @@ void SonagramPlugin::run(QStringList /* params */)
 	m_cmd_shutdown = true;
     }
 
-//    debug("SonagramPlugin::run(): done.");
+//    qDebug("SonagramPlugin::run(): done.");
 }
 
 //***************************************************************************
 void SonagramPlugin::insertStripe()
 {
-//    debug("SonagramPlugin::insertStripe()");
-    ASSERT(m_spx_insert_stripe);
+//    qDebug("SonagramPlugin::insertStripe()");
+    Q_ASSERT(m_spx_insert_stripe);
     if (!m_spx_insert_stripe) return;
 
     StripeInfoPrivate *stripe_info = m_spx_insert_stripe->dequeue();
-    ASSERT(stripe_info);
+    Q_ASSERT(stripe_info);
     if (!stripe_info) return;
 
     unsigned int stripe_nr = stripe_info->nr();
     const QByteArray *stripe = &(stripe_info->data());
 
     // forward the stripe to the window to display it
-    ASSERT(m_sonagram_window);
     if (m_sonagram_window) m_sonagram_window->insertStripe(
 	stripe_nr, *stripe);
 
@@ -329,12 +328,12 @@ void SonagramPlugin::calculateStripe(MultiTrackReader &source,
     output.fill(0);
 
     WindowFunction func(m_window_type);
-    QArray<double> windowfunction = func.points(points);
-    ASSERT(windowfunction.count() == points);
+    QMemArray<double> windowfunction = func.points(points);
+    Q_ASSERT(windowfunction.count() == points);
     if (windowfunction.count() != points) return;
 
-    QArray<complex> input(points);
-    ASSERT(input.size() == points);
+    QMemArray<complex> input(points);
+    Q_ASSERT(input.size() == points);
     if (input.size() < points) return;
 
     // initialize the table for fft
@@ -351,7 +350,7 @@ void SonagramPlugin::calculateStripe(MultiTrackReader &source,
 	    for (t=0; t < count; t++) {
 		sample_t s = 0;
 		SampleReader *reader = source[t];
-		ASSERT(reader);
+		Q_ASSERT(reader);
 		if (reader) *reader >> s;
 		value += (double)s;
 	    }
@@ -402,27 +401,27 @@ void SonagramPlugin::calculateStripe(MultiTrackReader &source,
 void SonagramPlugin::createNewImage(const unsigned int width,
 	const unsigned int height)
 {
-//    debug("SonagramPlugin::createNewImage()");
+//    qDebug("SonagramPlugin::createNewImage()");
 
     // delete the previous image
     if (m_image) delete m_image;
     m_image = 0;
 
     // do not create a new image if one dimension is zero!
-    ASSERT(width);
-    ASSERT(height);
+    Q_ASSERT(width);
+    Q_ASSERT(height);
     if (!width || !height) return;
 
     // also do not create if the image size is out of range
-    ASSERT(width <= 32767);
-    ASSERT(height <= 32767);
+    Q_ASSERT(width <= 32767);
+    Q_ASSERT(height <= 32767);
     if ((width >= 32767) || (height >= 32767)) return;
 
-//    debug("SonagramPlugin::createNewImage(): settings ok, creating image");
+//    qDebug("SonagramPlugin::createNewImage(): settings ok, creating image");
 
     // create the new image object
     m_image = new QImage(width, height, 8, 256);
-    ASSERT(m_image);
+    Q_ASSERT(m_image);
     if (!m_image) return;
     m_image->setAlphaBuffer(true);
 
@@ -434,7 +433,7 @@ void SonagramPlugin::createNewImage(const unsigned int width,
     // fill the image with "empty"
     m_image->fill(0xFF);
 
-//    debug("SonagramPlugin::createNewImage(): done.");
+//    qDebug("SonagramPlugin::createNewImage(): done.");
 }
 
 //***************************************************************************
@@ -448,13 +447,11 @@ void SonagramPlugin::refreshOverview()
 }
 
 //***************************************************************************
-void SonagramPlugin::windowClosed()
+void SonagramPlugin::windowDestroyed()
 {
-    // the SonagramWindow closes itself !
-    m_sonagram_window = 0;
-
-    // close the plugin too
-    close();
+    m_sonagram_window = 0; // closes itself !
+    m_cmd_shutdown = true;
+    release();
 }
 
 //***************************************************************************
