@@ -19,11 +19,11 @@
 #define _SONAGRAM_PLUGIN_H_
 
 #include "config.h"
-#include <qarray.h>
+#include <qmemarray.h>
 #include <qstring.h>
 #include "mt/SignalProxy.h"
+#include "libkwave/KwavePlugin.h"
 #include "libkwave/WindowFunction.h"
-#include "libgui/KwavePlugin.h"
 
 class OverViewCache;
 class QImage;
@@ -65,7 +65,7 @@ private slots:
      * Connected to the SonagramWindow's "destroyed()" signal.
      * @see #sonagram_window
      */
-    void windowClosed();
+    void windowDestroyed();
 
     /**
      * Internally used to synchronously insert the data of one
@@ -121,7 +121,7 @@ private:
     SonagramWindow *m_sonagram_window;
 
     /** list of selected channels */
-    QArray<unsigned int> m_selected_channels;
+    QMemArray<unsigned int> m_selected_channels;
 
     /** first sample of the selection, inclusive */
     unsigned int m_first_sample;
